#
# spec file for package openstack-tempest
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013 B1 Systems GmbH, Vohburg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define component tempest

%if ! %{defined _rundir}
%define _rundir %{_localstatedir}/run
%endif

%define version_unconverted 20.0.1.dev10

Name:           openstack-%{component}
Version:        20.0.1~dev10
Release:        1.1
Summary:        OpenStack Integration Test Suite (Tempest)
License:        Apache-2.0
Group:          System/Management
Url:            https://launchpad.net/tempest
Source0:        http://tarballs.openstack.org/tempest/tempest-master.tar.gz
%if 0%{?suse_version} > 1230
Source10:       %name.conf
BuildRequires:  systemd
%endif
Patch0:         install_absolute.patch
BuildRequires:  crudini
BuildRequires:  fdupes
BuildRequires:  openstack-suse-macros
BuildRequires:  python-base
BuildRequires:  python-jsonschema
BuildRequires:  python-oslo.concurrency
BuildRequires:  python-oslo.config
BuildRequires:  python-oslo.log
BuildRequires:  python-oslo.serialization
BuildRequires:  python-oslo.utils
BuildRequires:  python-pbr
BuildRequires:  python-testtools
BuildRequires:  python-urllib3
# Documentatin build requirements:
BuildRequires:  python-Sphinx
BuildRequires:  python-oslosphinx
%if 0%{?suse_version} > 1110
Requires(pre):  pwdutils
%else
Requires(pre):  shadow-utils
%endif
Requires:       %name-test = %{version}
Requires:       git-core
Requires:       python >= 2.6.8
Requires:       python-PyYAML >= 3.12
Requires:       python-jsonschema >= 2.6.0
Requires:       python-tempest = %{version}
Requires:       python-testtools >= 2.2.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
This is a set of integration tests to be run against a live OpenStack cluster.
Tempest has batteries of tests for OpenStack API validation, Scenarios, and
other specific tests useful in validating an OpenStack deployment.

%package test
Summary:        OpenStack Integration Test Suite (Tempest) - Test Package
Group:          Development/Languages/Python
Requires:       %{name} = %{version}

%description test
This is a set of integration tests to be run against a live OpenStack cluster.
Tempest has batteries of tests for OpenStack API validation, Scenarios, and
other specific tests useful in validating an OpenStack deployment.

%package -n python-tempest
Summary:        OpenStack Integration Test Suite (Tempest) - Python module
Group:          Development/Languages/Python
Requires:       python >= 2.6.8
Requires:       python-cliff >= 2.8.0
Requires:       python-fixtures >= 3.0.0
Requires:       python-jsonschema >= 2.6.0
Requires:       python-mock >= 2.0.0
Requires:       python-netaddr >= 0.7.18
%if 0%{?suse_version} <= 1110
# Yes, this is not (yet?) listed upstream as dependency
Requires:       python-unittest2 >= 1.1.0
%endif
Requires:       python-PrettyTable >= 0.7.1
Requires:       python-ddt
Requires:       python-debtcollector >= 1.2.0
Requires:       python-oslo.concurrency >= 3.26.0
Requires:       python-oslo.config >= 5.2.0
Requires:       python-oslo.log >= 3.36.0
Requires:       python-oslo.serialization >= 2.18.0
Requires:       python-oslo.utils >= 3.33.0
Requires:       python-oslotest >= 3.2.0
Requires:       python-paramiko >= 2.0.0
Requires:       python-pbr >= 2.0.0
Requires:       python-python-subunit >= 1.0.0
Requires:       python-six >= 1.10.0
Requires:       python-stestr >= 1.0.0
Requires:       python-stevedore >= 1.20.0
Requires:       python-testscenarios >= 0.4
Requires:       python-testtools >= 2.2.0
Requires:       python-urllib3 >= 1.21.1

%description -n python-tempest
This package contains the core Python module of OpenStack Tempest.

%prep
%setup -q -n %{component}-%{version_unconverted}
%patch0 -p1
%openstack_cleanup_prep

%build
python setup.py build
## python setup.py build_sphinx -b man

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
install -d -m 755 %{buildroot}%{_localstatedir}/lib/tempest
install -d -m 700 %{buildroot}%{_rundir}/tempest
%if 0%{?suse_version} > 1230
install -D -m 644 %{SOURCE10} %{buildroot}/%_tmpfilesdir/%name.conf
%endif

### configuration files
PYTHONPATH=. oslo-config-generator --config-file %{_builddir}/%{component}-%{version_unconverted}/tempest/cmd/config-generator.tempest.conf --output-file %{buildroot}%{_sysconfdir}/tempest/tempest.conf
rm -f %{buildroot}/etc/tempest/config-generator.tempest.conf

install -d -m 755 %{buildroot}%{_sysconfdir}/tempest
for fn in logging.conf accounts.yaml ; do
    mv %{buildroot}%{_sysconfdir}/tempest/$fn{.sample,}
done
## install -d %{buildroot}%{_mandir}/man1
## install -m 644 doc/build/man/*.1 %{buildroot}%{_mandir}/man1
%fdupes %{buildroot}%{python_sitelib}/%{component}

# configuration fixes
crudini --set %{buildroot}/etc/tempest/tempest.conf oslo_concurrency lock_path /var/run/tempest
crudini --set %{buildroot}/etc/tempest/tempest.conf boto s3_materials_path ""
crudini --set %{buildroot}/etc/tempest/tempest.conf boto s3_url http://localhost:3333
crudini --set %{buildroot}/etc/tempest/tempest.conf service_available neutron true
crudini --set %{buildroot}/etc/tempest/tempest.conf service_available swift false
crudini --set %{buildroot}/etc/tempest/tempest.conf service_available heat false
crudini --set %{buildroot}/etc/tempest/tempest.conf auth admin_username admin
crudini --set %{buildroot}/etc/tempest/tempest.conf auth admin_tenant_name service
crudini --set %{buildroot}/etc/tempest/tempest.conf identity alt_username alt_demo
crudini --set %{buildroot}/etc/tempest/tempest.conf identity alt_tenant_name alt_demo

### test subpackage
%openstack_test_package_install
cp -av .stestr.conf %{buildroot}/%{_localstatedir}/lib/%{name}-test/

%post
%tmpfiles_create %{_tmpfilesdir}/%{name}.conf

%files
%defattr(-,root,root)
%license LICENSE
%dir %{_sysconfdir}/tempest
%{_bindir}/tempest
%if 0%{?suse_version} > 1230
%_tmpfilesdir/%name.conf
%else
%ghost %dir %attr(700,root,root) %{_rundir}/tempest
%endif
%config(noreplace) %{_sysconfdir}/tempest/logging.conf
%config(noreplace) %{_sysconfdir}/tempest/tempest.conf
%config(noreplace) %{_sysconfdir}/tempest/accounts.yaml
%config(noreplace) %{_sysconfdir}/tempest/whitelist.yaml

%files test
%defattr(-,root,root)
%doc README.rst
%license LICENSE
%{_bindir}/verify-tempest-config
%{_bindir}/check-uuid
%{_bindir}/skip-tracker
%{_bindir}/tempest-account-generator
%{_bindir}/subunit-describe-calls
%{_localstatedir}/lib/openstack-%{component}-test
/var/lib/openstack-tempest-test/
## %{_mandir}/man1/tempest.1%{?ext_man}

%files -n python-tempest
%defattr(-,root,root,-)
%license LICENSE
%{python_sitelib}/%{component}/
%{python_sitelib}/%{component}-*.egg-info

%changelog
* Fri Mar 29 2019 cloud-devel@suse.de
- Update to version tempest-20.0.1.dev10:
  * Remove sys unused
* Thu Mar 28 2019 cloud-devel@suse.de
- Update to version tempest-20.0.1.dev9:
  * Remove the Ocata stable branch jobs from master gate
* Wed Mar 27 2019 cloud-devel@suse.de
- Update to version tempest-20.0.1.dev7:
  * Add release notes page for version 20.0.0
  * Replace openstack.org git:// URLs with https://
  20.0.0
  * Fix potential issue with adding a fixed ip
  * Use nova zuulv3 job for nova v2 API
  * Use base.delete\_server in test\_servers.py
* Mon Mar 25 2019 dmueller@suse.com
- create lockdir on install
* Sat Mar 23 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev386:
  * Add releasenote to tag the Tempest for Stein release
* Fri Mar 22 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev385:
  * Default gabbi\_tempest\_path to empty string
  * Checking config file actually exist or not in tempest run
  * immutable user source: v3 test\_roles
  * Remove unused and duplicate nodeset defined in Tempest
* Mon Mar 18 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev378:
  * Update v3 identity inherits tests to work w/ pre-prov
  * Use credentials domain instead of creating new one
  * Add profiler support into Tempest
* Sun Mar 17 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev372:
  * Immutable user source: v3 test\_inherits
  * allow create\_server with vnic\_type and port\_profile from kwargs
  * Add autopep8 to tox.ini
  * Move tempest-tox-plugin-sanity-check to Bionic
* Sat Mar 16 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev364:
  * Remove LOG in misc.py
  * Add py37 tox env
* Fri Mar 15 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev360:
  * Set ENABLE\_VOLUME\_MULTIATTACH=true on tempest-slow subnode localrc
  * Make type decorator compatible with unicode strings
* Tue Mar 12 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev357:
  * Fix openstack-dev ML ref in test removal process
* Sun Mar 10 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev355:
  * Update json module to jsonutils
  * Set concurrency default value
* Sat Mar  9 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev351:
  * Remove admin test\_l3\_agent\_scheduler API test module
* Fri Mar  8 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev349:
  * Make tempest-slow run on stable branch also
* Thu Mar  7 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev347:
  * no force\_tenant\_isolation in DefaultDomainTestJSON
  * Improved tempest plugin sanity check script
* Wed Mar  6 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev343:
  * Update neutron quota\_driver path
* Tue Mar  5 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev341:
  * stestr expects --concurrency to be an int
* Mon Mar  4 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev340:
  * doc: fix compute API microversion list format
* Sun Mar  3 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev338:
  * Make tempest-multinode-full job for stable branch
* Sat Mar  2 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev336:
  * Use rand\_password() for password when creating user
  * Add NetworkSubnetPools to tempest cleanup
* Wed Feb 27 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev332:
  * add python 3.7 unit test job
* Sun Feb 24 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev330:
  * Fix typo
  * Conditionally mark test\_attach\_detach\_volume as slow
  * Allow decorators.attr to be conditional
  * Mark test\_server\_connectivity\_reboot as slow
* Fri Feb 22 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev323:
  * Add unit tests for tempest cleanup
  * Fix tempest cleanup
* Wed Feb 20 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev319:
  * Update v3 identity group tests to work w/ pre-prov
* Tue Feb 19 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev317:
  * Remove deprecated services from cleanup
* Sat Feb 16 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev315:
  * Mark test\_volume\_boot\_pattern as slow
* Thu Feb 14 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev314:
  * Normalize endpoint path in oauth client
* Wed Feb 13 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev313:
  * Update v3 project tests to work w/ pre-prov
  * Immutable user source: v3 test\_groups
  * Update regions tests to work w/ pre-prov
* Tue Feb 12 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev307:
  * Fix tempest cleanup for python3
* Sun Feb 10 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev305:
  * Enable volume multiattach tests in tempest-full/slow jobs
* Thu Feb  7 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev303:
  * Make interop check job as voting
  * fix port\_profile
* Wed Feb  6 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev299:
  * Fix tempest cleanup AttributeError
  * Add black-list based tests for tempest run command
  * Add whitelist based tests for tempest run command
  * Immutable user source: v3 test\_projects
  * Fixing ignored value of --config parameter in tempest account-generator
  * Adding missing test cases of tempest workspace
* Sat Feb  2 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev287:
  * Current naming convention is uninformative
  * Add tempest-slow-py3 job definition
  * Add tempest-multinode-full-py3 job definition
  * Raise renew\_delay in TestNetworkBasicOps:test\_subnet\_details
  * Remove warnings.simplefilter to suppress ResourceWarning
  * Adding missing tests for regex and black-regex in tempest run
  * Fix invalid exception module usage
  * Ensure volume is deleted after build error
  * Update v3 identity domain configuration tests to work w/ pre-prov
  * fix typos
* Fri Feb  1 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev267:
  * Convert result of hosts.values() to list always
  * Skip test\_subnet\_details slow test until bug 1813198 is fixed
  * Log the result of command in get\_nic\_name\_by\_ip
* Thu Jan 31 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev262:
  * Fix E117 for pycodestyle (pep8) 2.5.0
* Wed Jan 30 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev261:
  * Update v3 identity project tag test to work w/ pre-prov
  * Update v3 identity domain negative tests to work w/ pre-prov
* Tue Jan 29 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev257:
  * Add placement client for basic GET operations
* Wed Jan 23 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev256:
  * Update v3 oauth consumers tests to work w/ pre-prov
* Tue Jan 22 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev254:
  * Check network connectivity of the instance before and after live migration
* Mon Jan 21 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev252:
  * Fix verify-config KeyError
  * Move v3 project negative tests to work w/ pre-prov
  * Move v3 identity endpoint group tests to work w/ pre-prov
* Wed Jan 16 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev247:
  * Add unittest for types\_client
* Tue Jan 15 2019 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev246:
  * [Trivial fix]Remove unnecessary slash
  * Remove unnecessary setUp
* Sun Dec 30 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev243:
  * Use renamed template 'integrated-gate-py3'
* Sat Dec 29 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev241:
  * update spelling error
  * Remove unnecessary line of code
* Mon Dec 24 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev238:
  * Add missing ws seperator between words part 2
* Thu Dec 20 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev236:
  * Add device\_owner to gateway port search criteria
* Mon Dec 17 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev234:
  * Immutable user source: test\_default\_project\_id
* Thu Dec 13 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev233:
  * Add irrelevant-files for grenade-py3 job
  * Move nova-cells-v1 job to the experimental queue
  * Migrate tempest provided base jobs to bionic
* Mon Dec 10 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev227:
  * Transfer respository  to repository
  * [Negative] Extend volume over quota limit
* Sun Dec  9 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev223:
  * Adding debugger in tox.ini
* Sat Dec  8 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev221:
  * Move test test\_list\_agents\_non\_admin to non-admin dir
* Fri Dec  7 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev219:
  * Change openstack-dev to openstack-discuss
  * Support immutable user source
* Sat Nov 24 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev216:
  * docs: Fix incorrect docstrings in reStructuredText format
* Thu Nov 22 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev215:
  * Handling invalid path of workspace register and move
  * Add missing ws seperator between words
  * Fix required projects for sanity plugin check job
  * interfaces\_by\_fixed\_ip no extra port
  * Make connectivity test less backend dependent
* Wed Nov 21 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev205:
  * Improve the user lock config options help message
  * docs: Include information about the list of supported projects
* Tue Nov 20 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev201:
  * docs: Fix plugin registry generation failures
* Sat Nov 17 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev199:
  * Add a blank space between "eui\_ip" and "when"
* Fri Nov 16 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev198:
  * addCleanup should be immediately after the creating statement
* Wed Nov 14 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev197:
  * Refactor cleanups for test\_trusts
* Sun Nov 11 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev196:
  * Add api ref link for import\_backup
  * Wait for IP add/remove in test\_add\_remove\_fixed\_ip
* Sat Nov 10 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev192:
  * change http links to https links
* Thu Nov  8 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev191:
  * Mark network slow test as slow
* Wed Nov  7 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev189:
  * Pass tox\_extra\_args to Run tempest task
  * Replace deprecated "decodestring"
  * Set max microversion 2.35 for nova floatingip and securitygroup
* Tue Nov  6 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev183:
  * trivial: Don't run integration tests on tools/.\* updates
* Mon Nov  5 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev181:
  * Deprecate available filters in favor of enabled
* Fri Nov  2 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev180:
  * [Trivial Fix] modify spelling error of "resource"
  * Update REVIEWING docs with fast-track approval process
* Thu Nov  1 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev177:
  * Adding missing test cases in "test\_run.py"
* Wed Oct 31 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev175:
  * Add ipv6 tempest jobs
* Sun Oct 28 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev174:
  * GABBI\_TEMPEST\_PATH in tox passenv and devstack playbook
* Fri Oct 26 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev173:
  * Adding missing test case of account generator resources
* Thu Oct 25 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev172:
  * swift: container ACL - use ID's for tenant and user
  * fix tox python3 overrides
* Wed Oct 24 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev168:
  * Fix assert logic in test\_list\_security\_groups\_list\_all\_tenants\_filter
  * Fix QuotasNegativeTest to use non dynamic credentials
* Tue Oct 23 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev164:
  * Do not check account unlock if lockout config is 0
  * Fix help message of user\_unique\_last\_password\_count
* Fri Oct 19 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev160:
  * Remove duplicate legacy-tempest-dsvm-multinode-full job
  * Remove deprecated find\_test\_caller function
* Thu Oct 18 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev156:
  * Make tempest-full-py3 not run for unit tests change
* Wed Oct 17 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev154:
  * Import periodic-tempest-dsvm-oslo-latest-full-master job
* Tue Oct 16 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev152:
  * Change way how second NIC in guest OS is configured
* Mon Oct 15 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev150:
  * Convert job legacy-periodic-tempest-dsvm-all-master
  * Use remote\_client from tempest.lib.common instead of tempest.common
* Sat Oct 13 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev146:
  * Convert legacy-tempest-dsvm-neutron-pg-full to Zuul v3
  * Allow to create a rest\_client not following redirects
  * Make some test\_list\_projects tests work w/ pre-prov
* Fri Oct 12 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev140:
  * Fix Zuul usage of tempest-full
  * Handling invalid name of workspace register and rename
  * Do not pass device when calling compute.base.attach\_volume
* Thu Oct 11 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev134:
  * Replace openSUSE experimental check with newer version
  * Run static account tests based on tempest-full-py3
  * Optimize and enhance the code of "test\_routers.py"
* Wed Oct 10 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev128:
  * Remove legacy-tempest-dsvm-cinder-v1
  * Add interop-tempest-consistency job in Tempest gate
  * Fix test\_get\_config\_file to always work
  * Use show\_volume\_type to check the result of update\_volume\_type
  * Add delete\_agent to AgentsClient
* Thu Oct  4 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev118:
  * Adding unit test of setting config path for "tempest run"
* Wed Oct  3 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev116:
  * Adding missing test cases of "test\_verify\_tempest\_config"
  * Deprecate all-plugin
  * Removing redundant spec value in account\_generator.py
  * Interface tests: wait for server to become SSHable
  * Add missing test for "Show API v2 details" action
* Tue Oct  2 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev106:
  * Add test coverage CMD cleanup\_service
  * refactor v3 cred tests to work with pre-prov
* Sat Sep 29 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev103:
  * Add response schema validation for volume qos-specs
  * Cleanup irrelevant-files list in .zuul.yaml
  * fix: Re-clarify unit test REVIEWING documentation
  * Removing redundant "if test\_resource.network" from account\_generator.py
* Sat Sep 22 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev95:
  * Optimize test\_volume\_swap\_with\_multiattach for server status wait
  * Mark some slow tests as slow so they move out of the main job
  * Rename TestQuotasClient to TestHostsClient
  * Default enable run\_validation
  * Skip test\_server\_connectivity\_cold\_migration\_revert until fixed
  * Skip 3.19 test\_reset\_group\_snapshot\_status
* Fri Sep 21 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev83:
  * Fixed test\_compare\_volume\_stats\_values false failures
  * Fix docstring example in HACKING
* Wed Sep 19 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev80:
  * Set max\_microversion 2.35 for nova image tests
* Tue Sep 18 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev79:
  * Removing duplicate variable "parsed\_args.config\_file"
  * Run tempest-full(-py3) in stable/rocky
* Sat Sep 15 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev75:
  * Fix an assert sequence in test\_image\_share\_accept
  * Set CONF.image\_feature\_enabled.api\_v1 default to False
* Thu Sep 13 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev71:
  * Follow devstack-plugin-ceph job rename
  * Fix deprecated\_name in the help message in config.py
* Wed Sep 12 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev67:
  * Use openstack-tox-cover template
  * switch documentation job to new PTI
  * import zuul job settings from project-config
* Tue Sep 11 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev61:
  * Fix to enable \`--config-file\` option
* Mon Sep 10 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev60:
  * Update .mailmap for ghanshyam emails
* Sat Sep  8 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev58:
  * Remove unnecessary response check in InstanceUsageAuditLogTestJSON
  * Bump up python version of unit test
* Thu Sep  6 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev54:
  * Add check for hypervisor state before getting uptime
  * trivial: Correct class name for BaseVolumeQuotasAdminTestJSON
  * Remove unnecessary class variables
  * Add test for list snapshots with offset param
* Wed Sep  5 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev46:
  * Cleaning up a duplicated code
* Tue Sep  4 2018 dmueller@suse.com
- switch to stestr
* Tue Sep  4 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev44:
  * Remove unused config.CONF
  * Removing unnecessary else
  * Update .mailmap email addresses
  * Do not set microversion for server diagnostics negative test
* Sat Sep  1 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev36:
  * Migration tests in v2.6 should not repeat all migration tests
* Fri Aug 31 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev34:
  * Modify comment of scheduler\_available\_filters
  * Fix nits and log from I996d257e089f0676e316f2b14207c343063ccf8e
* Thu Aug 30 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev30:
  * Prevent verify-config from IndexError
* Wed Aug 29 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev28:
  * Remove base class complex and confusing variable
* Tue Aug 28 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev27:
  * Add Tempest gate job for stable/rocky
  * Remove unnecessary class variable in v3 snapshots\_client
* Sun Aug 26 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev23:
  * Use base.get\_host\_for\_server to get server host
* Sat Aug 25 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev21:
  * Switch to stestr in README.rst and the method name
* Fri Aug 24 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev20:
  * Remove deprecated option volume\_feature\_enabled.api\_v1
* Thu Aug 23 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev19:
  * Remove unused compute.base.clear\_resources
  * Fix comments in rest\_client
  * add python 3.6 unit test job
  * Add test for create volume from snap without size
* Wed Aug 22 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev12:
  * Add server schema for microversion 2.8
  * Delete snapshot in test\_image\_defined\_boot\_from\_volume
  * Add etc/\*.conf files to .gitignore
  * Bump hacking to 1.1.0
* Mon Aug 20 2018 nicolas.bock@suse.com
- Update to version tempest-19.0.1.dev7:
  * Change schema hypervisor.cpu\_info from string to object in 2.28
* Mon Aug 20 2018 nicolas.bock@suse.com
- Fix linter complaints about licenses
* Sun Aug 19 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev5:
  * Add release notes page for version 19.0.0
* Sat Aug 18 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev3:
  * Set max microversion 2.43 for add\_fixed\_ip
* Fri Aug 17 2018 cloud-devel@suse.de
- Update to version tempest-19.0.1.dev2:
  * Fix typos in vnc-hardcoded-server-name-removed releasenotes
  19.0.0
  * Fix python pkg format issue
  * Fix 'ref' format errors in README file
  * Add releasenote to tag the Tempest for Rocky release
  * Deprecate volume api selection config option
* Wed Aug 15 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev395:
  * Fix disabled\_reason's type in services schema
  * Add server schema for microversion 2.63
  * Add server schema for microversion 2.57
  * Add server schema for microversion 2.54
  * Fill servers schema gap in microversion 2.47/2.48
  * Fill quota schema for microversion 2.36/2.57
  * Remove api\_version setting from volume v3/v2 service client
* Tue Aug 14 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev386:
  * trivial: Fix some compute api\_schema formatting nits
  * Fill aggregate schema for microversion 2.41
  * Add comment for schema change in microversion 2.13
  * Adding links to git reference in docs
* Mon Aug 13 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev378:
  * Fill schema gap in flavors.py
  * Removing unused attributes from test\_run.py
* Fri Aug 10 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev374:
  * Fixing test "test\_verify\_glance\_version\_no\_v2\_with\_v1\_1"
  * Make volume client alias with \_latest suffix
* Thu Aug  9 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev370:
  * Added tempest\_black\_regex to skip tempest tests
  * Add comment for schema change in microversion 2.19
  * Dynamic width count for plugin registry table column
* Wed Aug  8 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev364:
  * Pass "access\_point" server to get\_remote\_client
  * Add server schema for microversion 2.26
  * Add more information for InvalidCredentials exception
  * Add server schema for microversion 2.19
  * Hacking checks for negative test cases
  * Move all volume v2 service client unit tests to v3 dir
  * Use the same timeout as in the legacy job
* Tue Aug  7 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev350:
  * use fqdn for zuul projects
  * Use --os-endpoint-type for Cinder CLI
  * Add server schema for microversion 2.16
  * Fill server schema for microversion 2.9
  * Avoid server\_check\_teardown exception breaking tearDown
* Sat Aug  4 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev340:
  * Convert tempest-scenario-all job to tempest-slow
  * Fix typo xpvnc in get\_remote\_console schema
* Fri Aug  3 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev336:
  * Check API extension 'filter-validation'
  * Add server schema for microversion 2.6
  * Fill servers schema for microversion 2.3
* Thu Aug  2 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev330:
  * refactor: Prepare test\_list\_projects for pre-prov
* Wed Aug  1 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev328:
  * Log server console output during create/get timestamp
  * Fix broken image api ref url
  * Set max\_microversion 2.35 for nova network tests
  * Skip adding host to aggregate with az if host already in other zone
* Tue Jul 31 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev320:
  * Modify limits fields according to microversion
  * Move server groups schema into its own file
  * Add server tags schema in servers.py
  * Do not check flavor.id after Microversion 2.46
* Mon Jul 30 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev312:
  * Create port with port\_vnic\_type and port\_profile from config
* Sat Jul 28 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev310:
  * Skip verifying empty devices in test\_tagged\_attachment until bug is fixed
  * Move creating server group from resource\_setup to setUp
  * Make instance\_action\_events.traceback a non-required field
* Fri Jul 27 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev304:
  * Use a smaller number for checking console log length
  * Move volume v2 service client unit tests to v3 dir
  * Added storyboard integration to tempest.lib decorators
  * Replacing get\_vnc\_console with get\_remote\_console after microversion 2.6
  * Do not pass disk\_over\_commit after Microversion 2.25
* Thu Jul 26 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev294:
  * Remove unused class variables
  * Remove unnecessary body assignment
* Wed Jul 25 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev290:
  * Replace volume size with configured value
  * Cap additional nova-network tests at Queens
  * Add extra\_msg and server parameter to check\_vm\_connectivity
* Tue Jul 24 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev284:
  * Skip list FIP test for neutron new behaviour
* Mon Jul 23 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev282:
  * Add irrelevant-files to nova-multiattach job in .zuul.yaml
* Sun Jul 22 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev280:
  * Port tempest-scenario-all to zuul v3
* Sat Jul 21 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev278:
  * Correct the usage on listing neutron ports
  * Omit X-Subject-Token from log
  * no force\_tenant\_isolation in endpoint tests
* Thu Jul 19 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev272:
  * trivial: Fix typos in the documentation page
  * Set max\_microversion 2.43 for virtual\_interfaces tests
  * Add additional log of meta\_data devices content
  * docs: Add information on test removal/interop to REVIEWING
* Wed Jul 18 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev264:
  * Remove deprecated allow\_tenant\_isolation option
* Sun Jul 15 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev262:
  * remove skip for test\_connectivity\_between\_vms\_on\_different\_networks
  * trivial: Fix typos in the test\_removal documentation page
  * Add update\_service to compute services\_client library
  * docs: Add HACKING information about test attributes
* Sat Jul 14 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev254:
  * Rename scenario job and make it voting
* Fri Jul 13 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev252:
  * Move live migration tests out of scenario job
* Wed Jul 11 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev250:
  * Add api refs for volume snapshots client and network agents client
  * Move test\_tokens test to static
  * Run nova-live-migration job in check as n-v
* Tue Jul 10 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev242:
  * Move unset\_flavor\_extra\_specs to extra specs file
  * Add compute microversion 2.61 schema in flavors\_client
  * trivial: fix some incorrect compute microversion references
  * Mark raw strings as such
  * tox: Silence warnings from stdlib libraries
* Sat Jul  7 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev233:
  * Adding additional assertions for retype test
* Fri Jul  6 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev231:
  * refactor: Combine nearly duplicate group tests together
  * refactor: Add setup\_test\_group to identity admin base test class
* Thu Jul  5 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev227:
  * Add related bug info for resize test
* Wed Jul  4 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev225:
  * Adding test case for migration policy 'never'
  * Update image creation error msg to mention the correct image type
  * Add volume-attached resize revert server test
* Sat Jun 30 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev219:
  * Improve Tempest workspace manager unit test coverage
* Fri Jun 29 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev217:
  * Cleanup networks resources at test level
  * Move Stable branch Policy Doc outside of coding guide
* Thu Jun 28 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev213:
  * Cleanup v18.0.0 release notes' prelude
  * Add status check for creating volume backup
* Wed Jun 27 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev210:
  * Add extra apis to volume v3 services client
  * Delete a cg-snapshot following updated volumes
* Sat Jun 23 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev206:
  * Fix some typos on the types and encryption types client
* Thu Jun 21 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev205:
  * Add api ref links for snapshots and volume types clients
* Wed Jun 20 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev204:
  * Fix volume backup test
* Tue Jun 19 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev203:
  * Add new schema for Nova microversion 2.63
  * Move nova cell v1 job to check pipeline
  * Write tempest-multinode-full as zuulv3 native
  * Fix image\_id KeyError in test\_create\_backup
* Sun Jun 17 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev195:
  * Fix TestInterfaceWaiters
* Sat Jun 16 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev194:
  * Filter out implied roles
* Fri Jun 15 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev193:
  * Revert "Add server name check for multiple creations"
* Thu Jun 14 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev191:
  * Remove force\_tenant\_isolation from Cinder tests
  * Add server name check for multiple creations
* Tue Jun 12 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev187:
  * Fix typos replace seperate with separate
  * Fix tests for call\_until\_true function
  * Remove force\_tenant\_isolation from FloatingIPAdminTestJSON
* Mon Jun 11 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev182:
  * Move skip condition under skip\_checks method
  * Adding a note for test case test\_volume\_boot\_pattern()
* Sun Jun 10 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev179:
  * Cap nova-network tests at Queens
* Fri Jun  8 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev177:
  * Remove volume v2 service client warning
  * Fix race condition in device tag testing
* Thu Jun  7 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev174:
  * trivial: Fix reno typos
  * Replace Chinese quotes with English quotes
  * Add api ref links for network agents\_client
  * Fix test\_http test case
  * To cleanup the awaiting-state volume
  * Document branch support policy for extended maint branches
  * Remove python 2.6 docref
  * Use inline literal markup for options in releasenotes
  * Switch to use primary credential in volume backup tests
  * Modify quota set fields according to microversion
  * Add cinder v2 experimental job
  * Fix indentation in README.rst
  * Refactor random naming
  * Add compute microversion 2.57 schema in servers\_client
  * Assert volume deletion in test\_image\_defined\_boot\_from\_volume
  * Integration tests for tagged attach
  * Improve use of RemoteClient in device tagging test
  * Add wait\_for\_interface\_detach method
  * Add tests for wait\_for\_interface\_status
  * Add test to shelve the paused server: bug# 1745529
  * Add compute microversion 2.54 schema in servers\_client
  * Remove test\_get\_service\_by\_service\_and\_host\_name
  * Move volume v2 service clients to v3 dir
  * Volume Service Testing: default to v3 endpoints
  * Use assertTrue and assertFalse vs assertEqual
  * Cleanup ignored\_list\_T110.txt
  * Migrate legacy scenario job to tempest in-tree
  * Check status code when downloading empty file
  * Backup and restore scenario
  * Add service tagging for 'test\_iscsi\_volume'
  * Add nova-live-migration to experimental queue jobs
  * Fill update, rebuild, list API response schema for 2.47
  * Fill update, rebuild API response schema for 2.26
  * Fill update, rebuild API response schema for 2.19
  * Fill update, rebuild API response schema for 2.9
  * Add test Migrating a volume from created snapshot
  * Fix listing servers by invalid status after V2.38
  * Trivial docstring cleanup in TestServerAdvancedOps
  * Modify the empty list ensure method
  * Add 2.55 schema & update flavor API in flavors\_client
  * Add common method to check the microversion compatibility
  * Trivial: Fix the comment of TempestConfigPrivate
  * Use new encryption provider constants
  * Set max\_microversion 2.35 for nova security group tests
  * Add a negative test about attaching a in-use volume to the different server
* Thu Apr 26 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev91:
  * Removing the skip decorator as bug 1687044 was already resolved
* Wed Apr 25 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev89:
  * Follow the new PTI for document build
* Tue Apr 24 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev87:
  * Add job to run tempest-full with Python 3.6
  * Add tests for application credentials
* Mon Apr 23 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev83:
  * Improve patch and patchobject Base test case method attributes
* Thu Apr 19 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev81:
  * Skip puppet-\* projects for plugin search
  * Fix a plural mistake REVIEWING.rst
* Sat Apr 14 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev77:
  * Fix test\_snapshot\_list\_param\_marker when using predefined user
  * Add identity v3 project tags client
  * Fix TypeError in \_unshelve\_server
  * Fix a capitalization mistake in README.rst
* Fri Apr 13 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev69:
  * Fix code to pass pep8 Tox environment
* Wed Apr 11 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev68:
  * VNC harcoded server name removed
  * Fix test\_host\_name\_is\_same\_as\_server\_name
* Mon Apr  9 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev64:
  * Cleanup and rename test\_create\_ebs\_image\_and\_check\_boot
  * Replace list\_hypervisors with list\_services
  * Don't use hypervisor\_hostname as compute hostname
* Sun Apr  8 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev58:
  * [Trivial]Add coverage for extending non-blank volume
* Sat Apr  7 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev56:
  * [Trivial]Add coverage for creating snapshot from non-blank volume
* Fri Apr  6 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev54:
  * Docs: Elaborate on feature flag in HACKING file
* Sat Mar 31 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev52:
  * Set max\_microversion 2.35 for nova floating ip bulk tests
* Fri Mar 30 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev50:
  * Set max\_microversion 2.35 for nova tenant network tests
  * Run all scenario in parallel
* Thu Mar 29 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev46:
  * Updated from global requirements
  * Updated from global requirements
* Tue Mar 27 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev43:
  * Set max\_microversion 2.38 for nova image-metadata tests
* Mon Mar 26 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev41:
  * Replacing deprecated list\_hosts with list\_hypervisors
* Sat Mar 24 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev39:
  * Add verbose option for stdout in subunit\_describe\_call
  * Add nova-cells-v1 to experimental queue jobs
* Fri Mar 23 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev35:
  * Do not fail on stackviz issues
  * Fix expected response code of show\_image\_file
* Tue Mar 20 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev32:
  * Fix typos in release notes
  * Add project\_tags identity feature flag
  * Set max\_microversion 2.42 for hosts tests
  * Do not use skip\_checks in TestVolumeBootPattern
  * Keystone v3-ext/OS-ENDPOINT-POLICY endpoints implementation
* Sat Mar 17 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev24:
  * Update port profile only if defined
* Fri Mar 16 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev22:
  * Remove unnecessary indentations in releasenotes index
  * Add release notes page for 17.1.0 & 17.2.0
  * Connect to default ports if none are specified
* Thu Mar 15 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev17:
  * Fix create\_volume\_snapshot under scenario
  * Add network internal connectivity check to VMs
* Wed Mar 14 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev15:
  * Updated from global requirements
  * Rename duplicated class name AttachVolumeMultiAttachTest
  * Use create\_test\_server wrapper for server creation
* Tue Mar 13 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev9:
  * Update links in README
* Thu Mar  8 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev8:
  * Add support for blacklist file for Zuul jobs
* Sat Mar  3 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev7:
  * Stop running plugin-sanity job for doc and req changes
* Fri Mar  2 2018 tbechtold@suse.com
- Include .stestr.conf in -test package
* Fri Mar  2 2018 cloud-devel@suse.de
- Update to version tempest-18.0.1.dev6:
  * Add release notes page for 18.0.0
  * Use fetch-subunit-output role
  18.0.0
  * Update image using 'owner' parameter
  * Disable warnings as errors for sphinx
* Wed Feb 28 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev292:
  * Add releasenotes to mark the start of Queens support, newton EOL
  * Reno for tempest run CLI new arg and fix
* Tue Feb 27 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev288:
  * Add unit test for tempest run --config-file
  * allow to config port binding:profile
  * update the home-page url
  * Move share code to \_create\_server\_with\_group
  * Do not test create\_interface\_by\_fixed\_ips if no isolated network
* Sun Feb 25 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev278:
  * Fixing the condition to run tests in tempest run
* Sat Feb 24 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev276:
  * Add test for tempest run with a whitelist file
  * Add a black\_regex flag to tempest run
  * Fix the -l/--list-tests argument for tempest run
  * Cleanup selection list args in tempest run
  * Remove duplicate unit test module
* Fri Feb 23 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev266:
  * Add missing env vars from unit test job
  * Remove leftover call to \_create\_stestrepository
* Thu Feb 22 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev263:
  * Enable tempest-full on stable/pike
  * Create image using 'owner' parameter
  * Switch Tempest CLI commands from testrepository to stestr
* Wed Feb 21 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev257:
  * Fix misuse of assertTrue
  * Refactor config drive mounting
  * Delete identity domain must delete its contents
  * Expose bug: Delete identity domain with contents
* Tue Feb 20 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev251:
  * Remove outdated comment in .zuul.yaml
  * Make queens jobs voting
* Mon Feb 19 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev247:
  * Updated from global requirements
* Sat Feb 17 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev245:
  * Add stable/queens version of the full neutron job
* Fri Feb 16 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev243:
  * Add default value for CONF.auth.admin\_domain\_name
  * Fix image namespace test logging
  * Do not run stage-output again in Tempest
* Thu Feb 15 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev237:
  * Add compute test for ServerGroupAffinityFilter
* Wed Feb 14 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev236:
  * Fixes test\_device\_tagging IndexError
  * [TrivialFix] Remove unused statement in scenario/manager.py
  * Add simple compute API test to create server with utf8 name
* Tue Feb 13 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev230:
  * Add show quota details to network quotas\_client library
* Mon Feb 12 2018 tbechtold@suse.com
- Fix Requires
* Thu Feb  8 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev229:
  * Add test for showing encryption specs item
  * Fix a broken volume group api ref link
  * Deprecate list\_servers\_on\_hypervisor and search\_hypervisor in v253
* Thu Feb  8 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev223:
  * Add 'doc' tag for bug link on doc theme
  * Remove redundant py3 integration job
  * Refresh server data after fip is assigned
  * Add test for IP substring filtering
  * Use '\_live\_migrate' instead of '\_migrate\_server\_to' in test\_live\_migration.py
  * Neutron test cases create,list,update port failed
  * Remove BaseV\*ImageAdminTest class
* Wed Feb  7 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev209:
  * Delete meaningless and unused parameters
* Tue Feb  6 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev207:
  * Add the nova-multiattach job to the check/gate queues
* Sat Feb  3 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev205:
  * Zuul: Remove project name
  * Delete base module not applicable definition
  * Add multi-attach swap test
  * Add resize test for multiattach volumes
  * Add a few tests for cinder multiattach
  * Do not skip entire testcase if floating\_ip is not enabled
  * Support only volume api\_v3 is enabled
* Fri Feb  2 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev191:
  * Fix the default value of stage\_dir
  * Make tempest-full-py3 voting
* Thu Feb  1 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev187:
  * Fix compute api ref links
  * Update api-ref for bug#1602400
  * Remove unnecessary alias for service clients
  * Fix broken compute api ref links
  * Add show default quotas API to network quotas\_client library
  * Use tenant\_network if any in testcases after microversion v2.37
  * Use addClassResourceCleanup for cleanup of volume resources
* Wed Jan 31 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev173:
  * Fix creating release notes using tox -e venv -- reno new <slug>
* Mon Jan 29 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev171:
  * Add test case for group type specs APIs
* Sun Jan 28 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev169:
  * Replace curly quotes with straight quotes
* Fri Jan 26 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev167:
  * Add a py3 integration test
* Wed Jan 24 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev166:
  * Remove deprecated 'orchestration' config group options
  * Get func.\_\_class\_\_.\_\_name\_\_ if no attribute \_\_name\_\_
  * Fixed misspelling in test code
* Tue Jan 23 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev160:
  * Handle missing flavor.id in server response
  * Restrict test\_list\_endpoints\_for\_token to tempest
  * Remove unnecessary setup\_clients methods
* Mon Jan 22 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev154:
  * Remove deprecated config options 'resources\_prefix'
  * Updated from global requirements
* Sat Jan 20 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev151:
  * Do not select inactive l3 agent in L3AgentSchedulerTestJSON
* Fri Jan 19 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev149:
  * Add flavor check after resize server
  * Remove 'deactivate\_image' config options
  * Default to using neutron networks\_client in get\_tenant\_network
  * Do not override stage-dir in tempest post
  * Relocate branch conditional for tempest-full job
  * Add same extra specs as self.flavor\_ref for created new flavor
  * Add some missing implemented microversion in doc
  * Skip testcases when shared nets are found in AutoAllocateNetworkTest
  * Use wraps decorator
  * Remove redundant tempest-full
* Thu Jan 18 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev129:
  * Updated from global requirements
  * Add status='ACTIVE' when using changes-since as filter
  * Follow the new PTI for document build
  * Add NOTE related to 'on-demand' migration
* Wed Jan 17 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev122:
  * Rename tox\_venvlist
* Tue Jan 16 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev120:
  * Wait for server to be active in test\_device\_tagging
* Sun Jan 14 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev118:
  * Handle creating an image from a server with microversion > 2.35
  * CLI tests: Identity v3 (project name, api version)
* Sat Jan 13 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev115:
  * Decouple AttachVolumeShelveTestJSON from AttachVolumeTestJSON
* Sun Jan  7 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev114:
  * Revert "Use a non admin privileges for retyping a volume"
* Sat Jan  6 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev112:
  * Only run tempest-full on the master branch
* Wed Jan  3 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev111:
  * modify params transfer mode in test\_snapshot\_manage
  * Use addClassResourceCleanup in test\_container\_sync
* Tue Jan  2 2018 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev107:
  * Change containers to list if string
  * Ignore a Cinder volume's "updated\_at" field
  * Rename a method to avoid camel case
  * Fix the mistake of code indent
  * Do not use class variable for clients in ContainerSyncTest
  * Document how to write multiline regex with comments
  * Fix an outdated comment referencing nova-volumes
  * Set OS\_TEST\_LOCK\_PATH default value in fake\_config
  * Use addClassResourceCleanup for the cleanup of network resources
* Wed Dec 27 2017 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev89:
  * Add addOnException of unshelve\_server when using sharing server
* Sat Dec 23 2017 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev87:
  * Add some api ref links for network service clients
* Fri Dec 22 2017 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev85:
  * Fix broken swift ref links
  * Modify log message in debug\_ssh
  * Update Octavia plugin
* Thu Dec 21 2017 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev79:
  * Remove find\_stack\_traces.py
* Wed Dec 20 2017 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev77:
  * Updated from global requirements
  * Add release note about the ostestr tox job
* Tue Dec 19 2017 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev73:
  * Remove resource\_cleanup from test\_object\_version
  * Add skip checks for snapshot manage and group snapshots tests
  * Use addClassResourceCleanup in account service test
  * Remove confusing comment in common/compute.py
* Sat Dec 16 2017 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev65:
  * Add CONF.compute\_feature\_enabled.volume\_backed\_live\_migration
  * Add negative test for attaching an attached volume to the same instance
* Fri Dec 15 2017 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev61:
  * Use addClassResourceCleanup in test\_inherits
* Thu Dec 14 2017 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev59:
  * Add update groups types API endpoint to volumes v3 library
  * Refactor volume groups and group snapshots tests
  * Stop using resource\_cleanup in identity\_v3 tests
* Tue Dec 12 2017 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev53:
  * Remove deprecated 'forbid\_global\_implied\_dsr' feature flag
  * Fix a misspelled addClassResourceCleanp in tempest doc
  * Avoid tox\_install.sh for constraints support
* Fri Dec  8 2017 gayane.osipyan@suse.com
- Remove python-tempest-lib dependency
- Add python-jsonschema and python-testtool to BuildRequirements
* Fri Dec  8 2017 gosipyan@suse.com
- Update to version tempest-17.2.1.dev47:
  * Fix a missing preposition in plugin doc
  * Use addClassResourceCleanup for cleanup in identity users test
  * Use addClassResourceCleanup for cleanup in test\_regions
  * Revert "Update volume-status waiter for new cinder attach"
  * Use addClassResourceCleanup for cleanup of service
  * Initial tempest-full job
  * use addClassResourceCleanup in test\_roles
  * Add IPv6 support to create\_websocket()
  * Only use stestr and tempest run in tempest tox jobs
  * Make shelved\_offload\_time's help message more specific
* Sat Dec  2 2017 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev27:
  * Fix directory tree appearance in document
* Fri Dec  1 2017 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev26:
  * Use addClassResourceCleanup in test\_list\_projects
  * Move wait\_for\_interface\_status into \_check\_interface
  * Fix docs markup consistency
  * Add some verify in test\_create\_ebs\_image\_and\_check\_boot
  * Add Networks client unit tests
* Thu Nov 30 2017 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev19:
  * Remove deprecated skip\_unless\_attr decorator
  * Updated from global requirements
  * Fix verbose grammar
* Wed Nov 29 2017 cloud-devel@suse.de
- Update to version tempest-17.2.1.dev14:
  * Add the verify of network\_id in \_test\_create\_interface\_by\_port\_id
  * Remove a redundant self argument in decorators
  17.2.0
* Tue Nov 28 2017 cloud-devel@suse.de
- Update to version tempest-17.1.1.dev90:
  * Use service tagging 'decorators'
  * Change Conflict's error message
  * Use addClassResourceCleanup to cleanup floatingips
* Fri Nov 24 2017 cloud-devel@suse.de
- Update to version tempest-17.1.1.dev85:
  * test\_mtu\_sized\_frames: sanity check connectivity first
* Thu Nov 23 2017 cloud-devel@suse.de
- Update to version tempest-17.1.1.dev83:
  * Add docs for running a single test
  * Don't check console output if not available
* Wed Nov 22 2017 cloud-devel@suse.de
- Update to version tempest-17.1.1.dev79:
  * Fix a pointer to NotFound exception
  * Add role to build the stackviz report
  * Process test results from a tempest run
* Tue Nov 21 2017 cloud-devel@suse.de
- Update to version tempest-17.1.1.dev74:
  * Use zuul v3 for running tempest plugin sanity check
  * Fix indentation in docs
  * run-tempest role: new tempest\_test\_regex variable
  * Remove unnecessary argument in "skip\_because" decorator
  * Add post step to Tempest base job
  * Modify the help message for getting identity extensions
* Sun Nov 19 2017 cloud-devel@suse.de
- Update to version tempest-17.1.1.dev62:
  * test\_network\_v6: log console when test fails
  * Edit documentation for account-generator
  * Use get\_tenant\_network in get\_server\_ip
* Sat Nov 18 2017 cloud-devel@suse.de
- Update to version tempest-17.1.1.dev57:
  * Remove setting of version/release from releasenotes
  * Update URL from "http" to "https"
  * Updated from global requirements
  * Fix volume v1 api ref links
  * Stop using resource\_cleanup in identity\_v2 tests
  * Use addClassResourceCleanup to clear domains
  * Use addClassResourceCleanup in BaseImageTest
* Fri Nov 17 2017 cloud-devel@suse.de
- Update to version tempest-17.1.1.dev43:
  * Fix 'tempest cleanup' for volume service client
  * Remove v2 identity from tempest cleanup command
* Wed Nov 15 2017 cloud-devel@suse.de
- Update to version tempest-17.1.1.dev39:
  * Add support of args and kwargs in call\_until\_true
  * Move and update test\_resize\_volume\_backed\_server\_confirm
  * Initial skeleton for devstack-tempest base job
  * Add a .htaccess for redirecting old paths
* Tue Nov 14 2017 cloud-devel@suse.de
- Update to version tempest-17.1.1.dev31:
  * Updated from global requirements
  * Don't use server\_id class variable in \_test\_resize\_server\_confirm
  * Fix fixed\_ips tests to skip if ip not found
* Thu Nov  9 2017 cloud-devel@suse.de
- Update to version tempest-17.1.1.dev25:
  * Fix doc issue in plugin.py
* Sat Nov  4 2017 cloud-devel@suse.de
- Update to version tempest-17.1.1.dev23:
  * Change description of annotation
* Fri Nov  3 2017 cloud-devel@suse.de
- Update to version tempest-17.1.1.dev21:
  * Fix AssertionError in test\_rand\_password\_with\_len\_2
  * Ensure project get and list have match
  * Remove deprecated volume apis from v2 volumes client
  * Use addClassResourceCleanup in MeteringTestJSON
  * Add support for "per\_volume\_gigabytes" and "backup\_gigabytes" quota
* Wed Nov  1 2017 cloud-devel@suse.de
- Update to version tempest-17.1.1.dev11:
  * Remove specific project checking in test
* Sat Oct 28 2017 cloud-devel@suse.de
- Update to version tempest-17.1.1.dev10:
  * Add unit tests to check for CONF getattr during import
  * Use addClassResourceCleanup in TagsExtTest
  * List auth domains v3 identity endpoint
  17.1.0
  * Convert cleanup with addClassResourceCleanup in endpoint test
  * Remove routers\_client from manager.\_create\_subnet
  * Remove \_create\_router in scenario.manager
* Fri Oct 27 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev197:
  * Add release notes for an queens intermediate release
  * Don't read config in cred\_factory module
* Thu Oct 26 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev193:
  * Fix test case for updating volume type extra specs
  * Refactor of \_check\_tenant\_network\_connectivity
  * Remove method get\_ipv6\_addr\_by\_EUI64
* Wed Oct 25 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev187:
  * Make test.py and clients.py as stable for plugins
  * Add proxy\_url to get\_credentials in auth
  * Cap compute floating IPs tests
* Sat Oct 21 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev182:
  * Disable testing of the v2.0 identity API
* Fri Oct 20 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev180:
  * Don't read config in Manager class definition
  * Rename scenario.manager.\_create\_port to create\_port
* Thu Oct 19 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev176:
  * Fix "import xx as xx" grammer
  * Move the object client to tempest.lib
  * Allow to specify user and project domains in CLIclient
  * Rename base.rebuild\_server to base.recreate\_server
  * Fix object\_client methods to accept headers and query param
  * Remove wrapper methods from object\_client
* Wed Oct 18 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev164:
  * Add config options to set proxy\_url
  * Remove scenario.manager.rebuild\_server
* Mon Oct 16 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev160:
  * Updated from global requirements
  * Do not set alias user\_client for specific client
  * Remove \_check\_remote\_connectivity in scenario.manager
  * Only attempt to detach an in-use volume during cleanup
  * Setup networking for live migration tests
  * Fix senario test: test\_swift\_acl\_anonymous\_download
* Thu Oct 12 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev149:
  * Update README to use stestr instead of testr for unit tests
  * Add release note for --load-list
* Wed Oct 11 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev145:
  * Move object storage container\_client to lib interface
  * Fix volume group test
* Tue Oct 10 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev141:
  * Remove \_project\_network\_cidr in security group tests
* Mon Oct  9 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev139:
  * Remove deprecated APIs from volume v2 volumes\_client
* Sat Oct  7 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev137:
  * Fix create container method
* Fri Oct  6 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev135:
  * Add compare header version to test images oneserver
  * Test size extend for an attached volume
* Wed Oct  4 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev132:
  * Remove unnecessary global variables
  * Remove internal helper \_default\_security\_group
  * Switch to use stestr for unit tests directly
* Fri Sep 29 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev126:
  * Fill microversion doc for implemented volume tests
  * Remove redundant volume check in nova\_volume\_detach
* Thu Sep 28 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev123:
  * Remove unnecessary client alias in AvailabilityZoneTestJson
  * Add test case for reset group snapshot status
  * Remove unnecessary assertIn
  * Add compare header version to create\_image\_from\_server helper
  * Fix create, update or delete container metadata method
  * Make list methods consistent for container client
  * Fix list\_group\_snapshots API in v3 group\_snapshots\_client
  * Remove unused RFCViolation
  * Add --load-list argument to tempest to accept a non-regex whitelist
* Wed Sep 27 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev105:
  * Delete a volume by Non-admin privileges
  * Move internal helpers to the class that uses them
* Tue Sep 26 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev101:
  * Add missing addCleanup of \_delete\_group\_snapshot
  * Remove deprecated skip decorators
  * Add test case for reset group status
  * Move identity\_utils to common.identity
  * Add unit tests for not overriding setUpClass
  * Add unit tests for test class fixtures
  * Prepare setup\_clients and resource\_setup
  * Prepare setup\_credentials as stable
* Fri Sep 22 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev85:
  * Fix the 'service' decorator path in doc
  * Remove unneeded resource\_cleanups in compute tests
  * Compute volumes via addClassResourceCleanup
  * Compute SG via addClassResourceCleanup
  * Compute servers via addClassResourceCleanup
  * Remove one-line helper \_delete\_volume
  * Updated from global requirements
* Sun Sep 17 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev72:
  * Move object storage account\_client to lib interface
  * Remove unused \_add\_router\_interface\_with\_subnet\_id helper
* Sat Sep 16 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev68:
  * Fix a typo of a missing letter
  * Updated from global requirements
  * Move data directory under doc/source
* Fri Sep 15 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev62:
  * Use glance client to delete an image
  * Compute images via addClassResourceCleanup
  * Prepare skip\_checks as stable interface
  * Make skip\_checks and setup\_creds safe
  * Prepare network\_resources as a stable interface
  * Make validation\_resources a stable interface
  * Stop implicit validation\_resources provisioning
  * Make resource\_cleanup stable
* Thu Sep 14 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev48:
  * Remove unnecessary executable permissions
  * Add a validation resources fixture
* Wed Sep 13 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev44:
  * Capture logs when running unit tests
  * Fix the redundant use of netaddr.IPNetwork
* Tue Sep 12 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev40:
  * Remove unnecessary class variable
  * Remove "test\_create\_with\_nonexistent\_volume\_type"
* Tue Sep 12 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev36:
  * Remove unused helper in RoutersTest
  * Remove useless check in AttachInterfacesTestJSON
* Sat Sep  9 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev32:
  * Remove unnecessary back slash
  * Make validation resources leak safe
  * Get cidr/mask\_bits according to ip\_version in resource\_setup
  * [DOC] Fix "Title level inconsistent" warning
* Fri Sep  8 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev24:
  * Fix addCleanup in AutoAllocateNetworkTest
* Thu Sep  7 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev22:
  * Only choose available compute node as migration dest
  * doc migration: update the doc link address
  * Fix addCleanup order in test\_volume\_list\_param\_tenant
* Wed Sep  6 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev16:
  * Use create\_volume wrapper for volume creation
  * Unskip test\_reassign\_port\_between\_servers
* Mon Sep  4 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev14:
  * Add cost time printing in wait\_for\_volume\_resource\_status
  * [Doc] Remove html\_use\_smartypants config in doc
* Sat Sep  2 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev11:
  * Add compare header version function to tempest.lib
  * Avoid using v3 volume clients when v3 is disabled
* Fri Sep  1 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev7:
  * Fix for resetting snapshot status
  * Fix the test case for showing host
  * Fix identity tests when domain specific drivers are enabled
* Thu Aug 31 2017 cloud-devel@suse.de
- Update to version tempest-17.0.1.dev2:
  * Add release notes page for v17
  17.0.0
  * Add release not to mark the start of Pike support
  * Fix volume microversion link in doc
  * check is\_admin\_available for force\_tenant\_isolation in test.py
  * Use skip\_checks if all testcases have same skip conditions
  * Test shared and non-shared external networks
  * Add detail specific fields check in list\_backups
* Wed Aug 30 2017 cloud-devel@suse.de
- Update to version tempest-16.1.1.dev245:
  * Use skip\_checks instead of skipUnless
  * Add params to upload\_volume command
  * Updated from global requirements
  * add detaches to attachment test
* Tue Aug 29 2017 cloud-devel@suse.de
- Update to version tempest-16.1.1.dev237:
  * Add support for IPV6 tests in tempest
  * Added unit tests for blacklist and whitelist
  * Do not use self.name for volume name field
  * Fix class name for test extensions
* Mon Aug 28 2017 cloud-devel@suse.de
- Update to version tempest-16.1.1.dev230:
  * [TrivialFix] Add bug reference to releasenote
  * Use networks floatingips client to associate fips
  * Fix for resetting volume status
* Thu Aug 24 2017 tbechtold@suse.com
- Update to version tempest-16.1.1.dev224:
  * Move test decorators to common
  * Use a non admin privileges for retyping a volume
  * TrivialFix for flake8 and docs build in tox.ini
  * Fix RemoteClient having bad default ssh\_shell\_prologue
  * Remove unnecessary schema check of ip address
  * Test nonexistent volume type extra\_spec name instead of id
  * [TrivialFix]Remove unnecessary value taking
  * [TrivialFix] Remove unused statements in compute tests
  * Add comments for test module of tempest.test.idempotent\_id
  * Updated from global requirements
  * Fix unit test that break isolation
  * Remove unused variable assignment
  * Remove unused assignment
  * Add compute test for ServerGroupAntiAffinityFilter
  * Resolve TODO in test: 'test\_available\_volume\_retype\_with\_migration'
  * Stop passing around dicts in validation resources
  * Add docstring for validation resources
  * Fix client usage in validation resources
  * Drop validation resources dependency from CONF
  * Update and replace http with https for doc links in tempest
  * [Trivialfix]Fix typos in tempest
  * Remove unnecessary class Inheritance
  * Remove unnecessary resource\_setup in DvrRoutersNegativeTest
  * Do not run test\_create\_server\_with\_scheduler\_hint\_group twice
  * Volume and group on same backend in update\_group
  * Do not create server in test\_list\_servers\_filter\_by\_exist\_host
  * Remove unused global variable
  * Do not print empty list in assertNotEmpty
  * Py3: Finish the python3 port
  * Refactor test\_user\_update
  * Mark credentials\_factory stable for plugins
  * Remove dependency to identity v2
  * Make sure test use the latest volume clients
  * Add Tests for Groups Volume APIs - Part 4
  * Move schedule filter check to compute module
  * Remove usage of credentials\_factory.AdminManager
  * Increase unit test coverage for v2 images client
  * Fix microversion doc for implemented microversion tests
  * Add Tests for Groups Volume APIs - Part 3
  * Fix verify config API version checks
  * Add unit test for volume availability zone client
  * Remove redundant comments in credentials\_factory.py
  * Add release notes for client registration changes
  * TrivialFix: Remove the unused import code
  * Add test for showing volume image metadata
  * Moved releasenotes from tempest package to proper location
  * Do not call another testcase in one testcase
  * Remove unnecessary assertIsNotNone check
  * Remove unnecessary checks already coverd in schema
  * Remove \_list\_assertions from test\_roles.py
  * Remove unnecessary asserting for 'id' in body
  * Fix broken api links in lib/services
  * Judge skip conditions in skip\_checks instead of in resource\_setup
  * Fix disable\_ssl\_certificate\_validation values if ca\_certificates file is defined
  * Remove unnecessary usage of instance variable
  * TrivialFix: Remove the unused import code
  * Unsupported 'message' Exception attribute in PY3
  * Updated firewalls deafult port reference to Newton
  * Make verify\_tempest\_config workspace aware
  * Fixed the broken links for api microversion
  * TrivialFix: Correct reST field lists in docstrings
  * Updated from global requirements
  * Try to register all service clients
  * Remove support for py34
  * Fix some nits in object storage clients release notes
  * Import data\_utils from tempest.lib.common.utils
  * Add Tests for Groups Volume APIs - Part 2
  * Revert "Remove tempest.common data\_utils"
  * Move object storage capabilities\_client to lib interface
  * Remove deprecated test.related\_bug decorator
  * Move object storage bulk\_middleware\_client to lib interface
  * Complete credentials\_factory docstrings
  * Add unit test for volume limits client
  * Add unit test for volume extensions client
  * Fix object storage capabilities client return value
  * Updated from global requirements
  * Add Tests for Create/Delete/Show/List Group Types
  * Add better docs on credential providers
  * Migrate the preprov creds module to tempest lib
  * Migrate the dynamic creds module to tempest lib
  * Ensure test for Neutron GET / uses right URL
  * [DOC BLD FIX] Correct reST field lists in docstrings
  * Fix object storage bulk middleware client return value
  * Remove creds providers dependency from clients
  * Added return statement to retype\_volume in v2 volumes\_client
  * Add volume backed instance coverage to API tests
  * Fix account generator unit tests
  * Make credentials\_factory a bit nicer
  * Update the documention for doc migration
  * Unix style line ending
  * test\_boot\_server\_from\_encrypted\_volume\_luks skip condition
  * Add unit tests for volume and snapshot manage clients
  * Updated from global requirements
  * Cleanup the orchestration client init and attr
  * Remove unused clients from testcases
  * Move multi-nic tests to dedicated module
  * create test to verify catalog standardization
  * Generic method for creating a volume snapshot
  * Handle volume API version enablement
  * Fix instance\_action\_events response schema for finish\_time and result
  * Using fixtures instead of deprecated mockpatch module
  * Refactor volume clone tests
  * Remove unused tenant\_cidr from test\_routers.py
  * Use cls instead of self in classmethod
  * Remove unused LOG from clients.py
  * Add flag to generate tempest plugin list
  * Doc: fix markups, capitalization and add 2 REVIEWING advices
  * Add a page for release 16.1 to release notes
  * Added script for doing tempest plugin sanity
  * Add 'params' argument to v2 list\_backups API
  16.1.0
  * Add release notes for an intermediate release
  * Supplement unit tests for volume transfers client
  * Extra compute services\_client API endpoints
  * Updated from global requirements
  * Dynamic creds does not support create subnet with ipv6
  * Add test case for update volume backup
  * Add test for showing snapshot metadata item
  * Fix check\_service\_client\_function doc typo
  * Add test for showing volume metadata item
  * Move base\_client from volume.v3 to volume
  * Switch from oslosphinx to openstackdocstheme
  * Boot server from encrypted volume
  * Fix import error "No module named six.moves" for plugin sanity job
  * Update volume-status waiter for new cinder attach
  * Add response assertions and remove unused variables in volume tests
  * Added --rmdir flag to workspace remove
  * Pause resource cleanup
  * Fix image deletion checks after unshelve server
  * Tidy up releasenotes
  * Add token related API to Keystone v3-ext/OS-OAUTH1 client
  * Fix no attribute 'urlopen' error in python3
  * Add negative test for live migration
  * Adds \*\*params to v3 list\_endpoints
  * Enhance v3 list\_services to test filtering by service type
  * Updated from global requirements
  * Add Scheduler Stats client unit test
  * Handle the case that RFP negotiation message arrived early
  * Add api-ref url for compute list\_baremetal\_nodes
  * Adding and removing bytes\_body param from unit tests
  * Add network tags-ext API tests
  * Tests for Nova instance diagnostics (microversion v2.48)
  * Fix skip checks in volume and snapshot manage tests
  * Add api-ref urls for some volume v2 APIs
  * Xenapi: Fix tempest for xenserver device tagging
  * Fix check\_service\_client\_function mock\_args bug
  * Add Quotas client unit tests
  * Fix auto allocate network cleanup
  * Wait for server deletion if validation setup fails
  * Enhance tempest client for keystone v3 token APIs
  * Added tests for Nova microversion v2.47
  * Implement tempest client for keystone v2 token APIs
  * Save state of cloud before running tempest
  * create a non-admin token validation test
  * Add expect\_response\_code to base network client
  * Add Capabilities Client unit tests
  * Updated from global requirements
  * Fix test\_volume\_migrate\_attached to retype as admin
  * Add Floating IPs client unit tests
  * Fixed project lists for retrieving tempest plugins
  * Remove unused variables from api tests
  * Add Metering Label Rules client unit tests
  * Add Metering Labels client unit tests
  * Add Extensions client unit tests
  * Add Ports client unit tests
  * Verify config support cinder on subpath
  * Fix for unmanage and manage snapshot
  * Add network tags client
  * Use urllib2 instead of requests in tempest generate plugin list
  * ported tools/\*.py scripts to python3
  * Update "test\_unmanage\_manage\_snapshot" test to support some params
  * Do not use any() to check whether a list is empty
  * Replace assertGreaterEqual with assertNotEmpty
  * Update "create\_server" to wait until status is 'ACTIVE'
  * Update server nic handling for LXD style nic names
  * Fix html\_last\_updated\_fmt for Python3
  * Replace assertions with more specific ones
  * Add notes for network and identity in get\_service\_list
  * Remove unnecessary wait\_for\_volume\_resource\_status
  * Fix 4 bytes utf8 char test comment for create images
  * Use @test.services instead of skipUnless
  * Test coverage for network v2 security group rules client
  * Test coverage for network v2 security groups client
  * Use Neutron (if available) to create floating IPs for validation
  * Remove unused variables from scenario tests
  * Remove TODO comment
  * Fix minor header wordings
  * Use assert(Not)Empty,IsNotNone instead of assert(Not)Equal,GreaterEqual(0, len(.
  * Unit test for asserting correct url in list\_services
  * Fix DeprecationWarning in test\_volume\_pools.py
  * Add server group API schema for microversion 2.13
  * Updated from global requirements
  * Use create\_volume classmethod
  * Fix broken api urls in TypesClient
  * Add server param in manager.get\_remote\_client
  * Fix url in list\_services
  * Reuse v2 extension client for cinder v3
- run_tempest.sh got removed upstream
* Fri Dec 16 2016 tbechtold@suse.com
- Update to version tempest-13.0.1.dev422:
  * Do not create volume in resource_setup for test_volume_reset_status
  * Remove unused client in SecurityGroupRulesNegativeTestJSON
  * Use base.delete_server in base.rebuild_server
  * Use base.delete_server in ServersTestJSON
  * Fix a few Python 3.x issues
  * Separate capabilities service method from account_client
  * Add test.related_bug() to know launchpad bug reports
  * Make identity v3 domains_client use **kwargs
  * Set auth in clients before they are used
  * Add namespace property unittest
  * Use base.create_volume in VolumesTestJSON
  * Remove unused client in setup_clients
  * Docs: Add the remote tag to the badge image
  * Network test: rework the service types/service providers tests
  * Correct improper comment
  * tempest/test.py: make set_validation_resources() more idiomatic
  * Use wait_until in create_test_server to wait for server ACTIVE
  * Correct tempest reraising of exception
  * Add status_code to RESTful exceptions
  * Honour discoverability feature flag in swift tests
  * Add extra unit tests for base_url
  * Remove the Auto Tests Generators
  * Tox.ini: removed an outdated code comment
  * Tox: Hacking: enable extensions H106 and H203
  * Remove unused admin_hosts_client
  * Add server_group in default_quota_set
  * Correct variable usage error in test_get_hypervisor_uptime
  * Replace str(uuid.uuid4) with uuidutils.generate_uuid()
  * Modify incorrect import path
  * Add get metadata schema test methods
  * Remove unused client
  * Change personality inject path to /
  * Add sleep(2) when try to delete a container
  * Use different file content to test max_number_personality_files
  * Correct boundary value test in ImagesOneServerNegativeTestJSON
  * Remove prepare_instance_network in ImagesOneServerNegativeTestJSON
  * Rename test_delete_image_id_is_over_35_character_limit
  * Write a couple of test cases together
  * Add a test for attaching 2 volumes to a server
  * Make common->compute->shelve_server param more clear
  * Add resource clean for tests
  * Add server group limits in test_absLimits_get
  * Remove unnessary assertIsNotNone
  * Fix unit-test test_user_messages file name
  * Use TempestException from tempest.lib
  * Added bindep.txt to the project
  * Remove _is_true() from test_volumes_actions.py
  * Specify snapshot size when creating volume
  * Add possibility to pass prefix before cli command
  * Remove setup_client method
  * Add 'Negative' to negative test class names
  * Rename "VolumesCloneTest" class name to "VolumesV2CloneTest"
  * Add test create volume from bootable volume
  * Add resize_server in compute.base
  * Fix compute test_attach_volume
  * Remove old v3 volume services library and use lib/service for v3
  * Create two new clients under tempest.lib libary
  * Fix typo in documentation
  * Show team and repo badges on README
  * Minor fix in role_assignments_client docstring
  * Remove an obselete msg from then optimize a router test case
  * Updated from global requirements
  * Move role_assignments_client to tempest lib
  * Use names containing "non-existing" as non-existing resource names
  * Do not use instance variable in FloatingIPsNegativeTestJSON
  * Replace directly import of logging with import oslo_log
  * Remove CONF.volume_feature_enabled.bootable
  * Rename testcase names with 'with_out' to 'without'
  * Add namespace properties client and tests
  * Add deprecated_reason for nova_cert
  * Integration tests for device role tagging
  * Add wait_for_server_termination in test_server_basic_ops
  * Updated API ref link as single line which is more readable
  * Add hypervisor_type option
  * Make the parameter 'device' optional
  * Remove skipException for volume creation failure
  * Remove negative_rest_client
  * Use names containing "invalid" or "nonexistent" as invalid name
  * Make Identity v2 service clients as available  module
  * Check volume and minimum disk sizes to create volume
  * Cinder absolute-limits tests
  * Improved Cinder snapshot tests
  * Remove unused client in ServerMetadataTestJSON
  * Remove meaningless assignment
  * Use call_and_ignore_notfound_exc to cleanup floating-ip-bulk
  * Move list_hosts to resource_setup in test_hosts_negative
  * Add missing volume snapshot skip
  * Do not remove server_groups from default_quota_set
  * Use assertIs(Not)None to check for None
  * Add api ref link in TenantUsagesClient
  * Fix ref link in volume v1 service clients
  * Fix volume_create to use shared function with a cleanup
  * Delete duplicated dvr tests
  * Bump hacking version in test-requirements.txt
  * Use the correct path of InvalidConfiguration
  * Typo fixing
  * Move wait_for_interface_status to waiters
  * Wait for FIP status to get to DOWN in test_router_rescheduling
  * Improve error message on volume tests failure
  * fix bulk service name
  * _log_console_output missing space
  * Updated from global requirements
  * Fix glance create image
  * Use more specific asserts in tests
  * Get rid of useless tenant_id attribiute
  * _log_console_output do not raise NotFound
  * Move cred_client to tempest.lib
  * Update volume client class description
  * Updated from global requirements
  * Add connectivity check test for migration
  * Validate power_state enums in compute API response schema
  * compute/images/test_images_oneserver: don't share resources
  * Updated from global requirements
  * Fix cinder message-client naming to volume_v3_messages_client
  * Delete TimeoutException in tempest/exceptions.py
  * Require l3-ha extension for test_centralized_router_update_to_dvr
  * Add negative tests about update-volume API
  * Fixing 'test_verify_created_server_ephemeral_disk' test
  * Do not have heat to connect to external service
  * Use InvalidCredentials exception from correct path
  * Use random name in network common function
  * Remove services/volume/{v1,v2} directories
  * Remove a redundant dictionary
  * Fix a docstring typo in manager.py
  * Remove unnecessary function _create_multiple_servers
  * Pop name from volume.base.create_server
  * Boot a server from a non-bootable volume
  * Use assertGreater(Equal) over assertTrue
  * Make the non ha router usage explicit in a dvr test
  * Fix race in test_networks.py: don't try to get a possibly-deleted network
  * Correct a scheme example error from fake netutron versions client
  * Use is_scheduler_filter_enabled for ServerGroupAffinityFilter
  * Add random name in scenario.manager.create_server
  * [TrivialFix] Replace 'assertTrue(a in b)' with 'assertIn(a, b)'
  * Use random name in common function
  * Use random name in volume.base.create_snapshot
  * Use base.create_test_server_group to create server group
  * Define image status enums for compute proxy API schema
  * Pass username on v3 token issue
  * Move some network tests from Neutron to Tempest
  * Add missing tests for the image v2 API
  * Use assertGreater(Equal) over assertTrue
  * delete list_all_container_objects in the container_client
  * Updated from global requirements
  * Add _error_checker() call on versions_client
  * Remove unused arguments from _error_checker()
  * Use assertGreater(len(x), 0) over assertTrue(len(x) > 0)
  * Revert "Skip unstable v6 scenario tests"
  * Repalce to "tempest account-generator"
  * Don't rely on testtools.tests
  * Remove the Stress framework
  * Use rand name in common function in scenario tests
  * Use common function create_volume to create test volume
  * Add test_volumes_list functions in test_volumes_list.py
  * Use random name in network common function
  * Correct image's random name
  * Remove unnecessary function _create_multiple_servers
  * Image cleanup is missing in test_create_delete_image
  * Remove NetworksIPV6TestAttrs duplicate tests
  * Add unit tests for volume quotas_client
  * Add unit tests for volume snapshots_client
  * Add a generic method for backup creation
  * Test case with list-instance-actions for deleted server
  * Add existing volumes when using pre-provisioned credentials
  * Allow for wait in _restore_password
  * Trivial: Remove redundant variable
  * Fix Release Notes index page title
  * neutron: added test case to check connectivity using MTU sized frames
  * Scenario: server_basic_ops: use regular variable (not instance var)
  * Scenario: object_storage_basic_ops: move and update test description
  * Add deprecated code review guideline
  * test_schedule_to_all_nodes should choose available nodes
* Wed Oct 19 2016 tbechtold@suse.com
- Update to version tempest-13.0.1.dev86:
  * Set random name in common function create_server
  * Remove unnecessary name definition
  * Fix a typo in test_security_groups.py
  * Remove testscenarios denpendency
  * Remove one-line function in test_volumes_actions
  * Fix a typo in test_networks.py
  * Move volume service clients under tempest.lib
  * Skip test_volume_backed_live_migration unconditionally
  * Revert an accidental error modification of config item help message
  * Deprecate nova api extensions config option
  * Fix wording for python3.4 section in the readme
  * Stop using subprocess for testr init in tempest init
  * Improve error reporting when workspace not registered
  * Move InvalidConfiguration exception to tempest.lib
  * Use lib version of data_utils in dynamic creds
  * Move cred_provider abstract class to tempest lib
  * Remove CONF usage from dynamic_creds module
  * Remove the NegativeAutoTest Framework
  * waiters.py: raise BackupException defined in tempest/lib
  * Use Cinder v2 by default in scenario tests
  * Correct 'list index out of range' in FloatingIPDetailsTestJSON
  * Add test list namespace function
  * Correct 'list index out of range' error in dhcp agent test
  * Isolate change_server_password to use its own server
  * Remove unnecessary name definition
  * Add port parameter to ssh Client
  * Use common func create_volume in test_volumes_actions
  * Remove unused func _detach
  * Correct improper assert judgement
  * Remove redundant assert judgement
  * Remove unnecessary wait-for-volume-available
  * Add list the primary tenant
  * Add negative tests for deleting attached volume
  * Updated from global requirements
  * Use a common method for is a router interface
  * Rename reno files of 13.0.0
  * Fix the 13.0.0 newton release note
  * Remove duplicate python-subunit from test-requirements.txt
  * Add v13.0.0 release note page
  * Enable release notes translation
  13.0.0
  * Add release notes for start of Newton support
  * Add unit tests for encryption_types_client
  * Remove meaningless volume negative test
  * Only call register_service_clients if there are clients
  * Remove Sahara tests from Tempest
  * Updated from global requirements
  * Clarify the guideline of negative tests
  * Moving scenario docstring under the relevant test method
  * Remove a redundant image_id variable
  * Re-use common methods in ServerRescueNegativeTestJSON
  * Re-use common methods in test_rebuild_server_with_volume_attached
  * Re-use common methods in test_delete_server_while_in_attached_volume
  * Re-use common volume create/attach methods in test_iscsi_volume
  * Add compute API admin test for swap volume
  * Switch unit test tox jobs to use ostestr
  * Fix docstrings in Tempest REST client for Ironic
  * Add link for Unset keys and update some links in qos_client
  * Permission changes: Python file should be 0644 not 0775
  * Migrate backups clients to tempest.lib
  * Add a test for revert cold migration
  * Adding a new option CONF.network.dvr_extra_resources
  * Add 'code-block' and revise tab
  * Reviewing guideline: ask for CRD when new test+feature flag
  * Remove over-comment
  * Trivial: Delete a definition that is not needed
  * Updated from global requirements
  * Fix typo in the file
  * Add inherited role assignments tests
  * Fix tempest init inconsistency when it fails
  * Update hotplug test description
  * Docstrings should not start with a space
  * Correct a misleading in docstring
  * Fix a few grammatical errors in docs
  * Correct several typos
  * Updated from global requirements
  * Add a test for cold migration
  * Remove redundant links to clients
  * test_images_oneserver - use the addCleanup mechanism
  * Remove misleading arguments
  * Add more swift container negative tests
  * Introduce a new tox target that checks requirements.txt
  * Fix compute test_agents tests
  * Change into staticmethod
  * Move wait_for_qos_operations method to common.waiters
  * Move wait_for_backup_status function to common.waiters
  * Add test to get images by owner
  * Fix assert for public networks with multiple subnets
  * Define v2 encryption_types_client as library
  * tempest-cleanup can only be invoked as tempest cleanup
  * Use ConfigParser instead of SafeConfigParser
  * Reordering tests under the approprite directories
  * Adding update backups quota
  * Fallback to creds provider for fixed IP network if no network_for_ssh
* Wed Sep 28 2016 cloud-devel@suse.de
- Update to version tempest-12.2.1.dev177:
  * Wait for floating_ip to detach from server after deletion
  * test_list_servers_by_admin(specified_tenant) for preexisting servers
  * Add prefix "$" for command examples
  * standardize release note page ordering
  * Remove a redundent variable
  * Fix LOG.warn to LOG.warning
  * Fix subunit-trace output with tempest run
* Tue Sep 27 2016 cloud-devel@suse.de
- Update to version tempest-12.2.1.dev163:
  * Skip some tests if security-group extension is disabled
* Mon Sep 26 2016 cloud-devel@suse.de
- Update to version tempest-12.2.1.dev161:
  * Remove residual package
* Mon Sep 26 2016 cloud-devel@suse.de
- Update to version tempest-12.2.1.dev159:
  * Avoid local variable referenced before assignment
  * Delete Savanna element in client list
  * remove unused statement
  * Scenarios: remove redundant call to `resource_setup()`
* Sun Sep 25 2016 cloud-devel@suse.de
- Update to version tempest-12.2.1.dev151:
  * Remove invalid assertions for 304 resp
* Sat Sep 24 2016 cloud-devel@suse.de
- Update to version tempest-12.2.1.dev149:
  * Move test_snapshot_list_* tests to new file
  * Updated from global requirements
  * Trivial: group import statement in client.py
  * Don't include openstack directory in exclude list for flake8
  * Container Services underscore in metadata key translate to dash
* Fri Sep 23 2016 cloud-devel@suse.de
- Update to version tempest-12.2.1.dev140:
  * Remove duplicated judgement
* Thu Sep 22 2016 cloud-devel@suse.de
- Update to version tempest-12.2.1.dev139:
  * Migrate V1 and V2 qos service to tempest lib
  * Fix missing serial option of tox full-serial target
  * Rename renos of 12.1.0
  * Rename renos of 10.0.0 and 11.0.0
  * Deprecate method get_ipv6_addr_by_EUI64
  * Split base snapshots_client into v1 and v2
  * Rename test_list_servers_filter_by_server_status
* Wed Sep 21 2016 cloud-devel@suse.de
- Update to version tempest-12.2.1.dev125:
  * Remove image v1 test_delete_image_with_invalid_image_id
  * Fix typo in data_utils.py
  * Revert "Fix of verify_glance_api_versions"
  * Define v1 encryption_types_client as library
  * Rename renos of 12.2.0
  * Fix with using oslo_serialization base64 module
  * Scenario: test_minimum_basic: remove useless function
  * Replace volume's "test" name with classname as prefix
* Tue Sep 20 2016 cloud-devel@suse.de
- Update to version tempest-12.2.1.dev109:
  * Use other item instead of security_group in network-quotas test
  * Fill name param in create_test_server
  * Switch tox to use tempest run and deprecate bash runners
  * Define the volume types_client as library
  * Fix credential client to return raw response
  * Validate floating IP in server['addresses'] scenario
  * Fix of verify_glance_api_versions
* Sat Sep 17 2016 cloud-devel@suse.de
- Update to version tempest-12.2.1.dev97:
  * Add some params docstring to create_server
  * Remove _setup_network_and_servers() in TestNetworkAdvancedServerOps
* Fri Sep 16 2016 cloud-devel@suse.de
- Update to version tempest-12.2.1.dev93:
  * Add config option to create networks with port_security_enabled
  * Always wait on server delete
  * Update skip message in overlimit testcases
  * Modify use of assertTrue(A in B)
  * boot into a network that has "port_security_enabled=False"
* Thu Sep 15 2016 cloud-devel@suse.de
- Update to version tempest-12.2.1.dev82:
  * Remove unnecessary resource_setup()
  * Ignore deb-* packaging repos in the plugin list
  * Fix the docstring of _default_security_group
  * Remove unnecessary __init__.py of identity v2
  * Update Available para link of image v1 client
  * Remove non-locking accounts from the config guide
* Tue Sep 13 2016 cloud-devel@suse.de
- Update to version tempest-12.2.1.dev71:
  * Remove tests/fake_auth_provider
  * Use local variable for volume instead of instance one
  * Add description to the help of enable_instance_password
  * Update tempest init help message
  * Remove auth_request as no used
  * Move method to v2 volumes_client
  * Use api_extensions to decide security_group type nova used
  * Use an instance method instead of class method
* Mon Sep 12 2016 cloud-devel@suse.de
- Update to version tempest-12.2.1.dev55:
  * Define v3 credentials_client as library
* Sun Sep 11 2016 cloud-devel@suse.de
- Update to version tempest-12.2.1.dev53:
  * py3: Miscellaneous fixes
  * Define v3 trusts_client as library
* Sat Sep 10 2016 cloud-devel@suse.de
- Update to version tempest-12.2.1.dev49:
  * Move v3 inherited_roles_client to library interface
  * Update Available params of image
  * Added logic to validate storage policy info
* Fri Sep  9 2016 cloud-devel@suse.de
- Update to version tempest-12.2.1.dev44:
  * Update Available para link of keystone v3 client
  * Move v3 roles_client to library interface
  * Define separate inherited_roles_client for inherited roles
  * Update Available para link of network client
  * Remove base_types_client for the reability
* Thu Sep  8 2016 cloud-devel@suse.de
- Update to version tempest-12.2.1.dev37:
  * Define v3 identity_client as library
  * Move 3 volume methods to v2 volumes_client
  * Separate encryption_types_client from types_client
  * Don't create network resources for identity tests
  * Define the v3 Users Client as a library
  * Define v3 Groups Client as library
  * Delete duplicate if judgment
  * Use testcase name as prefix of resource name
  * Narrow assertion in attach/delete volume test
  * Update the links to api-ref of network
  * Fix checks for content length in object storage tests
* Wed Sep  7 2016 cloud-devel@suse.de
- Update to version tempest-12.2.1.dev18:
  * Add skip logic for admin cred in test_auto_allocate_network
  * Make identity v3 roles_client use **kwargs
  * Define v2 identity_client as library
  * test_list_servers_by_admin for preexisting servers
  * Count volumes vs partitions and remove hard-coded expected result
  * Update user and tenant client's Available params link
* Tue Sep  6 2016 cloud-devel@suse.de
- Update to version tempest-12.2.1.dev9:
  * Remove unnecessary resource_cleanup/setup
  * Move wait_for_qos_operations into base volume test
  * Remove get_attachment_from_volume()
  * Remove the default size in volumes_client
  * Remove unused global variable from VolumesV1NegativeTest class
  * Use 'OS-EXT-SRV-ATTR:host' directly
* Mon Sep  5 2016 tbechtold@suse.com
- Rebased patches:
  + install_absolute.patch (manually)
* Mon Sep  5 2016 tbechtold@suse.com
- Update to version tempest-12.2.1.dev3:
  12.2.0
  * Move `call_until_true` to tempest/lib
  * Fix doc build if git is absent
  * Remove unused methods from volumes_client
  * Define v3 projects_client as library
  * Add omitted blank space to assert_msg
  * Use quota_set instead of default_quota_set
  * Remove a word 'smoke' from some scenario tests
  * Add volume clone flag to clone tests
  * Add doc section on expectations of clean tenants
  * Adding testcases for metadata def resource types
  * Fix MismatchError in test_host_name_is_same_as_server_name
  * Define v3 services_client as library
  * Add a space between super's and setUpClass
  * Use expect_empty_body flag
  * Define v3 regions_client as library
  * Remove the update_object() in object_client
  * Move volume-type-access methods to volume v2
  * Skip admin floating IP tests if router extension is disabled
  * Remove expected_success check in images_client
  * Add a release note link on README
  * Fix docstrings to match with method arguments
  * Remove unused config.CONF
  * Revert "skip get-me-a-network tests"
  * Deprecate meaningless TYPE
  * Clean imports in code
  * Exclude gateway_ip of subnet in get_unused_ip_addresses
  * Delete unuesd function arguments in rest_client
  * TrivialFix: Remove cfg import unused
  * skip get-me-a-network tests
  * TrivialFix: Remove logging import unused
  * Fix mutliple attach/detach issue
  * Add using dash options instead of underscore
  * Remove thirdparty from tox.ini
  * Lower the aes-xts-plain64 key_size to 256
  * Create resources using wrapper utility
  * Improve test_update_image_metadata testcase
  * Update volume type details
  * Fix OverLimit's message
  * Add admin list_servers test with invalid_status
  * Fix exec_command to hang indefinitely
  * Call addCleanup(delete_server) immediately after resize server
  * Fix parameter receive
  * Remove unnecessary setUp()
  * remove unnecessary call in test_delete_container
  * Make args of types_client same
  * Fix test_volume_services testcase
  * Revert "Move dscv and ca_certs to config section service_clients"
  * Remove an unused function in object_client
  * Use classname as prefix of volume name
  * Use cls in class method instead of self
  * Scenario: remove the `addCleanup_with_wait` helper method
  * Add compute API tests for 'get-me-a-network'
  * Class Credentials not define __ne__() built-in function
  * Add existing volumes when using pre-provisioned credentials
  * Delete no need definitions
  * Use cls in classmethod instead of self
  * Remove unnecessary str() from some clients
  * Remove skip statement for bug 1450859 is fixed
  * Fix test_shelve_volume_backed_instance
  * Remove useless parenthesis
  * Fixed net_id key evaluation for net['id']
  * Remove a redundent resource_cleanup method
  * Remove the test_upload_large_objects negative test
  * Improving test_volumes_get testcase
  * Add missing config file read to tempest init
  * Adds to verify_cinder_api_versions api_v3 check
  * Remove unnecessary str() from base_types_client
  * Fixed manager.py to support multinode test on vnic_port
  * Remove unnessary delete_volume in test_volumes_list
  * Define volume quotas_client as library
  * Remove base_quotas_client for the reability
  * Fix network_for_ssh config option help
  * Fix reference to nonexistent ssh_connect_method in config help
  * change nova_cert config to default False and deprecate it
  * skip test_connectivity_between_vms_on_different_networks
  * Fix manager->get_auth_provider interface
  * Move dscv and ca_certs to config section service_clients
  * Configure stable service clients via the registry
  * Define volume services_client as library
  * Define volume hosts_client as library
  * Remove unnecessary str() which was for XML
  * Don't load non json body
  * Migrate service_clients to tempest.lib
  * Fix tempest and available modules
  * Updated from global requirements
  * Remove a redundant wait_for_backup_deletion()
  * Make identity v3 users_client use **kwargs
  * Make identity v3 credentials_client use **kwargs
  * Define volume availability_zones_client as library
  * Define volume extensions_clients as library
  * Fix notes which differnt from actual parameters
  * Add a TODO to remove Ironic related workaround
  * Optional setting service client on factory
  * Make identity v3 services_client use **kwargs
  * Make identity v3 groups_client use **kwargs
  * Remove deprecated Javelin CLI utilities from Tempest
  * Add : to docstring of service_clients
  * Fix. Do not create port if vnic_type defined and port is passed
  * Run attach/detach volume tests even without ssh
  * assertEqual can be used instead of assertListEqual
  * Set timeout value in urllib3.poolmanager.PoolManager
  * Updated from global requirements
  * Update the links to api-ref of network
  * Remove the wapper method show_quota_usage()
  * Remove unused TYPE from base_quotas_client
  * Remove base_services_client for the reability
  * Remove base_hosts_client for the reability
  * Skip test_reassign_port_between_servers until fixed
  * Delete unused parameters
  * Do not use $ in regex
  * Modified into a more appropriate function
  * Modify a spelling mistake
  * Delete no meaningful definition
  * Remove base_availability_zone_client for the reability
  * Remove base_extensions_client for the reability
  * Minor change to comment
  * Migrate image client group to client factory
  * Migrate network client group to client factory
  * Migrate compute client group to client factory
  * Register Tempest clients via the new interface
  * Service Clients registration interface for plugins
  * Fix README
  * Replace OpenStack LLC with OpenStack Foundation
  * Add available params in compute clients' comment
  * Add volume type description support
  * Do not use $ in OS user password
  * Use skip_checks in test_snapshot_pattern
  * Deprecate run_tests.sh
  * Fix typo about message of exception
  * Add server_id in exception ServerUnreachable
  * Skip unstable v6 scenario tests
  * Fix release notes around
  * Increase size of subnet allocation pool
  * Define v3 policies_client as library
  * Updated from global requirements
  * Define v3 endpoints_client as library
  * Fix subunit-describe-calls name of usage
  * py3: Replace map/filter with a list comprehension
  * Modify comment which does not conform to code
  * Introduce the ClientsFactory
  * Add available params in volume clients' comment
  * Reverse order of get_unused_ip_addresses
  * Remove unused LOG to keep code clean
  * Add new live_migration case to support block_migration=auto
  * Remove DataGenerator from the dentity base
  * Remove DataGenerator from admin V3 identity tests
  * Remove DataGenerator from admin V2 identity tests
  * Add python 3.5 classifier and venv
  * Fix typo in tempest/run help document
  * cinder backup reset status
  * Use skip_checks instead of skipUnless in TestShelveInstance
  * Add a test for attach/detach port on multiple servers
  * Add sync to avoid the loss of pub key data
  * Fix typo in Test Removal Procedure doc
  * Correct reraising of exception
  * Requirements.txt: remove pyOpenSSL
  * Removes explicit looping over dict .keys() method
  * Add available params in metering labels client's comment
  * Add available params in ports client's comment
  * Add available params in neutron security group client's comment
  * Updated from global requirements
  * Don't enable DHCP on floating IP subnet tests
  * Add missing validation to test_delete_saving_image
  * Add available params in network clients' comment
  * Add available params in subnet pools client's comment
  * Add available params in neutron security group rule client's comment
  * Add available params in baremetal client's comment
  * Add available params in identity v2 client's comment
  * Remove unused LOG
  * Add available params in neutron float ips client's comment
  * Add documentation for glance api
  * Factor up (most) CONF value in clients.Manager
  * Check network_data info in config drive tests
  * Update docstring for create_test_server
  * Remove the unused tenant and user option in cleanup
  * Moving backup test under non admin directory
  * Remove white space between print and ()
  * Cinder get-capabilities tests
  * Add available params in networks client's comment
  * Add available params in subnets client's comment
  * Tempest: Fixed a typo
  * Fix minor details in README
  * Update quickstart for revised temepst init setup
  * Making delete_on_termination configurable
  * Extend server schema for extended volume attribute
  * Fix test_project_create_with_parent
  * Updated from global requirements
  * Disable file injection by default
  * Add purge flag in image_meta_to_headers
  * Delete dynamic tenant correctly when _cleanup_default_secgroup fails
  * Cleanup tempest quickstart
  * Remove duplicated identity v2 clients
  * Fix teardown of the identity api
  * Use find_test_caller in test_utils instead of in misc
  * Add basic tempest run instructions to the quickstart
  * Add support for specifying a config file to tempest run
- Remove test_container_sync.patch . No longer needed.
* Thu Jun 23 2016 abel.navarro@suse.com
- Added patch test_container_sync.patch
  * https://review.openstack.org/#/c/328319/
* Thu Jun 23 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev285:
  * Service client modules in various services  __init__
  * Service client modules in object-storage __init__
  * Service client modules in image __init__
  * Service client modules in volume __init__
  * Add available params in set metadata
  * Image metadata for volume
  * Service client modules in identity __init__
  * Update identity v2 users_client methods name
  * Make `tempest init` working dir an abspath
* Wed Jun 22 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev271:
  * Correct some misspelt words in print messages
  * Service client modules in network __init__
  * Service client modules in compute __init__
  * Remove unused LOG from images_client
  * Return ResponseBody object from delete_role
  * Make identity v2 roles_client use **kwargs
  * Change hostname_equals_servername to get_hostname
* Tue Jun 21 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev259:
  * Generic "delete volume" method
  * Define v1 image_members_client as library
  * Make identity v2 tenants_client use **kwargs
  * Add a response schema for "log" attribute
* Sun Jun 19 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev251:
  * Adding/fixing docstring to _create_creds function
  * Add simple test for Neutron GET /
* Sat Jun 18 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev247:
  * Make identity v2 user_client use **kwargs
  * Make identity v2 service_client use **kwargs
  * Add IPv6 rule creation to validation resources
  * Add tests for Cinder user messages v3 API
  * Add operator role to heat stack owner
  * Consider pre-existing VMs when testing server list
  * Clarify "data" arg in create/update_image()
  * Move get_image_meta_from_headers from images_client
* Fri Jun 17 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev231:
  * Fixes port.id bug added with 777a307b3c9f4284facf081e6b951b5755333adf
  * Cleanup exceptions in tempest
* Thu Jun 16 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev228:
  * Add InvalidIdentityVersion in lib.exception
  * Remove neutron OO wrappers
  * Rename mathods of v1 image_members_client
  * Add available params in identity client's comment
* Wed Jun 15 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev220:
  * Quota usage after volume transfer
  * Remove the test path of image service
  * Add image API version to the reno
  * Remove unnecessary setUp()
  * Define v2 endpoints_client as libarry
  * Make endpoints_client use **kwargs
  * tempest: use host instead of hypervisor for aggregate test
  * Make --concurrency not required in account_generator cmd
  * Add available params in attach_volume's comment
  * Define v2 images_client as library
  * Add missing tests for the identity v3 API
* Tue Jun 14 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev199:
  * Use is_valid_ipv4 from oslo.utils
  * Add unit test coverage for account generator
* Sun Jun 12 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev195:
  * Stop passing TestResources to Managers
* Sat Jun 11 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev193:
  * Fix dsvm typo to dscv
  * Fix rendering of account generator utility authentication table
  * Fix docs warnings of auth
  * Fix the reno format of image-clients-as-library
  * Disable SmartyPants for docs
  * Add tempest run command
  * Count partitions starting with sd prefix
  * Use scope in v3 identity client
  * test_aggregates should choose available compute node
* Fri Jun 10 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev175:
  * Move reno of add-tempest-workspaces
  * Define _set_network_clients
  * Define _set_image_clients
  * Remove unused return value from take_action
  * Define image_members_client of image v2 as library
  * Rename image members clients
  * Define 3 image clients as libraries
  * Add unit tests for glance v2 service clients
  * Separate resource_types_client from images_client
  * Allows specifying a name for a particular endpoint
  * Cleanup some small issues in the microversion testing doc
  * Fix cinder volume nameing for admin
  * Remove use_default_creds from preprov creds
  * Fix the v2 image client variable name
  * Centralized Workspaces
  * Make missing global config dir not fatal in tempest init
  * Not to create security group when security_group ext is disabled
* Thu Jun  9 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev141:
  * Separate Image v1 members client
  * Separate schemas_client from v2 images_client
  * Cleanup wording and section for remote access config doc
  * Separate namespaces_client from v2 images_client
  * Separate Image v2 members client
* Wed Jun  8 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev132:
  * Fixed a Typo
  * Account generator for identity v3
  * Tempest image clients use version in URL
  * Remove unused _get_file_size()
  * Check which glance client version to use
  * Define routers_client as library interface
  * Move comptue base test to common dir
  * Remove unnecessary __init__()
* Tue Jun  7 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev116:
  * Remove tempest/tests/services/compute path
  * Updated from global requirements
  * Return 'DOWN' ports when Ironic enabled
  * Remove delete_extra_routes()
  * Remove update_extra_routes()
  * Remove GET ops from update_router()
  * Introduce new helper: call_and_ignore_notfound_exc()
  * Remove the Glance HTTP client. Use the common Rest Client instead
  * Add missing test for the object storage v1 API
* Sat Jun  4 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev100:
  * Increase test coverage on preprov creds
* Fri Jun  3 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev98:
  * Make username and project use same random ID
  * Fix volume backup import test
  * Change "$>" to "$" as CLI prompt
  * Fix Tempest testing way on the doc
  * Remove integrated dashboard tests
  * Add hacking rule to enfore no config in tempest.lib
  * Keep py3.X compatibility for urllib
* Thu Jun  2 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev85:
  * Fix rest_client's expected_success for non int status
* Wed Jun  1 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev84:
  * Correct test_get_usage_tenant's AttributeError
  * Use @wraps decorator
  * Add admin role on domain for v3
  * Adding wait_for_resource_deletion function for volume cleanup
  * Update the home page
* Tue May 31 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev75:
  * Updated from global requirements
  * Revert "Modify --endpoint-type to --os-endpoint-type for nova"
  * Remove kilo config flags from Tempest
  * Add assertion to test_create_security_group_rule_with_invalid_ports
  * Fix usage of rest_client expected_success() in tests
  * Allow image name to be empty for simple list test
* Sun May 29 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev65:
  * Unit test: fix flaky test_networks_returned_with_creds
  * Remove the `file_utils` module
  * Modify --endpoint-type to --os-endpoint-type for nova
  * Moved Cinder QOS tests to admin directory
  * Fix docs errors and warnings
  * Editing descripition for _create_loginable_secgroup_rule
* Sat May 28 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev54:
  * Finish removing legacy credentials
* Fri May 27 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev53:
  * Swift object client: use urllib3 builtin support for chunked transfer
  * Use common "waiters.wait_for_image_status" function everywhere
  * Hash credentials on user, project/tenant and pwd
  * Modify --endpoint-type to --os-endpoint-type for nova
* Thu May 26 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev45:
  * Introduce scope in the auth API
  * Rename get_image_meta method into check_image for Glance V1 client
  * Fix update_password tests
  * Modify projects_client to receive more attributes
  * Add a test case for rebuild of instances with volumes
  * Add cleanup in identity/test_users_negative.py
  * test_port_security_macspoofing_port: Don't assume DHCP port
  * Removed q-vpn from the list of dirty logs
* Wed May 25 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev32:
  * Remove deprecated legacy credentials provider
* Tue May 24 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev30:
  * Document tempest APIs which plugins may use
  * Use mock instead of relying on command stderr
* Sat May 21 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev26:
  * Improve RestClient rate limiting
* Fri May 20 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev24:
  * Update cfg option network_for_ssh's help msg
* Thu May 19 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev22:
  * Updated from global requirements
  * Cinder storage pools tests
  * Docs: Fix Hacking guide bulleting
  * Improve logging of credentials
  * Addresses Expect: 100-continue client behavior
  * Add test case for CONF skip decorators with message
  * Ensure tempest tests don't assume IP address allocation strategy
  * Adding documentation to dynamic_creds functions
  * Remove Ceilometer tempest tests
* Sat May 14 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev9:
  * Correct misspelt word in msg in test_images.py
  * Add separate release notes page for 12.0.0
* Fri May 13 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev5:
  * Revert "Skip test_resize_volume_backed_server_confirm for now"
* Thu May 12 2016 cloud-devel@suse.de
- Update to version tempest-12.0.1.dev4:
  * Skip test_resize_volume_backed_server_confirm for now
  * Change scenario test 'test_resize_server_confirm'
  * Snapshot list using 'limit' parameter
* Wed May 11 2016 cloud-devel@suse.de
- Update to version tempest-12.0.0:
  12.0.0
  * Add release notes for kilo EOL release
  * Py3: `reduce` is not a built-in anymore, use six.moves instead
  * Py3: fix an error when adding two `dict_items`
* Tue May 10 2016 cloud-devel@suse.de
- Update to version tempest-11.0.1.dev128:
  * Fix the docstring of skip_unless_config()
* Mon May  9 2016 cloud-devel@suse.de
- Update to version tempest-11.0.1.dev126:
  * Skip multinodes testing if no same/different scheduler filter enabled
  * Correct mispell words in comments
  * ssh before shelve to avoid ssh failures
  * Pass server to RemoteClient in API tests
  * Extend remote client to allow for better debugging
  * Use a single venv for all tempest jobs
  * trove: skip broken tests
  * Added random Infiniband GUID address generator
  * Migrate network resources into scenario path
  * Verify config support keystone on subpath
  * Add option to tempest init to show global conf dir
  * Add generic CONF skip decorators
  * Added test for router's port update with fixed IP
* Mon May  9 2016 cloud-devel@suse.de
- Update to version tempest-11.0.1.dev103:
  * Update configuration docs wrt admin credentials
  * Remove few refercences left to tempest-lib
  * Remove negative test framework documentation
  * object_storage/object_client.py: kill some dead code
  * Fix reference to tempest_lib
  * Volume: remove a useless `_delete_volume_type` alias
* Mon May  9 2016 cloud-devel@suse.de
- Update to version tempest-11.0.1.dev92:
  * Remove iso8601 and anyjson from requirements.txt
* Mon May  9 2016 cloud-devel@suse.de
- Update to version tempest-11.0.1.dev90:
  * Fix tempest init to update config options
  * List only alive agents
* Mon May  9 2016 cloud-devel@suse.de
- Update to version tempest-11.0.1.dev86:
  * Fix conf file open mode when "tempest init"
  * Search another path for etc/tempest
  * Use the same logic for selecting config path
  * Fix base unit test class location
  * Remove old cinder multibackend configuration from tempest.conf
* Mon May  9 2016 cloud-devel@suse.de
- Update to version tempest-11.0.1.dev77:
  * Fix error message about credential
  * Remove unnecessary space in help
  * Make README.rst consistent
  * Fix account generator error message
  * Add a test for reverting a resize with a deleted flavor
  * Microversion v2.20 tests: nova volume operations when shelved
  * Move shelve server logic in compute utility
* Fri Apr 22 2016 cloud-devel@suse.de
- Update to version tempest-11.0.1.dev66:
  * Add ostestr tox jobs
  * Add tests of fixed_ips in the attach interfaces nova API
  * Skip test_volume_list_with_detail_param_marker
  * Updated from global requirements
  * SSH: Do not rely on the .closed attribute
  * Align multiple lines in tox
  * Add pep8 check to use data_utils.rand_uuid()
  * Remove definitions of unused exception classes
  * Replace Mox with Mock
  * Do not create network resources in verify-config
* Thu Apr 21 2016 cloud-devel@suse.de
- Update to version tempest-11.0.1.dev47:
  * "is_resource_deleted" fails to verify delete
* Fri Apr 15 2016 cloud-devel@suse.de
- Update to version tempest-11.0.1.dev45:
  * Add compute 2.10 microversion tests info in doc
  * Cinder verifies getting volume list with marker
* Thu Apr 14 2016 cloud-devel@suse.de
- Update to version tempest-11.0.1.dev42:
  * Remove openstack-common.conf
  * Remove JSON from class name
  * Fix version replacement when path
  * Enable T108 check for network api tests
* Thu Apr 14 2016 cloud-devel@suse.de
- Update to version tempest-11.0.1.dev34:
  * Refactor extract code to function in auth.py
* Wed Apr 13 2016 cloud-devel@suse.de
- Update to version tempest-11.0.1.dev32:
  * Updated from global requirements
  * Remove virtualenv management scripts from oslo-incubator
* Tue Apr 12 2016 cloud-devel@suse.de
- Update to version tempest-11.0.1.dev30:
  * Get rid of httplib2, use urllib3 instead
  * Updated Image Not Created Error Thrown
  * Use tempest.tests.lib.base instead of tempest.tests.base
  * Fix volume mountpoint - read from configuration file
  * Make add_dhcp_agent_to_network  use **kwargs
  * Make v3 create_trust  use **kwargs & doc string
  * Make v2 create_user_ec2_credentials  use **kwargs
  * Make volume_quotas_client  use **kwargs
  * Add unit test for  availability_zone_client
  * Add SSL  parameters to negative tests
  * Test port update with new security group
  * Port  API Test Enhancement
  * Security Groups  API Tests Enhancements
  * Port  API Tests Enhancements
  * Log deletion errors in  clean servers
  * Check  get_vnc_console attributes of Nova APIs
  * Improve test_load_balancer_basic
  * Verify the response attributes of 'aggregate-set-metadata' API
  * remove  test_service_enable_disable in nova V3 tests
  * Separate negative tests  api/network/security_groups
  * Dump basic network info  in the test_network_basic_ops
  * Fix to create an image with given  min_ram value
  * Add negative test for  set server metadata
  * Added Swift tests:       * account: delete account metadata       * container: retrieve/delete container metadata       * object: retrieve/copy(2 ways) object Syntax bug fix in container_client.py:       return resp. body => return resp, body Fixed passing headers parameter in head method in rest_client.py:       return self.request('HEAD', url, headers) Removed unused imports
  * Adds an identity admin client and API tests for keystone roles
  * fixed the bug 983856. Pep8 complient made
  * bug 985867: remove conf_from_devstack in favor of             devstack.git/tools/configure_tempest.sh
  * Fixes LP#921409 * Adds /servers filter tests * Re-ordered resource building in fixtures to improve   execution time
* Tue Apr 12 2016 cloud-devel@suse.de
- Update to version tempest-11.0.1.dev23:
  * Adding explanation comment for multi-node test
  * Fix Review Checklist URL
  * Update extra_headers param docstring
  * Change alarm client name and tenant name
  * Extend T110 check for lib's service clients
  * Move keypair client to lib interfaces
* Sun Apr 10 2016 cloud-devel@suse.de
- Update to version tempest-11.0.1.dev12:
  * Updated from global requirements
  * Add separate release notes page for v11.0.0
  * Change assertTrue(isinstance()) by optimal assert
* Sat Apr  9 2016 cloud-devel@suse.de
- Update to version tempest-11.0.1.dev6:
  * Move multi-tenant server negative tests into subclass
  * Fix `test_requires_ext_decorator_with_all_ext_enabled`
  * Prepare for dynamic generation of tempest plugin registry
  * include domain_id when creating groups
* Fri Apr  8 2016 cloud-devel@suse.de
- Update to version tempest-11.0.1.dev2:
  11.0.0
  * Skip test_compare_db_flavors_with_os
  * deprecate use of tenant in configs
  * Make ports_client use common waiter method
  * Add release notes for tempest release 11.0.0
* Tue Apr  5 2016 cloud-devel@suse.de
- Update to version tempest-10.0.1.dev149:
  * Remove AuthorizationTestJSON tests
* Mon Apr  4 2016 cloud-devel@suse.de
- Update to version tempest-10.0.1.dev147:
  * Add tests for compute v2.10 microversion
* Fri Apr  1 2016 cloud-devel@suse.de
- Update to version tempest-10.0.1.dev145:
  * Ignore created_at/updated_at in test_show_port
* Wed Mar 30 2016 cloud-devel@suse.de
- Update to version tempest-10.0.1.dev143:
  * Add pep8 check for tempest.lib import
  * Remove the migrated service client
  * Removed deprecation warning from 'tempest --help'
* Tue Mar 29 2016 cloud-devel@suse.de
- Update to version tempest-10.0.1.dev137:
  * Add T111 history to HACKING.rst
  * Fix typo in variable name
  * glance_http: add IPv6 support
* Mon Mar 28 2016 cloud-devel@suse.de
- Update to version tempest-10.0.1.dev131:
  * Use common "waiters.wait_for_snapshot_status" function everywhere
  * More info when fail to get api version
* Sun Mar 27 2016 cloud-devel@suse.de
- Update to version tempest-10.0.1.dev127:
  * Removing wrapper method for "wait_for_volume_status" function
* Sun Mar 27 2016 cloud-devel@suse.de
- Update to version tempest-10.0.1.dev125:
  * Correct server basic ops test case name
* Sat Mar 26 2016 cloud-devel@suse.de
- Update to version tempest-10.0.1.dev123:
  * Add pypi download + version badges into README.rst
  * Removing some redundant words
  * Fix a few typos in microversion doc
  * Add release notes page for v10.0.0
* Fri Mar 25 2016 cloud-devel@suse.de
- Update to version tempest-10.0.1.dev116:
  * Fix comments in microversion doc
  * Move wait_for_resource_status()
  * Move list_dhcp_agents_on_hosting_network()
  * Remove redundant list_router_interfaces()
  * Allow get_tenant_network() for non-primary creds
* Thu Mar 24 2016 cloud-devel@suse.de
- Update to version tempest-10.0.1.dev106:
  * Add microversion testing doc in tempest
* Thu Mar 24 2016 cloud-devel@suse.de
- Update to version tempest-10.0.1.dev104:
  * Fix tests when having multiple floating pools
  * Update the docs on ssh validation
  * Remove unsed wrapper method
* Tue Mar 22 2016 cloud-devel@suse.de
- Update to version tempest-10.0.1.dev98:
  * Add support of microversion in all compute service clients
* Sat Mar 19 2016 cloud-devel@suse.de
- Update to version tempest-10.0.1.dev96:
  * Adding a note to 'test_update_user_password' test for Keystone V2
  * Update comments for keystone precision and fernet
  * Unskip test_list_virtual_interfaces
  * Remove the port list that is not used
* Fri Mar 18 2016 cloud-devel@suse.de
- Update to version tempest-10.0.1.dev89:
  * Trivial: Fix some document comments in microversion
  * Make routers_client use **kwargs
* Thu Mar 17 2016 cloud-devel@suse.de
- Update to version tempest-10.0.1.dev85:
  * Fix API test for external subnet visibility
  * Actually run `test_skip_attr_*` unit tests
  * Scenario/manager.py: always wait when delete a cinder vol
* Thu Mar 17 2016 cloud-devel@suse.de
- Update to version tempest-10.0.1.dev79:
  * Add note a section to lib doc about where to put plugins
  * Migrated microversion testing framework to tempest/lib
  * Optimize "open" method with context manager
  * common/compute.py: remove some useless code
* Mon Mar 14 2016 tbechtold@suse.com
- Update to version tempest-10.0.1.dev71:
  * Fix cleanup CLI for router client
  * Fix PendingDeprecationWarning for assert*
  * Move microversion config options to 'compute' section
  * Remove tempest duplicate copy of skip_unless_attr
  * Fix V3 credential behavior, documentation
  * TrivialFix: Remove pending deprecationwarning
  * Use tempest.lib's base module for network clients
  * Split out Neutron routers client
  * Make 'device' optional in volume attach response schema
  * Test base_url works with an unversioned endpoint
  * Switch hdp to cdh in the default list of Sahara plugins
  * Added support to verify extra-routes deletion
  * Fix typo in library doc title
  * network: Fix subnet_allocation extension check
  * Use urlunparse to reconstruct base_url
  * Add OS-INHERIT of keystone v3 in api tempest
  * Making Keystone clients consistent
  * Fixes LiveBlockMigrationTestJSON.test_iscsi_volume bad call
  * Remove service_client module
  * Use tempest.lib clients for bulk ops
  * Allow heat volume tests to use configured volume size
  * Updated from global requirements
  * Make network clients use rest_client
  * Make identity clients use rest_client
  * Make image clients use rest_client
  * Make volume clients use rest_client
  * Make database/telemetry clients use rest_client
  * Unit tests: mock some time.sleep and time.time
  * Fix ambiguous method name
  * Add more detail info to EndpointNotFound
  * Make object/orchestration clients use rest_client
  * Implement TIMEOUT_SCALING_FACTOR for tempest
  10.0.0
  * Security Groups multi-node scenario
  * Add LOG.info to boot from volume tests
  * Fix test_get_service_by_host_name
  * Make compute keypairs_client use rest_client
  * Make data_processing/baremetal use rest_client
  * Add release notes for upcoming release
  * Properly handle failures during resource cleanup
  * Add documentation for the library interface
  * Split roles_client for keystone v3 client
  * Tokens need user domain be created correctly
  * Make identity service client class name consistent
  * Updated from global requirements
  * Add Identity v3 account configuration information
  * Allow user to be disabled
  * Instance ID was corrected
  * Use isinstance instead of type
  * Added processing /compute URL for getting list of versions
  * remove largeops test
  * Skip test_volume_backed_live_migration()
  * Add reno to tempest
  * Use tempest.lib code in tempest
  * Deprecate Tempest stress tests
  * Migrate tempest-lib code into new lib dir
  * Skip Heat neutron tests
  * Use new oslo.config api to generate configuration-group help
  * Split trusts_client from keystone V3 client
  * Split domains_client from keystone V3 client
  * Minor test style update
  * Add microversion fixture to set microversion
  * Remove zaqar tests from tempest
  * Python 3 deprecated the logger.warn method in favor of warning
  * Enable logging if log_config_append is None
  * Fix cleanup command
  * Fix cleanup cmd for assigning role to user
  * Remove redundant interfaces from v3 identity client
  * Remove some dead code
  * Remove test test_create_delete_server_group_with_multiple_policies
  * Get NIC name by "ip -o link"
  * Use subnetpools_client from tempest-lib
  * Use quotas/security_groups clients from tempest-lib
  * Don't run testcase if interface_attach is False
  * Remove MapR 4.0.1 tempest test
  * Skip the test_get_service_by_host_name
  * skip overlimit tests when default quota set is -1
  * Split users_client from keystone V3 client
  * Separate projects client from identity V3 client
  * Fix cleanup for networking quota
  * Updated from global requirements
  * Revert "Remove setup_credentials from orchestration tests"
  * Add cleanup for endpoint tests
  * Remove old code for Juno compatibility
  * Log more info when mke2fs fails on a guest
  * Use 2 network clients from tempest-lib
  * Update .mailmap
  * Fix KeyError in exception message of manager
  * Revert "Add new test "RebuildInstanceWithVolume""
  * Add tests of port_id in the attach interfaces nova API
  * Updated from global requirements
  * Updated .gitignore to work with ide
  * Make v3 identity_client consistent
  * Emit warning when instances have ports not ACTIVE
  * Fixing typos in tempest/test.py
  * Fixed bug with url building
  * Add new test "RebuildInstanceWithVolume"
  * Add note about ironic config options
  * Make 2 functions in network_client use **kwargs
  * Only run dual-NIC/dual-stack IPv6 tests in gate
  * don't explicitly delete security group rules
  * Remove setup_credentials from orchestration tests
  * Remove Keystone client variables that are not used anywhere
  * Add new exception InvalidAPIVersionRange for microversion
  * skip test_list_server_filters_by_regex
  * Separate microversion test case related unit tests
  * Identity V3: missing api coverage for 'Get Endpoint' method
  * Consolidate the ssh code
  * Refactoring of 'DataGenerator' classes for identity V2 and V3
  * Add the group and role checks API in tempest
  * Fix stress tests job to use dynamic cred
  * Split endpoints-client out of keystone v2 identity client
  * Split out Neutron extensions client
  * Updated from global requirements
  * Scenarios: remove trivial wrapper methods
  * Remove redundant import from scenario tests
  * Replace legacy cred provider in heat api test
  * Replace exit() by sys.exit()
  * Revert "Cap Pip<8 due to pip bug"
  * Split DataGenerator class for v2 and v3
  * Updated from global requirements
  * Separate base microversion client and compute client
  * Updated from global requirements
  * Fix logic in dump_accounts
  * Cap Pip<8 due to pip bug
  * Add omit files for coverage
  * create_server: pass arguments as part of kwargs
  * Split services client out of keystone v2 identity client
  * Fixing test_create_port_in_allowed_allocation_pool when 3 (or more) controllers
  * Use container/disk format settings in glance v1 test
  * Wait for servers termination when cleaning up telemetry test
  * Adds default domain name to dashboard login params
  * add client_manager_class param to BaseTestCase
  * Delete unnecessary internal method
  * Mark amazon image file config options deprecated
  * Split out Neutron security group rules client
  * Raise tox min version to avoid maximum recursion issue
  * Don't use non-existent method of Mock
  * Migrate tempest-account-generator to new cliff cli framework
  * Apply "POST/DELETE" rules to agents_client
  * Add network wrapper method checks
  * Add different_host test on multiple nodes
  * Add tests for Nova microversion v2.2
  * Fix to show cli subcommand help message
  * Use 5 neutron clients from tempest-lib
  * Fix create_test_server for multiple create request
  * Make v1 list_images use **kwargs & doc string update
  * Fix tempest_lib import order
  * Mark Javelin as deprecated
  * Split users_client from keystone client v2
  * Updated from global requirements
  * Migrate verify-tempest-config to new cliff cli framework
  * Skip security group tests without secgroup ext
  * API/compute: create all servers through the common wrappers
  * Make volume snapshots_client to use **kwargs
  * Updated from global requirements
  * Add tempest-list-plugins
  * Use floating_ips_client from tempest-lib
  * Update global-requirement for tempest-lib
  * Scenario: Skip TestServerMultinode when only 1 compute node
  * Add external gateway to dvr before scheduling with dvr_snat agent
  * Redundent if Statement
  * Make v1 create_image & update_image use **kwargs
  * Make volume volume_client to use **kwargs-part2
  * Make volume volume_client to use **kwargs-part1
  * remove log_console_of_servers from get_remote_client
  * Trival: Remove unused logging import in some files
  * Fix the password input
  * Scenario manager: don't access glance_client if Glance is not available
  * Silences Javelin UT
  * Typos and consistency in configuration.rst
  * Config: change cinder bootable flag to True
  * Fixing the deprecated library function
  * Change validate message for test_exceed_max_template_size_fails
  * Fix leak from tempest.conf in fake_config fixture
  * Add support override OS_TEST_TIMEOUT for all environments
  * Wrong usage of "an"
  * Fix server admin password usage
  * Safe ram/disk/vcpus values for test-made flavor
  * Refactoring of setting 'name' variable in tempest/common/compute.py
  * Make 2 base_snapshots_client function use **kwargs
  * Use six.StringIO/BytesIO instead of StringIO.StringIO
  * Keep py3.X compatibility for urllib.urlencode
  9
  - 
  * [sahara] adding new plugin versions to sahara tempest tests
* Fri Jan  8 2016 cloud-devel@suse.de
- Update to version tempest-8.0.1.dev302:
  * Add support of schema versioning for microversion
  * Rename compute images_client to compute_images_client
  * Fix create/show/delete methods on subnetpools_client
* Thu Jan  7 2016 cloud-devel@suse.de
- Update to version tempest-8.0.1.dev296:
  * Rename references to compute security group rules client
  * Misspelling in message
  * Misspelling in messages
  * Wrong usage of "a"
  * Add set microversion in base compute service client
* Wed Jan  6 2016 cloud-devel@suse.de
- Update to version tempest-8.0.1.dev286:
  * Fix grammatical mistake, Changed word from "an" to "a" in below file:
  * Correct wrong message in configuration doc
  * Wrong spelling of existing
  * Add a note about using a full path for test accounts option
  * Change LOG.warn to LOG.warning
  * Add logic to select the request microversion
  * Fix password not strong enough for identity test_groups
* Tue Jan  5 2016 cloud-devel@suse.de
- Update to version tempest-8.0.1.dev272:
  * Split out Neutron subnetpools client
  * Split out Neutron agents client
  * Enable test_list_security_groups_list_all_tenants_filter with neutron
* Sat Dec 26 2015 cloud-devel@suse.de
- Update to version tempest-8.0.1.dev266:
  * Make v3 update_role use **kwargs & doc string
  * [V3] Renaming region_client into regions_client
  * [V3] Renaming policy_client into policies_client
  * Make v2,v3 create_role use **kwargs & doc string
* Fri Dec 25 2015 cloud-devel@suse.de
- Update to version tempest-8.0.1.dev258:
  * Make v2 for identity_client functions use **kwargs
* Thu Dec 24 2015 cloud-devel@suse.de
- Update to version tempest-8.0.1.dev256:
  * Updated from global requirements
  * Stop testing rebuild for ironic
  * Add stdout logging for cleanup CLI
  * Add stdout logging for stress
* Wed Dec 23 2015 cloud-devel@suse.de
- Update to version tempest-8.0.1.dev249:
  * Fixing two tests when nova-net is enabled and run_validation = True
  * Split out Neutron security groups client
  * Make 3 functions in network_client use **kwargs
  * Use servers_client from tempest-lib
  * Use Tempest-lib's compute server_groups_client
  * Make volume_qos_client use **kwargs
  * Make add_dhcp_agent_to_network use **kwargs
  * Make volume_types_client use **kwargs
* Tue Dec 22 2015 cloud-devel@suse.de
- Update to version tempest-8.0.1.dev233:
  * Use Tempest-lib's compute security_group_rules_client
  * Use floating_ips_client from tempest-lib
  * Update global-requirement for tempest-lib
  * Add description for stress in tempest cli
  * [V3 identity] Renaming service_client into services_client
  * Drop lock_path section from config guide
  * Fix telemetry tests to use v1 create image correctly
  * 'List volume type' comment has fixed
* Sat Dec 19 2015 cloud-devel@suse.de
- Update to version tempest-8.0.1.dev217:
  * Fix tempest cleanup command
  * Remove the ec2 api tests from tempest
  * Fix password not strong enough for cmd
  * Get rid of unused env variable
  * Make update_agent in network_client use **kwargs
  * Make create_image use **kwargs
  * Fixed the comments of port security group test
  * Teach Tempest how to count vcpus
  * Make update_extra_routes use **kwargs & doc string
* Fri Dec 18 2015 cloud-devel@suse.de
- Update to version tempest-8.0.1.dev199:
  * Set a tempest lock_path default to a tmpdir
  * Update configuration options ssh-auth-strategy
  * Remove pre-check for test accounts file in credential factory
  * Split out roles client from keystone identity client
  * Fix password not strong enough failures
  * Clean up comment about dual-stack case handling
  * Set force_tenant_isolation on neutron quotas tests
  * test_port_security_macspoofing_port: Fix an inversed check
  * Set default value for tempest log file
* Thu Dec 17 2015 cloud-devel@suse.de
- Update to version tempest-8.0.1.dev182:
  * Fix and improve server personality tests
  * Split out Neutron quotas client
  * Make server action methods[m-z] use **kwargs
  * Make server action methods[f-l] use **kwargs
  * Make v3 create_trust use **kwargs & doc string
  * Fix some Type in docstrings
* Wed Dec 16 2015 cloud-devel@suse.de
- Update to version tempest-8.0.1.dev170:
  * Make v3 update_user_password use **kwargs
  * Split out keystone tenant client
  * Make server action methods[a-c] use **kwargs
  * Add compute client base class for microversion support
  * Rename references to compute security groups client
  * Remove unused add_sample()
  * Add run_stress to cliff-based cli framework
* Tue Dec 15 2015 cloud-devel@suse.de
- Update to version tempest-8.0.1.dev156:
  * Replace assertEqual(None, *) with assertIsNone in tests
  * Make volume backups_client to use **kwargs
  * Rename add_image_member to create_image_member
* Sat Dec 12 2015 cloud-devel@suse.de
- Update to version tempest-8.0.1.dev151:
  * Change docstring of compute client
  * Put py34 first in the env order of tox
* Fri Dec 11 2015 cloud-devel@suse.de
- Update to version tempest-8.0.1.dev147:
  * Make live_migrate_server() use common method
  * Makes microversions config option clear about 'None'
  * Making names of Cinder client classes consistent
  * Use Tempest-lib's compute volumes_client
  * Fix T110 violation for database client
  * Remove pre-request-validation from v2 image_client
  * Make v2 create_user_ec2_credentials use **kwargs
  * [V3] Rename get_policy to show_policy
  * Make argument params of list methods consistent
* Thu Dec 10 2015 cloud-devel@suse.de
- Update to version tempest-8.0.1.dev129:
  * Updated from global requirements
  * Fix race condition when changing passwords for admin tests
* Wed Dec  9 2015 cloud-devel@suse.de
- Update to version tempest-8.0.1.dev125:
  * Make add_router_to_l3_agent use **kwargs
  * Split out Neutron metering label rules client
  * Renaming Cinder admin client files
  * Use interfaces_client from tempest-lib
  * [V3] Rename get_region to show_region
  * [V3] Rename get_credential to show_credential
  * Fix some Typo in docstrings
* Tue Dec  8 2015 cloud-devel@suse.de
- Update to version tempest-8.0.1.dev111:
  * Add unit test for test_servers_client-allfunctions
  * Make add_member use **kwargs and doc string update
  * Update global-requirement for tempest-lib
  * Add network quota exceeding negative test
  * Split a server test into two distinct tests
* Sun Dec  6 2015 cloud-devel@suse.de
- Update to version tempest-8.0.1.dev103:
  * Make create_floating_ip use **kwargs
  * Add the base microversions test part
  8
  - 
* Sat Dec  5 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev238:
  * Use the idempotent id and tooling from tempest-lib
  * Switch run_tests.sh to use subunit-trace
  * Remove unused agents's schema
  * Add script to use tempest-lib files in tempest
  * Rename image_client to images_client
  * Remove unused json_request()
  * Rename private methods of glance_http
* Fri Dec  4 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev224:
  * Add docstring for update_image_member
  * Make volume_quotas_client use **kwargs
  * Split out Neutron metering labels client
  * Add keystone v3 user negative case test authentication with disabed user
* Thu Dec  3 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev216:
  * Updated from global requirements
  * Migrate scenario tests ssh-auth-strategy
  * Changing directory structure for Cinder clients
  * Fix typo in tox.ini
  * Add tests to update group with few fields
* Wed Dec  2 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev206:
  * Fix some inconsistency in docstrings
  * Switch run_tempest.sh to use subunit-trace
* Tue Dec  1 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev202:
  * Make argument params of list methods consistent
  * Use versions_client, versions from tempest-lib
* Mon Nov 30 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev198:
  * Use tenant_usages_client from tempest-lib
  * Use tenant_networks_client from tempest-lib
* Sat Nov 28 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev194:
  * Remove "s" from imange clients' method
  * Make image_client use **kwargs
  * Adds test for mac_spoofing
* Fri Nov 27 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev188:
  * Change checks for test_server test
  * Change multi-backend configuration to a list
  * Use snapshots_client from tempest-lib
  * Use Tempest-lib's compute services_client
  * Use Tempest-lib's compute security_groups_client
  * Use V3 params when initializing Keystone V3 clients
  * Use Tempest-lib's compute security_group_default_rule
  * Use Tempest-lib's compute quotas_client
  * Fix T110 violations for image_client
  * Scenarios: cleanup class scope variable usage
  * [V3] Rename get_group to show_group
  * [V3] Make groups_client use **kwargs
  * Bring back Python 2.6 compat (don"t use dict comprehension)
* Thu Nov 26 2015 tbechtold@suse.com
- Update default admin_tenant_name and admin_username in
  tempest.conf
* Thu Nov 26 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev163:
  * Drop fixed_network dependency from CONF
  * Use Tempest-lib's compute quota_classes_client
  * Use Tempest-lib's compute networks_client
  * Use Tempest-lib's compute migrations_client
* Wed Nov 25 2015 vuntz@suse.com
- Stop setting a [cli] section in tempest.conf, it's gone upstream.
* Wed Nov 25 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev155:
  * Change tests to adapt alarm spliting
  * Use Tempest-lib's compute limits_client
  * Remove preprov provider dependencies from CONF
  * Use Tempest-lib's compute instance_usage_audit_logs
  * Use Tempest-lib's compute images_client
  * Add T111 hacking rule for consistent DELETE method
  * Refactor T110 rule
  * Add keystone v3 user negative cases
  * Fix T110 violations for servers_client
  * [V3] Separating groups_client from identity_client
  * Move identity wait until after password is updated
  * Move get_user_by_username to common part
  * Remove unused config option image_alt_ssh_user
* Tue Nov 24 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev129:
  * Split out Neutron floating IPs client
  * Change comments and description for minimum_basic test
  * Removing initialization of clients that are not used
  * Move get_tenant_by_name to common part
* Fri Nov 20 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev121:
  * Skip test that rely on creds by role
  * Updated from global requirements
  * Modify baremetal_basic_ops test
* Fri Nov 20 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev116:
  * Fix H404/405 violations for remaining
  * Unbreak test_created_router_interface (heat)
  * Fix H404/405 violations for thirdparty and stress
  * Fix H404/405 violations for unit tests
  * Fix H404/405 violations for common code
  * Fix H404/405 violations for api tests(3/3)
  * Fix H404/405 violations for api tests(2/3)
  * Fix H404/405 violations for api tests(1/3)
  * Add negative test to test_domains_negative
  * Fix skip_checks in live_migration
* Thu Nov 19 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev97:
  * Fix H404/405 violations for tools
  * Fix H404/405 violations for service clients
  * Move get_server_or_ip method to common class
  * add 'create domain with name length > 64'
  * Factor up config dependent credential classes
  * Fix race condition when changing passwords
* Wed Nov 18 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev85:
  * Fix H404/405 violations for scenario tests
  * Remove novaclient/neutronclient description
  * Remove server_groups_client from ignore_list
  * [V3] Make service_client use **kwargs
  * Add installation procedure of cookiecutter to doc
  * Updated from global requirements
  * change some sentences to help understand
* Tue Nov 17 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev71:
  * Fix AttributeError in multinode jobs
  * Rename get_server_group to show_server_group
  * Add hacking rule for "GET /resources"
  * [V3] Make region_client use **kwargs
  * [V3] Make policy_client use **kwargs
  * [V3] Make endpoints_client use **kwargs
  * [V3] Make credentials_client use **kwargs
  * Rename references to compute floating IPs client
  * Remove BaseComputeTest and _api_version
* Sun Nov 15 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev53:
  * Use skip_checks for live-migration feature in test
* Sat Nov 14 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev51:
  * make schedule_to_every_node use real scheduler hint
  * Trivial fix of doc string
  * Use choices kwarg when defining string options with defined choices
* Fri Nov 13 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev45:
  * add test to ensure cloud is using minimum number of nodes
* Thu Nov 12 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev43:
  * Fix TypeError exception in test_server_actions setup
  * Rename list_users_for_tenant to list_tenant_users
  * Apply a naming rule of GET to v2 keystone clients
  * Modify scenario tests
  * Split out Neutron ports client
  * Add documentation for service catalog format
  * Fix checks for X-Trans-Id in DLO-related storage tests
* Wed Nov 11 2015 tbechtold@suse.com
- Add missing BuildRequires python-tempest-lib for sample config
  generation.
- Set PYTHONPATH when running oslo-config-generator to include
  the config parameters from tempest.config
* Wed Nov 11 2015 tbechtold@suse.com
- Add BuildRequires for sample config generation.
* Wed Nov 11 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev30:
  * Remove unused has_admin_extensions()
* Tue Nov 10 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev28:
  * Provide better message when no IPv4 addresses found
* Fri Nov  6 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev26:
  * Refactor volume_boot_pattern test
  * Add negative test: create domain with empty name
  * Add cleanup to cliff-based cli framework
  * Allow empty directories for tempest init
* Thu Nov  5 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev18:
  * Add assertion after domain deletion
  * Remove checks for ipv6 utilities before use
* Wed Nov  4 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev15:
  * Updated from global requirements
  * Remove skip decorator for volume scenario test
* Tue Nov  3 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev13:
  * Remove resource_setup() from test_live_migration
  * create_router cannot take enable_snat=False
* Sat Oct 31 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev10:
  * Prepare cred_client for migration
  * Fix unit tests for migration
  * Switch to using pbr version for cli version string
  * Add plugin cookiecutter in documentation
  * Use Tempest-lib's compute hypervisor_client
* Fri Oct 30 2015 cloud-devel@suse.de
- Update to version tempest-7.0.1.dev4:
  7
  - 
  * Drop admin_role CONF dependency from cred provider
  * Removed shared instances for live-migration
  * test_network_advanced_server_ops: cleanup class scope variable usage
  * test_minimum_basic: cleanup class scope variable usage
* Thu Oct 29 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev248:
  * test_snapshot_pattern: cleanup class scope variable usage
* Wed Oct 28 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev247:
  * test_shelve_instance: cleanup class scope variable usage
  * test_stamp_pattern: cleanup class scope variable usage
* Mon Oct 26 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev243:
  * Remove dependency from credentials domain CONF
* Mon Oct 26 2015 bwiedemann@suse.com
- Update to version tempest-6.0.1.dev241:
  * Remove CredentialProvider deps to CONF
  * Stop validating pre-provisioned credentials
  * plugin.rst: Fix a typo in an example code fragment
  * skip compute alt tenant tests if no project_id in url
  * Fix DEFAULT_CONFIG_DIR
  * Make docstring of servers consistent
  * Pass the status 'ACTIVE' for getting a target port
  * Use Tempest-lib's compute hosts_client
  * Use Tempest-lib's compute floating_ips_bulk_client
  * Use Tempest-lib's compute floating_ip_pools_client
  * Use Tempest-lib's compute flavors_client
  * Fixing checking bytecode
  * Use Tempest-lib's compute fixed_ips_client
  * Remove migrated service clients from test_service_client
  * Add compute personality feature config
  * Use Tempest-lib's compute extensions_client
  * Use Tempest-lib's compute certificates_client
  * Use Tempest-lib's compute baremetal_nodes_client
  * Use Tempest-lib's availability_zone_client
  * Use Tempest-lib's aggregate client
  * Split out Neutron subnets client
  * Bump minimum tempest-lib version
  * Moves an incorrectly marked negative test
  * Set correct ACL for Swift staticweb tests
  * Add failure ports to error message
  * Make services_client use **kwargs
  * Log output from ping command
  * Fix value explanation in get_creds_by_roles
  * Add unit test for create_server,list_addresses
  * Handle exceptions from plugins gracefully
* Fri Oct  9 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev160:
  * Remove "extensions" from volumes_extensions_client
  * Split snapshot test in test_volume_quotas_negative
* Thu Oct  8 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev157:
  * Updated from global requirements
  * Add json schema for disable service
  * Fix tempest-account-generator command roles issue
  * Added Test Cases for ImagesClient
  * Added Test Case for InterfacesClient
  * Add unit tests for show_server and list_servers
  * Add unit tests for snapshots_client
  * Make create_server_group use **kwargs
  * Subnet pools extension api added
  * Metadata definition namespaces api added
  * Change tenant usage tests to wait until retrive valid response
  * Fix way to create login_url in dashboard test
  * Skip test_router_rescheduling if l3 scheduler extension is not enabled
  * Deprecate credential config options
* Sat Oct  3 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev129:
  * Add test for config drive extension
  * Added Test Case for HostsClient
* Fri Oct  2 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev125:
  * Pass mount_path through to ssh_client.mount in scenario manager
  * Remove unused _ssh_to_server from test_stamp_pattern
  * Remove "extensions" from snapshots_extensions_client
  * Negative test cases added in Telemetry
* Thu Oct  1 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev117:
  * Split out Neutron networks client
  * Fix test_port_list_filter_by_ip with test_accounts
* Wed Sep 30 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev113:
  * Refactor tempest scenarios tests
  * Check cinder api version in compute tests
  * Follow up patch on missed IdentityV2 methods
* Wed Sep 30 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev107:
  * Fix gate-tempest-dsvm orchestration.stacks.test_volumes failure
* Sun Sep 27 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev106:
  * Add volume backed live migration test
  * Add unit test for flavors_client
  * Fix spelling typo in warning message
  * Updated from global requirements
  * Full response for missed IdentityV2Client methods
* Wed Sep 23 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev97:
  * Fix constants of config sections names in verify_*_api_versions
* Tue Sep 22 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev96:
  * Rename SwiftScenarioTest to ObjectStorageScenarioTest
* Sun Sep 20 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev94:
  * Fix typos in scenario tests, etc
* Sat Sep 19 2015 cloud-devel@suse.de
- Rebased patches:
  + 0001-Add-possibility-to-skip-test_subnet_details.patch dropped (merged upstream)
* Sat Sep 19 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev92:
  * Add resource cleanup in volume snapshots tests
  * Enhance unit test coverage: availability_zone_client
  * Add unit test for floating_ips_client
  * Make create_server use **kwargs
  * Add a simple test for port security vs security group
  * Add possibility to skip test_subnet_details if DHCP client not available
* Fri Sep 18 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev80:
  * Move add/remove fixed ip action to servers_client
  * Add unit test for hypervisor_client
  * Add shelve/unshelve volume backed instance test
* Thu Sep 17 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev75:
  * Rename `index` test into list
  * Rename references to compute networks client
  * Use tempest-lib's fake_auth_provider on services
  * Fixing a typo in "TODO" message
  * Add tests for getting nova api version details
  * Add unit tests for security_group_rules_client
  * Added Identity API tests for user ec2 credentials
  * Give access to CredClient in tests
* Wed Sep 16 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev59:
  * Create base class for Tempest Network clients
  * Test case updated with alarm history api
  * Remove unused parameter 'tenant_id'
* Tue Sep 15 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev53:
  * Add unit tests for volumes_extensions_client
  * Add test for volume snapshot in compute api
  * Fix missing value types for log message
  * Remove nova v2 API comments
  * Return complete response from servers_client
  * Switch using token_client to the recommended
  * Fix the condition of some snapshot tests
  * Fix typo in baremetal_group & AuthGroup of config.py
* Sat Sep 12 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev39:
  * Enhance unit test coverage: agents_client
  * Remove list_security_group_rules wrapper method
  * Split the operator and reseller users in the account generator
  * Add unit tests for floating_ips_bulk_client
  * Return complete resp from volumes_extensions_client
  * Add unit test for server_groups_client
  * Remove assertion checking rescoped issued_at
  * Full response for database flavor client methods
  * Added CONF.validation entry security_method
* Fri Sep 11 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev24:
  * Add unit tests for security group default rules
  * Updated from global requirements
  * Add initial unit test for tempest plugins
  * Use the oslo.config sphinx module to generate sample
* Thu Sep 10 2015 jsuchome@suse.com
- Added 0002-Add-possibility-to-skip-test_subnet_details.patch
  so that we can skip the test not supported by docker
* Thu Sep 10 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev19:
  * Use proper method for nova disable service unit test
  * Switch using token_client to the latest for gate
  * Only add roles for enabled services
  * Add docs section on config options to reviewers guide
  * Added Test Case for BaremetalNodesClient
  * Add unit test for floating_ip_pools_client
  * Add unit tests for security_groups_client
  * Cleanup API version schema
  * Fix identity new endpoint_type options for old users
* Wed Sep  9 2015 cloud-devel@suse.de
- Update to version tempest-6.0.1.dev7:
  * Use Cinder API V2 if V1 is disabled
  * Fix wrong dict reference for show_network
  6
  - 
  * Add unit tests for migrations_client
  * Deduplicate cert, audit_log and tenant_net client
  * Remove too_slow_to_test flag
  * Return complete response from remaining service client
* Tue Sep  8 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev518:
  * Remove code duplication in delete methods
  * Added Test Cases for FixedIPsClient
  * Deduplicate client unit tests
  * Make update_server use **kwargs
  * Add hacking check for testtools.skip
  * Migrate volume tests to the ssh-auth-strategy
  * Full response for VolumesClient methods
  * Update logic to detect DVR in rescheduling test
  * Update tox.ini for sphinx build instructions
* Sun Sep  6 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev500:
  * Added test_user_update_own_password tests for Identity v2, v3
* Sat Sep  5 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev498:
  * Ensure test_list_show_tenant_networks is isolated
  * Added test_list_tenants non-admin test for v2, v3 api/identity
  * De-duplicate test class names
  * Add test for Nova list-versions API
  * Cleanup tempest docs a bit
  * Switch remaining json import to oslo_serialization
  * Add mac info to test_list_virtual_interfaces
  * Return correct domains in cleanup service
  * Fix response of database Limits & Versions client
* Fri Sep  4 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev481:
  * Remove Nova v3 version API schema
  * Migrate telemetry tests to the ssh-auth-strategy
* Thu Sep  3 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev477:
  * remove service-type from neutron extension list
  * Do not pass wait_until to create_server()
  * Add docstring for tenant_network
  * test_volume_boot_pattern: re-use create_floating_ip from base class
  * Add "server" to action methods - part 2
  * Fix the mix use of name and uuid in NetworksNegativeTestJSON
  * Fix tests updating server by name rather than id
* Wed Sep  2 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev463:
  * Add unit tests for tenant_networks_client
  * Encap netaddr-0.7.16
* Wed Sep  2 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev459:
  * Add flag for volume clone tests
  * scenario/test_minimum_basic: relax a MatchesDictExceptForKeys check
* Tue Sep  1 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev455:
  * Skip ebs scenario test due to bug 1489581
* Mon Aug 31 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev454:
  * Remove meaningless braces
* Sun Aug 30 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev453:
  * Disable cinder backup import/export test
  * Remove unused init file and directory
  * Fix typo in the create_isolated_networks help in config.py
  * Add unit tests for instance_usage_audit_log_client
  * Add unit tests for certificates_client
  * Return complete response from limits,migration client
  * Full response for missed Identity V3 Client
  * Return complete response from tenant_networks_client
* Sat Aug 29 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev437:
  * Skip router rescheduling test
  * add waiting for snapshot available status
  * Fix typo in tempest coding guide
  * Fixed few typos
  * Adds test for router rescheduling
* Fri Aug 28 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev427:
  * Add unit test for availability_zone_client
  * Add unit tests for tenant_usages_client
  * Return complete response from compute images_client
  * Return complete response from compute quotas client
  * Update the Tempest README for new run workflow
  * Marking the login_url option as "deprecated_for_removal"
  * add 'boot from ebs' scenario test
  * Remove some dead code
  * Avoid default quota limit of 10 subnets
* Thu Aug 27 2015 tbechtold@suse.com
- Update to version tempest-5.0.1.dev409:
  * Properly skip nova tests if nova isn't available
  * remove test_update_host_with_extra_param
  * Make volumes_extensions_client use **kwargs
  * Add plugin docs section on configuration options
  * Return complete response from compute networks_client
  * Return complete resp from security_groups_client
  * Return complete resp from sec grp default rule client
  * Return complete response from tenant_usages_client
  * Return complete response from services_client
  * Return complete resp from server_groups_client
  * Return complete resp from security_group_rules_client
  * Return complete response from interfaces_client
  * Return complete response from instance usage client
  * Return complete response from flavors_client part-2
  * Return complete response from flavors_client part-1
  * Return complete response from compute/aggregates_client
  * non-admin user only able to download Active image
  * Fix misspelling in the "README.rst"
  * Fix typo in tempest configuration guide
  * Fix name "Quantum" to "Neutron" in comment
  * Full response for Volume SnapshotsClient methods
  * Router should be disabled to be upgraded to DVR
  * Full response for Database Limits & Version Client
  * Add unit tests for services_client
  * Fixed typo
  * Full response for VolumeHostsClient methods
  * Full response for Volume QosClient methods
  * Full response for Volume BackupsClient methods
  * Fix typo in tempest configuration page
  * Full response for DataProcessingClient methods
- Disable man build for now
- Generate tempest.conf with oslo config generator
- Add install_absolute.patch
* Sat Aug  1 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev179:
  * Skip test_check_nova_notification_event_and_meter
  * Rename service client classes which include "Ip"
* Fri Jul 31 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev175:
  * Allow v3 identity to work without the admin domain name
  * Separate security_group_rules_client
  * Add unit tests for create/update/delete_agent
  * Fixing test_volume_boot_pattern when use_floatingip_for_ssh=false
  * Fix Neutron cleanup
  * use services decorator to enable telemetry test
  * add initial check for nova event in ceilometer
* Fri Jul 31 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev161:
  * Updated from global requirements
  * Add unit test for method list_keypairs
  * Add unit test for method list_aggregates
* Wed Jul 29 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev155:
  * Add documentation to HACKING.rst describing idempotent_id
  * Fix two typos on tempest documentation
  * Update smaple config for new oslo.config release
* Wed Jul 29 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev149:
  * Add tempest init command to tempest cli
  * Activate site-packages for tempest plugins
  * Make quotas_client use **kwargs
  * Make interfaces_client use **kwargs
  * Make fixed_ips_client use **kwargs
* Mon Jul 27 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev142:
  * Use image minDisk as volume size when necessary
  * Add plugin interface for appending to tempest config
* Sat Jul 25 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev138:
  * Updated from global requirements
  * Make aggregates_client use **kwargs
  * Refactor exception handling
  * Enable tempest install to setup a config dir
* Fri Jul 24 2015 dmueller@suse.com
- fix up requires
* Thu Jul 23 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev133:
  * Add 'allow_duplicate_networks' to compute-feature-enabled options
  * Fixing test_port_list_filter_by_ip in case of several DHCP agents
* Mon Jul 20 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev130:
  * Adds testcase for volume backup-export and import
  * Avoid weird typecasting
  * Remove extra space in docstring
  * Reuse mocked body value between tests
* Sat Jul 18 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev123:
  * More cleanup/refactoring of neutron client
* Fri Jul 17 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev121:
  * Fix list_migration response schema for None values
  * Ensure we close the file accounts file after reading
  * Updated from global requirements
  * Remove redundant attach/detach volume methods from test_minimum_basic
  * Ensure a role is assigned to created users with v3 auth
  * Migrate compute tests to the ssh-auth-strategy
  * Stop test execution in case of an plugin error
  * Fix error in loader.discover() call
  * Add unit test for agents_client
  * Make argument params of list methods consistent
  * Use self.client in test_server_actions
  * Remove wait_for_server_status from servers_client
  * network_client should support multi routes
* Wed Jul 15 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev96:
  * Switch all uses of json to oslo_serialization
  * Rename test.plugins to test_plugins
  * Wait server to be terminated in VolumesV2NegativeTest
* Tue Jul 14 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev90:
  * Fix non-admin compute quota issue
  * Separate floating_ips_bluk_client
  * Separate floating_ip_pools_client
  * Updated from global requirements
  * Sync venv scripts from oslo-incubator
  * Make the arguments of resource id consistent
  * Provide a full path top level to test discovery
  * Remove wait_for_volume_status from compute client
  * Separate server_groups_client from servers_client
  * Re-factor neutron client for 'list' methods
* Sat Jul 11 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev71:
  * Add tests for Cinder volume list pagination
* Fri Jul 10 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev70:
  * Fix mock==1.1.0 break test_raw_request_chunked
  * Create test for private image
* Fri Jul 10 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev63:
  * Remove unused is_enabled()
  * Remove wait_for_image_status from compute client
  * Move wait_for_interface_status from service client
  * Add basic external test plugin support to tempest
  * Expanded assertion in test_create_token for keystone v2, v3
  * Adding negative test cases for ports
  * Remove unnecesarry code in PortsAdminExtendedAttrsTest
  * Use the prefix-embedded rand_name method
  * Adding negative test cases for subnets
  * Apply a naming rule of GET to show_server method
  * Remove "JSON" from sevice clients' names
  * Add cliff based common cli entrypoint
  * Add ":" to docstring of CredentialProvider
  * update ceilometermiddleware sample target
  * Removing unused functions parameters in test.py
  * Neutron service client should not trim API response
  * Re-factor neutron client for 'delete' methods
  * Re-factor neutron client for 'show' methods
  * Re-factor neutron client for 'update' methods
  * Support for ipv6 in compute response JSON schema
* Fri Jul  3 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev25:
  * Get rid of duplicated creation of security groups in test_volume_boot_pattern
  * Fix useless usage of Linux utils
  * Remove str() calls from compute clients
  * Apply a naming rule of GET to compute clients(v*)
* Thu Jul  2 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev17:
  * Apply a naming rule of GET to compute clients(t*)
  * Apply a naming rule of GET to secgroup clients
  * Modify RemoteClient to use ssh validation config parameters
* Wed Jul  1 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev12:
  * Use random password generator for IsolatedCreds
  * Updated from global requirements
  * Removing unnecessary comments
  * Add resource prefix string
  * Delete resources when dvr test skipped
  * Set the correct API version for the V2 identity client
  * Fix failed to access pip server when run behind proxy
* Tue Jun 30 2015 cloud-devel@suse.de
- Update to version tempest-5.0.1.dev2:
  * Unbreak the world!
  5
  - 
  * Add compute_feature_enabled.attach_encrypted_volume config option
* Fri Jun 26 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev239:
  * Re-factor neutron client for 'create' methods
  * Apply a naming rule of GET to compute clients([ik])
  * Updated from global requirements
  * Added comment how to get list of network extensions in tempest.conf
  * Remove advanced services tests
* Wed Jun 24 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev227:
  * Fix the description in tempest.conf.sample
  * Apply a naming rule of GET to compute clients(q*)
  * More javelin unit tests
* Tue Jun 23 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev222:
  * Updated from global requirements
* Mon Jun 22 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev221:
  * Provide a config option to customize remote shell command
  * re-enable glance notification tests
* Sat Jun 20 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev217:
  * Add a rule for blocking "-" from rand_name call
* Fri Jun 19 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev215:
  * Block additionalProperties on Nova API tests
  * Add create_test_server function
* Thu Jun 18 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev212:
  * Fix no attribute 'is_dvr_router' error in test_l3_agent_scheduler
  * Made a several-seconds checking&waiting for object to be deleted
* Thu Jun 18 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev209:
  * Remove key 'absolute' from limits client
* Wed Jun 17 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev208:
  * Apply a naming rule of GET to compute clients(n*)
  * Separate quota_classes client from quotas client
* Tue Jun 16 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev204:
  * More Javelin Unit tests
  * Add passenv option to tox.ini
  * Add router to resources section of yaml output
* Mon Jun 15 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev199:
  * Remove error handling of list_networks
  * Apply a naming rule of GET to compute clients(l*)
  * Apply a naming rule of GET to compute clients(h*)
  * Apply other "get" rule of GET to image v2 client
* Sun Jun 14 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev191:
  * Updated from global requirements
  * Neutron: Remove get_namespace from API extensions
* Fri Jun 12 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev187:
  * Fix L3AgentSchedulerTestJSON failure for dvr routers
  * Provides a sample resourcefile for Javelin
  * Add keystone v2.0 and v3 api discovery checks
* Thu Jun 11 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev181:
  * Fix spell error in configuration.rst
  * Add tenant network creation to account creation script
  * Fix several bugs in verify_tempest_config
  * Added documentation to tempest-account-generator
* Wed Jun 10 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev173:
  * Fix fail test_iscsi_volume
  * Apply a naming rule of GET to compute clients(f*)
  * Apply other "get" rule of GET to image v1 client
  * Make the names of image_member methods consistent
  * Check for NotFound exception in setUp() function
  * Fix condition of Swift SLO API tests run
  * Add support for image deactivate and reactivate
  * Check domain's enabled attribute strictly
  * Check IPv6 mupltiprefix feature
* Mon Jun  8 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev155:
  * Add test_port_list_filter_by_ip test
* Sat Jun  6 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev153:
  * Unskip test skipped because of closed bugs
  * Fixing some tests for DHCP IPv6
* Fri Jun  5 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev149:
  * Fix Nova API misimplementation for security groups
* Thu Jun  4 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev147:
  * Raise baremetal.unprovision_timeout default to 300 sec
  * More Javelin Unit tests
* Wed Jun  3 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev143:
  * Deleting ports before deletion of routers in resource_cleanup
* Tue Jun  2 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev141:
  * Check only for added/deleted metadata entries
  * Verbose waiting for status in neutron FWaaS
  * Fix server creation n test_large_ops
* Mon Jun  1 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev135:
  * Do not consider subnets of shared public nets
  * Verify exact match for volume metadata update
* Sat May 30 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev131:
  * Remove extra return value from scenario call to show_router
  * Apply a list_image_members rule of GET to image client
  * Apply a show_image rule of GET to clients
  * Remove heat-slow tox entry
  * Extend PATH and set -o pipefail in linux ssh
  * Add OS_TOP_LEVEL to testr conf
* Fri May 29 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev121:
  * Add config option to disable network isolation
  * Log instance console when ssh fails in EC2 test
  * Pass wait_until arg in create_test_server call
  * Replace "hardcode" in scenario tests
  * Apply a list_images rule of GET to image client
* Thu May 28 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev111:
  * Fix sample conf file based on new oslo.log release
* Wed May 27 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev110:
  * Remove skip for bug 1439371 on test_volume_boot_pattern
  * Fix typo in skip_checks function of BaseTestCase class
  * Fixing wrong cleanup order in test "test_rebuild_server"
  * Make sure filtered_by_ip list servers test uses correct ip filter
* Tue May 26 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev102:
  * Add domains negative test
  * Added test of default domain in Keystone
  * Image properties in scenario tests
* Sun May 24 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev96:
  * Move remaining schema files into v2_1 directory
* Fri May 22 2015 rsalevsky@suse.de
- Update to version tempest-4.0.1.dev94:
  * Add test caller to scenario manager ssh connection failure for tracking
  * Fixing broken Heat tests for Swift resources
  * isolated creadentials are not cleaned up
  * Fix typo in cleanup_service class name
  * Ensure scenario utils creds are cleaned up
  * Tool for generation user accounts from spec
  * Extend credentials to support roles
  * Move identity_version to class level
  * Add py34 to readme, pkg metadata, and envlist
  * To test bootable flag in a cinder volume
  * Adds unit test for Javelin
  * Add cleanup after creating keypair
  * Fix tenant isolation and unit tests with py3
  * Added cleanup for tenant quotas
* Wed May 20 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev70:
  * Only create a TokenClient if api_v2 is enabled
* Sat May 16 2015 dmueller@suse.com
- install accounts.yaml
* Sat May 16 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev68:
  * Don't create network resources for scenario utils
* Fri May 15 2015 dmueller@suse.com
- fix lock_path
* Fri May 15 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev66:
  * Fix doc issue of lock test accounts
* Thu May 14 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev64:
  * Fix last unit tests on py34
  * Fix raise syntax in test.py for python3 compat
  * Introduce creds_provider in test.py
  * Extend get_client_manager to support roles
  * Remove unused wrapper methods
* Wed May 13 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev54:
  * Use six.moves.builtins to mock open in unit tests
  * Add new config option to globally trigger resource validation
  * Updated from global requirements
  * Fix tenant isolation and unit tests with py3
  * Drop use of 'oslo' namespace package
* Tue May 12 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev45:
  * Switch use of hashing strings to unicode in accounts
  * Switch all uses of iteritems to use six instead
  * Fix comprehension syntax error with python3
  * Switch all uses of urllib and HTMLParser to import from six
  * Fix verify_tempest_config to not leak a tenant
  * Instance ID was corrected
  * Define validation_resources function for ssh validation
  * Trim object storage smoke tests to a small set
  * Rework get_network_from_name() function
* Sun May 10 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev32:
  * Respect configured cred provider in scenario utils
* Sat May  9 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev30:
  * Remove common/ssh.py due to migration to tempest_lib
  * Remove CLI testing once and for all
  * Remove unnecessary force_tenant_isolation
  * Test live migrate on a paused instance
* Fri May  8 2015 dmueller@suse.com
- remove suse-skip-some-tests.diff
* Thu May  7 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev23:
  * Drop v2 and v3 tokens clients
  * Delete server after resize test
* Tue May  5 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev20:
  * Fix logging.conf sample
  * Honour ssh_connect_method in test_baremetal_server_ops
* Sat May  2 2015 cloud-devel@suse.de
- Update to version tempest-4.0.1.dev17:
  * Remove version string from the setup.cfg
  * add image smoke tags
  * Fix typo in scenario manager
  * Drop auth and corresponding unit tests
  * Cleanup fixed_name logic in test_list_server_filters
  * Create a new project for trusts tests
* Fri May  1 2015 cloud-devel@suse.de
- Update to version tempest-4.dev10:
  * trim compute smoke tag
  * remove qos tests from volume smoke tag
  * trim network smoke tests
  * remove smoke tag from admin tests
  * remove smoke tag from negative tests
  * not all scenario tests should be in smoke
  4
  - 
  * Use addCleanup in test_rebuild_server
  * Wait for complete deletion of volume snapshot before deleting volume
* Thu Apr 30 2015 cloud-devel@suse.de
- Update to version tempest-4.dev925:
  * Remove unused methods
  * Initial class creds creation in test base class
  * Switch all uses of httplib to import from six
  * Switch all uses of ConfigParser to import from six
* Wed Apr 29 2015 cloud-devel@suse.de
- Update to version tempest-4.dev917:
  * remove gate tag (part 3)
  * remove gate tag (part 2)
  * remove gate tag (part 1)
* Tue Apr 28 2015 cloud-devel@suse.de
- Update to version tempest-4.dev911:
  * Apply a naming rule of GET to compute clients(a-e)
  * Cleanup some details about the accounts files
  * Switch all uses of urlparse to import from six
  * Switch all uses of StringIO to use it from six
  * Fix non-locking test accounts doc section
  * Add a paragraph on the use of tempest_roles option
  * Adjust registration of ami image in boto tests
  * Allow SSH instance with username and password in scenario cases
* Mon Apr 27 2015 cloud-devel@suse.de
- Update to version tempest-4.dev895:
  * Apply a naming rule of GET to compute clients(a-e
  * Apply a naming rule of GET to telemetry client
  * Fixing spelling errors in messages when tests are skipped
  * remove swift cli tests
  * Direct ssh bash output to /dev/null
  * Add section to config guide for setting up services
  * Add config guide section on service feature enabled sections
  * Add logging of account allocation to accounts provider
  * Add configuration guide sections for more required options
  * Start a tempest config guide networking section
  * Add version and min_version to version API schema
  * Rename an internal method to _helper_list()
  * Decouple Sahara templates test from vanilla plugin
* Wed Apr 22 2015 cloud-devel@suse.de
- Update to version tempest-4.dev871:
  * Fix test accounts unit test race with networks
  * Revert "Test creation of server attached to created port"
  * Apply a naming rule of GET to messaging client
  * Adding port_admin_state_change option to config
* Sat Apr 18 2015 cloud-devel@suse.de
- Update to version tempest-4.dev863:
  * Test creation of server attached to created port
* Fri Apr 17 2015 cloud-devel@suse.de
- Update to version tempest-4.dev861:
  * Update linux client to support basic MTU testing
  * Add network support to the accounts providers
  * Improve logging in fixed_networks
  * FIx Accounts with identity v3 and v2 data in yaml
  * Add new multi ssh configuration options
  * Arrange quotas response schema into one file
  * Rearrange keypairs response schema into one file
  * Deprecates 'format' in Javelin image description
* Wed Apr 15 2015 cloud-devel@suse.de
- Update to version tempest-4.dev842:
  * Fix external connectivity check for dualstack
  * Make this script work with keystone v2 and v3
* Sat Apr 11 2015 cloud-devel@suse.de
- Update to version tempest-4.dev838:
  * Remove EC2 test case that incompatible with Amazon
  * Apply a naming rule of GET to orchestration client
  * Apply a naming rule of GET to volume client
* Fri Apr 10 2015 cloud-devel@suse.de
- Update to version tempest-4.dev832:
  * Prevent failures when running as non-admin
* Thu Apr  9 2015 cloud-devel@suse.de
- Update to version tempest-4.dev830:
  * Rearrange hypervisors response schemas into one file
  * Embed network resoruces and credentials in TestResources
  * Make L3AgentSchedulerTestJSON DVR-aware
  * Skip test_volume_boot_pattern until bug 1439371 is fixed
  * Fix fixed_network bug 1439634 - ipsec issue
  * Remove Sahara CLI tests (migrated)
  * Allows selection of floating IP pool in Javelin
  * Skip test_security_groups_basic_ops for vnic_type=direct of macvtap
* Wed Apr  8 2015 cloud-devel@suse.de
- Update to version tempest-4.dev814:
  * Use network from get_tenant_network in scenario
  * Use the catalog to discover available services instead of get_service
  * Allows Javelin to specify Swift role
* Tue Apr  7 2015 cloud-devel@suse.de
- Update to version tempest-4.dev808:
  * Fix fixed_network bug 1439634
  * L3 Agent Scheduler testcase cleanups
  * Limit tempest.config's use of cfg.CONF
  * Print an error message and fail if network could not be found by name
  * Allow Javelin to create volumes without servers
  * Remove hyphen from rand_name calls in scenario tests
* Sat Apr  4 2015 cloud-devel@suse.de
- Update to version tempest-4.dev796:
  * Rename test_live_block_migration to test_live_migration
  * Change default cirros ssh user
  * Testcase to create domain without description
* Fri Apr  3 2015 cloud-devel@suse.de
- Update to version tempest-4.dev791:
  * Clarify how to resolve a uuid collision
* Thu Apr  2 2015 cloud-devel@suse.de
- Update to version tempest-4.dev789:
  * Use the configured version of identity in stress
* Wed Apr  1 2015 cloud-devel@suse.de
- Update to version tempest-4.dev787:
  * test_accounts_file can be None
  * 1373513 has been fixed, remove skip
* Tue Mar 31 2015 cloud-devel@suse.de
- Update to version tempest-4.dev783:
  * Only use accounts.yaml with locking provider
  * Add API tests for Neutron DVR extension
  * Handle fixed_network edge cases gracefully
  * Update description of Enable block_migrate_cinder_iscsi
  * Remove hyphen from rand_name calls in identity tests
  * Add test for the various config cases of is_admin_available()
* Sun Mar 29 2015 cloud-devel@suse.de
- Update to version tempest-4.dev769:
  * Split resource_setup for network tests
  * Remove hyphen from rand_name calls in compute tests
  * Remove hyphen from rand_name calls in thirdparty tests
  * Non-admin token tests for Keystone API
* Fri Mar 27 2015 rsalevsky@suse.com
- Update to version tempest-4.dev761:
  * Start instances using fixed network when possible
  * Remove hyphen from rand_name calls in baremetal tests
  * Remove hyphen from rand_name calls in image tests
  * Remove hyphen from rand_name calls in volume tests
  * Pass identity_version into get_credentials
  * Support identity_version in credential provider wrappers
  * Refactor floatin_ips V2.1 API response schema
  * Drop any dependency from config in test_credentials
  * Refactor fixed_ips API response schema
  * Rearrange aggregates response schema into one file
  * Adding sudo to command _renew_lease_dhclient in remote_client
  * Remove invalid use of kwargs from image clients
  * Remove remaining CONF references in service_client
  * Use oslo concurrency api to get lock path
  * Updated from global requirements
  * Support v3 in credential providers and subclasses
  * Remove ceilometerclient CLI tests
  * Fix interfaces response schema
  * Rearrange certificates response schema into one file
  * Rename compute response schema dir to v2_1
  * Respect configured credential provider everywhere
  * Remove unused dependency to config module
  * Fixing spelling error in the message when test is skipped
  * Remove redundant calls to clear_isolated_creds
  * Make check_uuid executable
  * Add 'instance_uuid' in show baremetal schema
  * Add 'disabled_reason' in hypervisor schema
  * Allow sress test runner to skip based on available services
  * Fixes a typo and adds proper captilization
  * javelin: don't destroy floating IP resource
- Rebased patches:
  * suse-skip-some-tests.diff
* Thu Jan 29 2015 cloud-devel@suse.de
- Update to version tempest-4.dev293:
  * Fix _create_loginable_secgroup_rule in scenario manager
* Wed Jan 28 2015 cloud-devel@suse.de
- Update to version tempest-4.dev291:
  * Updated from global requirements
  * Add ironic port show by mac address
  * Allow to specify the list of sahara enabled plugins
* Sun Jan 25 2015 cloud-devel@suse.de
- Update to version tempest-4.dev286:
  * Remove CONF values from database client
  * Use server_client clearly for removing server_group
* Sat Jan 24 2015 cloud-devel@suse.de
- Update to version tempest-4.dev283:
  * Remove CONF values from network client
* Fri Jan 23 2015 cloud-devel@suse.de
- Update to version tempest-4.dev282:
  * Remove CONF values from compute clients
* Thu Jan 22 2015 cloud-devel@suse.de
- Update to version tempest-4.dev281:
  * Update glance_http for SSL
  * update test_volume_boot_pattern to assign one value
  * Skip test_subnet_details
  * Use valid metadata keys for compute images
* Wed Jan 21 2015 cloud-devel@suse.de
- Update to version tempest-4.dev274:
  * Switch rest_client module to tempest-lib
  * Remove RestClientException inheritance
  * Change orchestration client to return one value and update tests
  * Remove CONF values from OrchestrationClient
  * Add compute_quotas lock fixture to test_absolute_limits_negative
  * Use create_test_server in test_max_image_meta_exceed_limit
  * Change compute image client methods to return one value
* Tue Jan 20 2015 cloud-devel@suse.de
- Update to version tempest-4.dev261:
  * Change some compute admin image client methods to return one value
  * Add return one value to volume delete methods
  * Adds scenario for DNS-nameserver configuration
  * Remove JSON-specific code from client settings
* Mon Jan 19 2015 cloud-devel@suse.de
- Update to version tempest-4.dev253:
  * Move tempest_roles options to auth group
* Sat Jan 17 2015 cloud-devel@suse.de
- Update to version tempest-4.dev251:
  * Add explicit cleanup to test_ports
  * Make rest_client module py34-compatible
  * Change volume client methods to return one value
  * Move fake get_credentials methods to test_auth
  * Remove CONF reference in test_rest_client
  * Adds tests create/update port with multiple attributes
  * Create port in allowed allocation pools
  * Test delete of SLAAC subnet without port delete
* Fri Jan 16 2015 cloud-devel@suse.de
- Update to version tempest-4.dev236:
  * Add roles to all tempest created users
  * Move ResponseBody/List classes to service_client
  * Make TestSwiftBasicOps use object_client
* Thu Jan 15 2015 cloud-devel@suse.de
- Update to version tempest-4.dev231:
  * Test port update with new security group
  * Separate tests of negative_rest_client
  * Remove imports of http module
  * Add raw_request() to RestClient
  * Remove all CONF values from RestClient
  * Updated from global requirements
* Wed Jan 14 2015 cloud-devel@suse.de
- Update to version tempest-4.dev219:
  * Floatingip as port fixed ip
* Tue Jan 13 2015 cloud-devel@suse.de
- Update to version tempest-4.dev217:
  * Add image client build timeout config option
  * Change v2 identity client methods to return one value
  * Add test case for floating_ip response body
  * Routers Negative API Test
* Fri Jan  9 2015 cloud-devel@suse.de
- Update to version tempest-4.dev209:
  * Change image client methods to return one value
  * Floating IP Negative Tests
* Thu Jan  8 2015 cloud-devel@suse.de
- Update to version tempest-4.dev205:
  * Separate NegativeRestClient from rest_client
  * Move _get_region() to NegativeRestClient
  * Remove ObjectClientCustomizedHeader class
* Wed Jan  7 2015 cloud-devel@suse.de
- Update to version tempest-4.dev199:
  * printout testr tests that fail
  * Handle HTTP 415 in rest_client
  * Update sample config
  * Remove AccountClientCustomizedHeader class
* Tue Jan  6 2015 cloud-devel@suse.de
- Update to version tempest-4.dev193:
  * Avoid port_state error in test_create_list_show_delete_interfaces
  * Skip load balancer API test for ipv6 network
* Mon Jan  5 2015 cloud-devel@suse.de
- Update to version tempest-4.dev189:
  * Remove _get_endpoint_type() from RestClient
  * Separate build_interval/timeout from RestClient
  * Updated from global requirements
  * Delete unused schema definition console_output
  * Change v3 identity client methods to return one value
  * Ignore router_interface is not found while cleanup
* Sun Jan  4 2015 cloud-devel@suse.de
- Update to version tempest-4.dev178:
  * Ensure subnet for port security group tests
* Sat Jan  3 2015 cloud-devel@suse.de
- Update to version tempest-4.dev176:
  * Drop ComputeAdmin configs, credentials and manager
* Fri Jan  2 2015 cloud-devel@suse.de
- Update to version tempest-4.dev174:
  * Avoid overlapping subnets in class NetworksTestJSON
  * Adds documentation for Javelin
* Wed Dec 31 2014 cloud-devel@suse.de
- Update to version tempest-4.dev170:
  * Remove python client related logging
  * Preupgrade setuptools in tox tempestenv
  * Remove interface json and set skip_test method
  * Correctly fetch the ips from server
  * Remove Nova v3 API config
* Tue Dec 30 2014 cloud-devel@suse.de
- Update to version tempest-4.dev161:
  * Improves documentation formatting of cleanup.py
* Mon Dec 29 2014 cloud-devel@suse.de
- Update to version tempest-4.dev159:
  * Fixing typo in config.py
  * Add ComputeClient for cleanup
  * Skip personality max limit tests in case no limit
* Fri Dec 26 2014 cloud-devel@suse.de
- Update to version tempest-4.dev151:
  * Refactor custom matchers
  * Fix log message on exception in setUpClass
* Thu Dec 25 2014 cloud-devel@suse.de
- Update to version tempest-4.dev148:
  * Add ObjectStorageClient for cleanup
* Wed Dec 24 2014 cloud-devel@suse.de
- Update to version tempest-4.dev144:
  * EC2: do not assume order in dictionary
  * Fix dhcpv6-stateful tempest test to validate only valid use-case
* Tue Dec 23 2014 cloud-devel@suse.de
- Update to version tempest-4.dev140:
  * Add VolumeClient for cleanup
  * Improve error message on exception raised by get_default
  * Actually attach a volume to an instance before taking snapshot
  * DHCP6 Tests fail to remove DVR ports
  * Test wrong IP version of prefix in security rule
* Mon Dec 22 2014 cloud-devel@suse.de
- Update to version tempest-4.dev130:
  * Add note about build_timeout
* Sat Dec 20 2014 cloud-devel@suse.de
- Update to version tempest-4.dev128:
  * Add IdentityV3Client for cleanup
  * Change neutron client methods to return one value and update tests
  * Reorder setup and cleanup functions for readability
* Fri Dec 19 2014 cloud-devel@suse.de
- Update to version tempest-4.dev123:
  * Fix slowest test output after test run
  * Add a word "Test" to metering test classes
  * Remove unnecessary setting from CredentialsTests
  * Add Test to Create Port with no security groups
  * Fix rebuild server tests for wrong input
  * Use isolated creds for dashboard scenario
  * Fix ipv6 network scenario in multi-network environment
  * Do not test the metadata_items limit when there is no limit
  * Do not test the maxImageMeta limit when there is no limit
  * DHCPv6 network tests
* Thu Dec 18 2014 cloud-devel@suse.de
- Update to version tempest-4.dev104:
  * Remove Nova v3 API schemas
  * Remove Nova v3 API clients
  * Remove Nova v3 API tests
* Sun Dec 14 2014 cloud-devel@suse.de
- Update to version tempest-4.dev101.gab6106d:
  * Skip IPv6 scenarios for baremetal
  * Remove use of 'cls.enabled = False'
* Sat Dec 13 2014 cloud-devel@suse.de
- Update to version tempest-4.dev99.g59101f7:
  * Remove Nova v3 API code from RestClient
  * Raise a new exception NotImplemented for HTTP501
  * Remove XML related code from RestClient
  * Updated from global requirements
* Fri Dec 12 2014 cloud-devel@suse.de
- Update to version tempest-4.dev91.ge869ff3:
  * Bump working version to 4
  * Change rest client exceptions' inheritances
  * Move safe_body() into specific class
  * Make InvalidServiceTag inherit from TempestException
  * Framework for staged setup
  * Use assertIn to check for subnet membership
  * Remove network debug
  * Handle pagination keys in lister response
  * Adds scenario for IPv6 addresses
* Thu Dec 11 2014 cloud-devel@suse.de
- Update to version tempest-3.dev75.g10c0e4f:
  * Remove unused TOKEN_CHARS_RE
  * Check that the number of fixed_ips is at least one
  * Skip test_update_router_admin_state for baremetal
* Wed Dec 10 2014 cloud-devel@suse.de
- Update to version tempest-3.dev70.gfc7d4ff:
  * Temporarily disable service-type test
  * Ensure extension aliases are used for nova based services
  * Revert "Log the credentials used to clear networks"
  * Add more verbose info for wait_for_..._status methods
  * Ironic: Remove few misguided negative tests on ports
  * Test to create bulk port
  * Basic networks Scenario Test Enhancements
  * Firewall as a service API Test Enhancement
  * Scenario manager: catch Exception in get_remote_client
* Tue Dec  9 2014 cloud-devel@suse.de
- Update to version tempest-3.dev52.g3dd8545:
  * Remove Volume V1 specific test base classes
  * Log the credentials used to clear networks
  * Support creating users with a default_project_id
  3
  - 
* Fri Dec  5 2014 cloud-devel@suse.de
- Update to version tempest-3.dev233.ga7db669:
  * Add ca_certificates_file option to test against SSL servers
* Thu Dec  4 2014 cloud-devel@suse.de
- Update to version tempest-3.dev232.g70f996c:
  * Remove unnecessary secgroup attrs from scenario tests
* Wed Dec  3 2014 cloud-devel@suse.de
- Update to version tempest-3.dev230.g69f3e78:
  * Port API Test Enhancement
  * add cinder v2 api tests for volume_services
  * Fixing casual failing of nc service in LBaaS
  * Security Group ICMP validation for icmp-code
* Wed Dec  3 2014 cloud-devel@suse.de
- Update to version tempest-3.dev222.g12f862b:
  * Make policy client methods return one value, and fix tests
  * part-2 expect badRequest in server metadata test
  * Use volume_id rather than volume_name in volume extensions timeout
  * Adapt negative testing documentation
  * Use a compute service type from tempest.conf
  * Respect auth.allow_tenant_isolation
  * Remove not used attribute _schema_file
  * Expand service validation to work for Nova cells
  * Dashboard login page assert string fix
  * Cleanup class resources for large-ops scenario
  * Added neutron cli test case for fwaas
  * Moved init_conf call and preserve tempest network objects
* Tue Dec  2 2014 cloud-devel@suse.de
- Update to version tempest-3.dev198.g7861870:
  * Fix print name of ResponseBody object
  * Expect badRequest in server metadata negative test
  * Add code to enable single-value response for http clients
  * Fix error message when isolated tenant subnet creation fails
* Sat Nov 29 2014 cloud-devel@suse.de
- Update to version tempest-3.dev190.ge5af625:
  * Remove unnecessary parameters on create_volume API
  * Take InstanceType for launchconfig res creation
* Fri Nov 28 2014 cloud-devel@suse.de
- Update to version tempest-3.dev187.g8fa6c03:
  * use built in HTMLParser instead of lxml
  * Remove unused xml config options
  * Enable cinder v2 api tests in volume quotas
  * Fix doc for usage of python clients in scenario tests
  * Add a shelve/unshelve scenario
* Thu Nov 27 2014 cloud-devel@suse.de
- Update to version tempest-3.dev178.ge4119b6:
  * remove xml_utils and all things that depend on it
  * purge xml clients from tempest.clients
  * part 2 of delete xml
  * delete all compute xml tests
  * Skip test_volume_boot_pattern until bug 1373513 is fixed
* Wed Nov 26 2014 cloud-devel@suse.de
- Update to version tempest-3.dev168.g5e27849:
  * rm pyc files before test runs
  * Unified interface for ScenarioTest and NetworkScenarioTest
  * Update documentation for clarity
  * Updated from global requirements
  * Use standard assertVolumeStatusWait for volume detachment
  * Security Groups API Tests Enhancements
  * enable cinder v2 api for test_volumes_backup
  * Sync latest log module from oslo-incubator
  * Add Conflict exception in test_floating_ips_actions case
* Sat Nov 22 2014 cloud-devel@suse.de
- Update to version tempest-3.dev150.g9981e16:
  * Add check for too_slow_to_test flag on swift notification test
* Fri Nov 21 2014 cloud-devel@suse.de
- Update to version tempest-3.dev149.g9be1c23:
  * Add scenario test for swift-proxy ceilometer middleware
  * Support for IPv6 tests for API
* Thu Nov 20 2014 cloud-devel@suse.de
- Update to version tempest-3.dev145.g98f3931:
  * Add internal methods for setting identity clients
  * Add internal methods for setting volume clients
  * Add config options for XML support in Keystone
  * Ignore NotFound during network cleanup on API
  * Enable cinder v2 api for volume type extra specs tests
  * Enable v2 api for volume and snapshot tests
  * Fix inheritance for BaseTestCase
  * Move common compute clients to the setting method
  * Enable cinder v2 api for volume hosts
  * Adds test for deleting external network with floatingIPs
  * Updated from global requirements
  * Adds doc for public_router_id in tempest.conf
  * Update README.rst for generating sample conf file
  * Add internal methods for setting compute clients
  * Attempt to test live_migration by default
  * skip test_server_cfn_init as the failure rate is too high
  * Delete console negative tests
  * Make every swift clients use expected_success
  * enable cinder v2 api for volumetype test
  * Fix invalid URL in AccountClientCustomizedHeader
  * Use addCleanup when running swift scenario tests
  * Make delete_container use expected_success
  * Fix empty string as id in create flavor request
  * Creating individual resources for vpnaas test case
  * quota testcases use tenant_name should use tenant_id
  * Update docs for regenerating sample conf file
  * Decouple resources and preconditions in secgroup scenario
  * Revert "Skip test_list_server_addresses if neutron"
  * Adds "list external networks" test to regular user
  * Remove "Disabled Reason" from test_cinder_service_list
* Sat Nov 15 2014 cloud-devel@suse.de
- Update to version tempest-3.dev73.g816131c:
  * Stop resource leakage for negative tests
  * Fixes grammatical errors in HACKING.rst
  * Remove a redundant KeyPairsV3ClientJSON
  * Fix tox stress invocation to not quote arguments
  * Skip some tests when cinder is not enabled
  * Use "ip" instead of "ifconfig" to get MAC address
* Fri Nov 14 2014 cloud-devel@suse.de
- Update to version tempest-3.dev61.ga462b9d:
  * Fixes volume client in volume tests
  * Don't setup identity v3 client if v3 is disabled
  * Fix service validation schema
* Thu Nov 13 2014 cloud-devel@suse.de
- Update to version tempest-3.dev55.g1e6d39e:
  * javelin2: destroy functions above network resources
  * javelin: add network and secgroup resources
  * Adds test for list/get volume attachments V2 APIs
* Wed Nov 12 2014 cloud-devel@suse.de
- Update to version tempest-3.dev49.g31a91ee:
  * Fixed a comment on dirty logs list
  * Create subnet without gateway and explicit IP ver
* Tue Nov 11 2014 cloud-devel@suse.de
- Update to version tempest-3.dev45.gf306a23:
  * Remove ephemeral size assertion in baremetal scenario
* Sat Nov  8 2014 dmueller@suse.com
- Update to version tempest-3.dev43.g7cbc5a4:
  * Add wait for async secgroup add to minimum basic scenario
  * Increase the 'all' timeout because slow tests are included
  * Change CLI tests to use auth providers
* Mon Nov  3 2014 dmueller@suse.com
-  0001-Adjust-oslo-logging-to-provide-adapter-is-enabled-fo.patch
* Sat Nov  1 2014 dmueller@suse.com
- Update to version tempest-3.dev38.geef8381:
  * Correct docstring indentation
  * Fix the flavor ram string value
  * Add list-networks test for os-networks API
  * Switch to using subunit-trace from tempest-lib
  * Migrate cli test framework to tempest-lib
  * Fix and re-enable test_disassociate_not_associated_floating_ip
* Wed Oct 29 2014 cloud-devel@suse.de
- Update to version tempest-3.dev26.gfde24dd:
  * Allow some lag for floating IP to reach a status
  * Adds method to verify multiple tenants are available
  * Include 207 in http success status code RFC-4918
* Mon Oct 27 2014 cloud-devel@suse.de
- Update to version tempest-3.dev20.g912cb93:
  * Fix missing usage of the xml neutron clients
  * Remove checking of non empty resp body for 204
  * Add config option for XML support in Networking
  * Fix AttributeError when test_function_help fails
  * Fix resource leakage in messaging.test_queues
  * Remove AltManager class from client
  * Bump version string to coincide with kilo release
  2
  - 
  * Make duration in serial test approximate total run time
  * Add cleanup to test_verify_multiple_nics_order
  * Remove PYTHONHASHSEED=0 from tox pep8 job
  * Log identifiers of resources being cleaned up
  * Add list servers to large ops test
  * Fix execute status of cleanup script files
  * Don't double log API request
  * Port API Tests Enhancements
  * Remove OfficialClient dependency from HACKING.rst
* Fri Oct 17 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1285.g4b53c89:
  * Move tempest to oslo-config-generator
  * enable cinder v2 api for test_multi_backend
* Thu Oct 16 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1281.g9aeebd7:
  * Make rest_client.wait_for_resource_deletion timeout error more specific
  * Add a server console-log test with unlimited length
  * Don't use a specific arg list for stress in tox.ini
  * Fix duplicate ref of volume_types_client in vol tests
  * Clean up tox.ini and make tempest and unit test distinct
  * Easier to read console output
* Wed Oct 15 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1269.g9b0aed3:
  * Add missing space to build_timeout description
  * Fix cleanup for EC2 test_compute_with_volumes
  * Move status check to client for "messaging" tests
  * Orchestration use stack timeout waiting for ping response
  * Add expected response checks of secgroup rules
  * Adds status check for FloatingIP in network scenarios
  * Fix finding router for scenario tests
* Wed Oct 15 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1255.g4afe75c:
  * Verify network interfaces are in requested order
  * Adds TestSecurityGroupsBasicOps created VM's security_groups check
  * Add exceptions.BadRequest to the test case of reserve_fixed_ip
  * Run telemetry in javelin if resources.yaml says so
  * Remove @author tags from copyright statements
  * Add Credentials Provider factory
* Tue Oct 14 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1244.gafb3e83:
  * Revert "Skip telemetry_notification_api test due to bug 1336755"
* Sat Oct 11 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1242.gd40ea28:
  * Allow javelin to run with incomplete resources.yaml
  * Add the start message for debugging net info
* Fri Oct 10 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1238.ge470eb5:
  * Fix verify_tempest_config with disabled services
  * Fix create_user parameters for v3
  * Fixes image create utf-8 multibyte test
* Thu Oct  9 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1232.g41d6aa2:
  * Fwaas API Test Enhancement
* Wed Oct  8 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1230.g6a81d4a:
  * Fix use of kwargs instead of **kwargs
  * Log AttributeError as 'info' instead of 'exception'
* Tue Oct  7 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1226.ge47fc1a:
  * Drop unused safe_setup decorator
  * Separate security group rule test for each args
* Tue Oct  7 2014 dmueller@suse.com
- Update to version tempest-2.dev1223.g41fa16d:
  * Hacking rule to forbid resource unsafe fixtures
  * Remove setUpClass added after cleanup
  * remove heat test_updates tests
  * Migrate cli tests to resource_* fixtures
  * Migrate thirdparty tests to resource_* fixtures
  * Migrate scenario tests to resource_* fixtures
  * Migrate volume API tests to resource_* fixtures
  * Improve IPV6 parity in Security Group testcases
  * Fix Docstrings for test_server_basic_ops.py
  * Remove Resp status code checks in stress tests
  * Don't parse config file if it doesn't exist
  * Fix schema definition admin_flavor_create
  * Reduce complexity during import phase
  * Fix MismatchError for LB scenario test
  * Fix use of code name in services decorator
  * Add tempest post-run cleanup script
  * Fix arguments for method expected_success
* Thu Oct  2 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1190.ga3cca56:
  * Use shared values for test_security_group_rules
  * skip cfn_init test, it is failing too much
  * Revert "Add "reboot_instance" EC2 API test"
  * Remove "nova-manage flavor list" CLI test
  * Removes deprecated net_common module
  * Drop client_type for auth module
  * Drop OfficialClientManager and references to it
  * javelin: fix user destruction
  * Add an internal test method for rebooting a server
  * Add test list_servers_filtered_by_name_regex
* Wed Oct  1 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1170.g2cae75a:
  * Drop OfficialClientManager from tenant isolation
  * Migrate telemetry API tests to resource_* fixtures
  * Migrate queuing API tests to resource_* fixtures
  * Migrate orchestration API tests to resource_* fixtures
  * Add subnet tests for extra attributes
* Tue Sep 30 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1160.g1a8b6db:
  * disable neutron network tests that fail too much
  * Add a test for deleting a suspended server
  * javelin: Detach the volume before destruction
  * Updated from global requirements
  * Migrate scenario utils to tempest client
  * Fix resource cleanup in server rescue tests
  * Add a test documentation section to the docs
  * Do not run fwaas API tests in smoke
* Mon Sep 29 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1144.g07bfc57:
  * Javelin: enable volume resources
  * Rename NeutronScenarioTest to NetworkScenarioTest
  * Drop OfficialClientTest and NetworkTest
  * Stop using intersphinx
  * enable volumes v2 snapshot tests by sharing codes
  * Add bash to tox whitelist_externals
  * Unskip test_update_port_with_second_ip()
  * Make SwiftScenarioTest methods public
  * Work toward Python 3.4 support and testing
* Mon Sep 29 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1126.g58791da:
  * Skip large_ops_scenario if large_ops_number < 1
  * Cleanup leftover dependencies to official clients
  * Add a test for deleting multiple objects by POST method
* Sun Sep 28 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1121.gd1848f0:
  * Add "reboot_instance" EC2 API test
* Sat Sep 27 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1119.gb053376:
  * Add test caller to test_server_cfn_init timeout error message
  * reenable full request/response logging at DEBUG
  * Log deletion errors in clean servers
  * Lock test_resize_server_using_overlimit_* tests on 'compute_quotas'
  * Add response schema for V2 sec grp default rule
  * Unskip test_create_and_get_delete_bucket()
* Fri Sep 26 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1107.gc1f6cd3:
  * Properly preserve trace on error during wait
  * Updates Tempest to match Zaqar's API name change
  * Restoring dashboard tests
* Thu Sep 25 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1101.g9f74390:
  * Remove duplicate _ping_ip_address() methods
  * Migrate object_storage API tests to resource_* fixtures
  * Migrate image API tests to resource_* fixtures
* Thu Sep 25 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1095.ga46e3fb:
  * Migrate test_load_balancer_basic to tempest client
  * Drop autoscaling scenario test
  * Migrate data_processing API tests to resource_* fixtures
  * Migrate database API tests to resource_* fixtures
  * Migrate TestStampPattern to tempest client
* Wed Sep 24 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1085.g6a12cc9:
  * Migrate baremetal_basic_ops to tempest clients
* Wed Sep 24 2014 dmueller@suse.com
- Update to version tempest-2.dev1083.gd3b399d:
  * Replace wait with communicate to avoid potential deadlock
  * Migrate baremetal API tests to resource_* fixtures
  * Migrate network API tests to resource_* fixtures
  * Migrate identity API tests to resource_* fixtures
  * Migrate computev3 API tests to resource_* fixtures
  * Removes bogus negative create image compute
  * Fix scenarios not passing down specific network
  * Backward compatibility to credentials in conf
* Mon Sep 22 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1067.gcf1bfa3:
  * Migrate computev2 API tests to resource_* fixtures
* Mon Sep 22 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1065.g465ec2e:
  * Delete baremetal resources in correct order
  * Add missing baremetal API tests
* Sat Sep 20 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1061.g5caf1e7:
  * Typo fixes "tryies", "snaphot", "Retruns"
  * Make cli test namespace include test files
  * Framework for resource safe class level fixtures
  * Migrate test_server_cfn_init to tempest clients
  * Fix unstable assertion in test_cinder_endpoints
  * Make output from check_logs less verbose
* Sat Sep 20 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1049.g6e0787e:
  * Remove PYTHONHASHSEED=0 from tox.ini
* Fri Sep 19 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1047.g3d670cb:
  * Select AuthProvider type from credentials type
  * Unskip test_rescope_token()
* Thu Sep 18 2014 dmueller@suse.com
- Update to version tempest-2.dev1043.g595d736:
  * Fail tempest if 0 tests are run
  * Update Heat CLI test to pass with random hash
  * Unskip test_stack_update_add_remove()
  * Properly print STDOUT and STDERR in test_wrappers
  * Migrate test_large_ops to tempest client
  * large ops test should be derived from OfficialClientTest
  * Support lack of ephemeral volumes for baremetal
  * Change LOG.exception to LOG.info for skipped tests
  * Replace confusing member name
  * Remove redundant waiter in create_volume cleanup
  * Allow new quota types
  * Have the EC2 instance test to wait for termination
  * Migrate advanced server network to tempest clients
  * Migrate test_encrypted_cinder_volumes to tempest client
  * Move javelin2 over to use oslo logging
  * Move success response checking to the token client
  * Cleanup neutron default security groups on tenant deletion
  * Fix tox coverage job
  * Allow FWaaS API test to accept more than one end state
  * Remove test start output in pretty tracer
  * Fix errors on import with service tags
* Sat Sep 13 2014 cloud-devel@suse.de
- Update to version tempest-2.dev1001.g4d1d242:
  * VolumeMultiBackendTest: delete error volumes
* Fri Sep 12 2014 dmueller@suse.com
- Update to version tempest-2.dev999.g86921b0:
  * Skipping dashboard test to unblock gate
  * Better timeout exception in wait_for_resource_deletion
  * javelin: fix object destruction
  * Migrate security_groups_basic to tempest clients
  * Add baremetal API tests about console
  * Move cli tests into service subdirectories
  * Move response code checking to client for v3 identity tests
  * Check port's status also in show port tests
  * Remove force_tenant_isolation=True from test that doesn't need it
  * Verify network connectivity before state check
  * Only log console log if nova supports consoles
  * Avoid to iterate over empty list in DictMismatch
  * Add a NotLockingAccounts credentials provider
  * Fix use of nonexistent class variable in accounts
  * Fix TypeError in TestVolumeBootPattern
  * Fix V2 hypervisor server schema attribute
  * Some scenario tests do not delete network resources
  * Make unit tests not depend on random hash seed
  * Adds the clients and tests for CINDER QoS V1 & V2 APIs
  * Fix load balancer scenario if no tenant network
  * Fix network/secgroup scenario tests for ironic
  * Allow out of quota failure status code to be 413 or 403
  * Fix IPv6 default masks for SLAAC
  * Adds v2 keystone service test to service v3
  * Fix response body format of orchestration_client to dict
  * Use safe_setup instead try block in setUpClass
  * javelin: implement resource destruction
  * Heat SwiftResources : only count containers created by Tempest
  * Refactor ways of creating anonymous test user
  * Improve the selectability of Swift tests
* Fri Sep  5 2014 cloud-devel@suse.de
- Update to version tempest-2.dev935.ga5c669d:
  * Properly detect grenade in check_logs script
* Thu Sep  4 2014 cloud-devel@suse.de
- Update to version tempest-2.dev934.gb3ae2ce:
  * Migrate test_network_basic_ops to tempest clients
  * Fix "mutable" object as default value
  * Add a check_telemetry method to javelin
  * Removes test_force_delete_server_invalid_state negative test
* Tue Sep  2 2014 cloud-devel@suse.de
- Update to version tempest-2.dev926.g45dcf11:
  * remove default=None for config options
* Tue Sep  2 2014 cloud-devel@suse.de
- Update to version tempest-2.dev924.gaf1fcc7:
  * Migrate test_server_advanced_ops to tempest client
  * Adds Ironic set/get boot device API test
  * Add a test for inline parameter of TempURL
  * Updated database clients for bp client-checks-success
  * Adds an orchestration API test for resource types
  * test_neutron_resources to read template's values
* Mon Sep  1 2014 cloud-devel@suse.de
- Update to version tempest-2.dev912.g6e41803:
  * Add _interface attribut in BaseNetworkTest
* Sun Aug 31 2014 cloud-devel@suse.de
- Update to version tempest-2.dev910.g0684c14:
  * Migrate test_volume_boot_pattern to tempest client
  * Migrate test_server_basic_ops to tempest client
  * Rename Marconi to Zaqar
* Sat Aug 30 2014 cloud-devel@suse.de
- Update to version tempest-2.dev904.gdb0604b:
  * Extract SwiftScenarioTest class to manager
  * Fix hardcoded gateway in IPV6 subnet api tests
* Fri Aug 29 2014 cloud-devel@suse.de
- Update to version tempest-2.dev900.gf0536c7:
  * Add REVIEWING.rst
  * Add functools.wraps on all function decorators
* Thu Aug 28 2014 cloud-devel@suse.de
- Update to version tempest-2.dev896.gcd235c7:
  * Catch BadRequest exception from correct module
  * Remove functionality to load json files
* Thu Aug 28 2014 cloud-devel@suse.de
- Update to version tempest-2.dev892.g9c1ce58:
  * Ensure proper ordering of XML arguments
  * Adds support for custom image formats in scenarios
  * Fixes Hyper-V basic scenario volume partition name
  * Add service tags to tempest/api/orchestration/stacks
* Wed Aug 27 2014 tbechtold@suse.com
- Update to version tempest-2.dev884.ge41007c:
  * Client response checking for orchestration service
  * Move API response success check to Neutron client
  * Add cases for Swift scenario test
  * Add sec-group rules for ping6 and ssh -6
  * missing network configuration in telemetry tests
  * Add network's status check after creation of network
  * Remove test_db_archive_deleted_rows
  * Use list comprehension in create_bulk_networks
  * Add compute tags to tempest/api/database/flavors test
- Refresh suse-skip-some-tests.diff
* Mon Aug 25 2014 bwiedemann@suse.com
- use %%_rundir if available, otherwise /var/run
* Sun Aug 24 2014 cloud-devel@suse.de
- Update to version tempest-2.dev867.gba4cdee:
  * Revert change to get_remote_client()
  * Ensure PYTHONHASHSEED=0 for the 'all' tox env
  * Updated the baremetal client for bp client-checks-success
  * Migrate test_snapshot_pattern to tempest client
  * Don't use swift roles when no swift
  * Running without keystone v3 doesn't require uri_v3
* Sat Aug 23 2014 cloud-devel@suse.de
- Update to version tempest-2.dev855.gbf98eb7:
  * Add glance tag to test_server_actions
  * Migrate test_minimun_basic to tempest client
  * Fix "NotFound" error in _clear_stacks()
  * Migrate swift scenario test to tempest client
  * Use python abc in DeletableResource class
  * Use python abc in StressAction class
  * Remove not used server creation from test_server_rescue
* Thu Aug 21 2014 cloud-devel@suse.de
- Rebased patches:
  + 0001-Avoid-unneeded-use-of-set-and-use-list-instead.patch dropped (merged upstream)
* Thu Aug 21 2014 cloud-devel@suse.de
- Update to version tempest-2.dev841.g9cfa75e:
  * test_hotplug_nic wait for the guest
  * Change default size for strings to 1
  * Supports DEFAULT group opts in TempestPrivateConfig
  * Convert request schema (servers)
  * Convert request schema (flavors_admin)
  * Avoid unneeded use of set, and use list instead
  * Change 'ceilometer' tag to 'telemetry' and add tags to cli tests
  * Add network tags to test_quotas_negative
* Wed Aug 20 2014 cloud-devel@suse.de
- Update to version tempest-2.dev825.geb3f2cd:
  * Update volume client check success
  * Add MatchesDictExceptForKeys custom matcher
  * Deacrease the required image store size by 4 GiB
  * Add os-networks JSON client for tempest
  * Add new snapshot compute feature flag
  * Disable hacking rule H305
* Tue Aug 19 2014 cloud-devel@suse.de
- Update to version tempest-2.dev813.gfbd4233:
  * Migrate test_aggregates_basic_ops to Tempest clients
  * Relax check for router interface in _verify_network_details
* Mon Aug 18 2014 cloud-devel@suse.de
- Update to version tempest-2.dev809.g485a1e6:
  * Convert request schema (flavors)
* Sat Aug 16 2014 cloud-devel@suse.de
- Update to version tempest-2.dev807.gfcd64c0:
  * Add ironic instance rebuild test
  * Allow dict's as schema definitions
  * Enable E128 ignore E129
  * Enable H407,H305,H307,E122 ignore E123
* Fri Aug 15 2014 cloud-devel@suse.de
- Update to version tempest-2.dev800.gf54773c:
  * Revert "Added neutron cli test case"
  * Added neutron cli test case
  * Add console_output compute feature flag
  * Stop leaking identity resources in teardown_all()
* Thu Aug 14 2014 cloud-devel@suse.de
- Update to version tempest-2.dev792.g3226ca1:
  * Remove cleanup code according to TODO comment
  * Add a config option to select compute xml api
  * If no volume, don't delete volume in teardown
* Wed Aug 13 2014 cloud-devel@suse.de
- Update to version tempest-2.dev786.gfceab11:
  * Remove skipping flavor_access_add/remove related tests
  * Add a new credential provider to use a list of creds
  * Add min_client_version decorator for CLI tests
* Mon Aug 11 2014 cloud-devel@suse.de
- Update to version tempest-2.dev780.ge5dc7a3:
  * Remove skipping test_list_servers_by_admin_with_all_tenants test
  * Fix typo in comment
  * Router API Tests Enhancements
  * Move response validation schema's in sub folder
  * Implement javelin2 destroy images
  * Do not isolate networks for baremetal
  * Add interface_attach compute feature flag
  * Skip ceilometer test test_check_glance_v*_notifications
  * Add image-list to glance cli help test
  * Set python hash seed to 0 in tox.ini
  * Allow out of quota failure status code to be 413 or 403
  * More comments to doc strings
  * Enable some volumes v2 tests by sharing codes part2
  * Tag test_nova_keypair_resources as gate, not slow
  * Separate create server schema for admin password
  * Sahara: add API tests for jobs
  * Sahara: preparations for job tests
  * Add new shelve compute feature flag
  * Update compute attach tests to use "volume_device_name"
  * Move baremetal API tests to an /admin subdir
  * Adds new v3 projects tests to Keystone
  * Remove unnecessary log message
  * Add parametric tests of Swift object API, part 4
  * Make unable to ping log messages appropriate level
* Wed Aug  6 2014 vuntz@suse.com
- Add 0001-Avoid-unneeded-use-of-set-and-use-list-instead.patch to
  fix python 2.6 issue.
* Fri Aug  1 2014 cloud-devel@suse.de
- Update to version tempest-2.dev733.ge5d2083:
  * Skip test_rescope_token
  * Fix skip_path logic if path part is empty
* Thu Jul 31 2014 cloud-devel@suse.de
- Update to version tempest-2.dev730.g973c6cd:
  * Allow out of quota failure status code to be 413 or 403
  * Use random binary data for test images
  * Fix javelin2's skip logic in checks
  * Avoid errors in log when neutron tests are skipped
  * Check rescue_server action attributes of Nova APIs
  * Use python abc in auth class
  * Check rebuild server action API attributes
  * Adds test for Sec group default rule Nova V2 API
* Wed Jul 30 2014 dmueller@suse.com
- Update to version tempest-2.dev714.g4d90d67:
  * Move CommandFailed exception to tempest.exceptions
  * Add unit test section to the field guide index
  * Add links to the field guide index
  * Add glance notifications tests for ceilometer
  * orchestration api test_stacks wait for deletion
  * Fix exception when api_extensions is set to empty
  * Call clear_isolated_creds in scenario tests
  * Enable some volumes v2 tests by sharing codes
* Mon Jul 28 2014 cloud-devel@suse.de
- Update to version tempest-2.dev698.g8b31bd5:
  * Run javelin2 check at the end of create
  * Adds "user-password-update" to v3/test_users
  * Add client response checking for data processing service
  * Skip migrate server invalid state if resize is off
  * Fixes incorrect assertion check
  * Add "capabilities:" to multiple_backends extra-spec key
  * Read template's expected value orchest test Part-2
* Sat Jul 26 2014 cloud-devel@suse.de
- Update to version tempest-2.dev682.g5ac9a6f:
  * Make javelin2's ping for longer
  * Make javelin2 create_server wait for server to boot
  * Add destroy_server to javelin2
  * Add logs to javelin2
  * orchestration: tolerate NotFound in wait_for_stack_status
  * Skip telemetry_notification_api test due to bug 1336755
  * Migrate test_dashboard_basic_ops to tempest clients
  * Avoid conflicts with other tests instances
* Fri Jul 25 2014 cloud-devel@suse.de
- Update to version tempest-2.dev666.g72d07d8:
  * Add base class for all credential providers
* Thu Jul 24 2014 dmueller@suse.com
- Update to version tempest-2.dev664.g60b9cca:
  * Revert "Add tests for wait_for_server_status"
  * Delete unused class Service
  * Add config file flag to javelin
  * Log when javelin2 finishes running successfully
  * Make javelin resources optional
  * Make sure cli CommandFailed prints out stdout and stderr
  * Base class for scenario test using Tempest clients
  * Fix a few bugs when running with -u
  * Removed deprecated command from glance cli
  * Re-enable 'check_trust_roles'
  * Read template's expected value orchest test Part-1
* Tue Jul 22 2014 cloud-devel@suse.de
- Update to version tempest-2.dev642.ga438303:
  * Updated from global requirements
  * Create test images via Glance instead of Nova
* Sun Jul 20 2014 cloud-devel@suse.de
- Update to version tempest-2.dev639.gf0e042d:
  * Adds list users tests in v3
  * Add python-ceilometerclient in requirements
* Sat Jul 19 2014 cloud-devel@suse.de
- Update to version tempest-2.dev635.g165a743:
  * Refactor random url generation into its own method
  * Verify get_instance_action attributes of Nova API
  * Added Heat Software Config-Deploy API tests
  * Skip hypervisor uptime test for baremetal
  * Correct misspelled words
  * Correct volume type api schema validation
  * Skip baremetal tests if driver not supported
  * Replace the console output on Error with fault a message
  * Fixed argument parsing in run script
* Fri Jul 18 2014 cloud-devel@suse.de
- Update to version tempest-2.dev617.g4871ae4:
  * Adjust stress test documentation
  * Make javelin check logging a bit better
  * Exclude volume tags while listing instance tags
  * Validate server detail list attribute of Nova APIs
  * cleaning up index.rst file
* Thu Jul 17 2014 cloud-devel@suse.de
- Update to version tempest-2.dev607.g2b86552:
  * Add tests for wait_for_server_status
  * Add three new CLI tests of sahara
  * fix javelin to let you specify imgdir
  * olso log sync
  * Always pass str to shlex.split for py26 compat
  * Remove docutils pin
  * Fix availability zone client in compute admin test
* Fri Jul 11 2014 cloud-devel@suse.de
- Update to version tempest-2.dev593.g9664636:
  * First part of moving success response checking to identity client
  * Change of copyright to HP for keystone regions
  * Add tox job to build docs
* Thu Jul 10 2014 cloud-devel@suse.de
- Update to version tempest-2.dev587.g2663a5b:
  * Add a skip for bug #1334368
  * Sharing codes for volumes list tests
* Wed Jul  9 2014 cloud-devel@suse.de
- Update to version tempest-2.dev583.ge3e9da7:
  * Make os-quota-class-sets test not break quotas
  * Add Ironic show driver API test
* Mon Jul  7 2014 cloud-devel@suse.de
- Update to version tempest-2.dev580.g005958f:
  * Verify list-Floating-IP-Bulk Nova API attributes
  * Improve test isolation in test_networks:BulkNetworkOpsTest*
* Sun Jul  6 2014 cloud-devel@suse.de
- Update to version tempest-2.dev576.gd7285f3:
  * Add querying for lists in ceilometer client
* Fri Jul  4 2014 cloud-devel@suse.de
- Update to version tempest-2.dev574.g63d89fe:
  * Make test_drivers.py use driver name from conf
  * Fix disk_available_least in JSON schemas
  * Convert scenario test tearDown to addCleanup
  * Improve cinder CLI existing tests
  * unskip list server actions tests
  * update iptables rules for more useful debugging
  * Sahara: minor changes for API tests
  * VPNaaS API Tests Enhancements
  * Remove the skip for test_get_instance_action()
  * Add network service tag to compute tests
  * Verify "get a server" API response attributes
  * Improve neutron CLI existing tests
  * Allowed Address Pair API Tests Enhancements
  * Verify V2 list server_group API attributes
  * Add test for compute API os-quota-class-sets
  * Code clean-up of CLI test "cinder list-extensions"
  * Correcting 'id' type in compute schema
  * Adds keystone roles v2 tests in v3
  * lbaas basic - open firewall for http on vip port
  * Extending quota support for neutron LBaaS entities
* Thu Jul  3 2014 cloud-devel@suse.de
- Update to version tempest-2.dev534.gbd21fbd:
  * Fix "create a flavor" tests for strong validation
  * Add a hacking check to block scenario manager in api tests
  * botoclient does not honor disable_ssl_certificate_validation
* Wed Jul  2 2014 cloud-devel@suse.de
- Update to version tempest-2.dev528.g8520a48:
  * Add skip decorators in test_servers_negative
  * Fix race condition in flavor tests
  * Verify delete-Floating-IP-Bulk Nova API attributes
  * Adds scenario tests for volume encryption
  * Fix calls to mock.assert_not_called()
* Tue Jul  1 2014 dmueller@suse.com
- Update to version tempest-2.dev518.ge64601f:
  * add py27 to default tox
  * Correct nc command in test_load_balancer_basic
  * Fixes Scoping bugs
  * Missing node driver interface validation API
  * Avoid snapshotting from compute authorization test
  * Added service "data_processing" to service list
  * Sahara: add API tests for job binaries
  * Enable GET port_detail API to set parameters
* Sun Jun 29 2014 cloud-devel@suse.de
- Update to version tempest-2.dev502.gbdc64b3:
  * Add 'id' to the server group cleanup list, not body
  * Add Tests for Message & Claim APIs
  * Add 'Member' role to all created users
  * Tempest API tests: Add ipv6 attribute tests
* Sat Jun 28 2014 cloud-devel@suse.de
- Update to version tempest-2.dev494.gda60377:
  * Add caller to v1 image_client wait_for_image_status timeout exception
  * Require stevedore for check_uptodate.sh
  * Skip quota-out tests temporary to change error codes
  * Drop unused admin client in server metadata tests
* Fri Jun 27 2014 cloud-devel@suse.de
- Update to version tempest-2.dev486.g1d30c65:
  * javelin: create and attach volumes
* Fri Jun 27 2014 cloud-devel@suse.de
- Update to version tempest-2.dev484.g0b46e3d:
  * Avoid empty string for length in os-getConsoleOutput
  * Use config generator rc instead of wrapper script
  * Update config generator from oslo-incubator
  * Add parametric tests of Swift object API, part 1
* Thu Jun 26 2014 cloud-devel@suse.de
- Update to version tempest-2.dev476.gdc3d185:
  * Add client response checking for image service
  * Added swift CLI test cases
  * Handle backup not found in test_create_backup
  * Add "create a server" test with server group
* Wed Jun 25 2014 cloud-devel@suse.de
- Update to version tempest-2.dev468.g079bf98:
  * Verify create agent attributes of V2/V3 APIs
  * provide enough time to do expires in obj tests
  * HEAD doesn't return a body
  * Remove assertTrue from ssh unit tests
  * Add new rescue compute feature flag
  * Fix T104 for scenario test subdirs
  * Don't try to trace non-printable characters in debug output
  * Bump baremetal power/assoc/unprovision timeouts
  * Add README section about API stability
  * Don't store duplicate policies for server_group
* Mon Jun 23 2014 dmueller@suse.com
- add suse-skip-some-tests.diff
* Sat Jun 21 2014 cloud-devel@suse.de
- Update to version tempest-2.dev449.gf783013:
  * Updated from global requirements
  * Use the http image location conf option for api tests
  * Make test_snapshot_pattern ssh error path work
  * Skip case for fixing incorrect exception assertion
  * make logformat more similar to oslo
  * Add branchless tempest section to README.rst
* Fri Jun 20 2014 cloud-devel@suse.de
- Update to version tempest-2.dev438.gfe3a91c:
  * Add Ceilometer client for scenarios tests
  * Force connection auth as part of RemoteClient in scenario
  * Check create-Floating-IP-Bulk Nova API attributes
* Thu Jun 19 2014 cloud-devel@suse.de
- Update to version tempest-2.dev433.g787852f:
  * Enable E251,E265 rules ignore H402
  * Sharing codes for cinder v1 and v2 tests
  * Enable E113,E111,H302,F812,E713 rules
  * Don't include boto tests as part of smoke tests
  * Verify list_instance_action attributes of Nova API
  * Use known flavor ID as marker
  * Sync versionutils from oslo-incubator
  * Adds test for Floating Ips bulk Nova V2 API
* Wed Jun 18 2014 cloud-devel@suse.de
- Update to version tempest-2.dev417.gacc0e28:
  * Bump hacking to 0.9.x series
  * Unbreak baremetal API tests that were not updated
  * Set default to false for nova v3_api config option
  * Disable isolated_creds.net_resources on network scenarios
  * Sahara: preparations for job binary tests
  * Add total runtime to summary output
  * make 'server' as 'required' in server update schema
  * Add unittests for remote client
  * cleanup on remote_client
  * Check create/get/delete V2 server_group attributes
  * Clarify API extension description of Nova API
  * Nodestate API test for power state set
  * Reworked scenario tests to use their own non-default security groups
  * Enhanced Trove (database) flavor API tests
  * Deduplicate status call checks
  * Check non json type on glance client json_request method
* Tue Jun 17 2014 cloud-devel@suse.de
- Update to version tempest-2.dev385.gc73ee5b:
  * Remove the validate_driver_info test
  * add block_device_mapping to create_server params for nova clients
  * Mising CLI test for Keystone
  * Optimization and response status code update
  * Add cinder CLI tests "qos-list" and "encryption-type-list"
* Mon Jun 16 2014 cloud-devel@suse.de
- Update to version tempest-2.dev375.gdc0a76b:
  * fix usage of allow_tenant_isolation
* Sun Jun 15 2014 cloud-devel@suse.de
- Update to version tempest-2.dev373.g76bf0bc:
  * Cleanup for local variable in test_attach_volume
  * Convert get_console_output length=None to -1 for Nova V3 API calls
  * Use a more sensible network topology for some router tests
* Sat Jun 14 2014 cloud-devel@suse.de
- Update to version tempest-2.dev367.g2ea4225:
  * Heat Overlapping ip issue
  * VPNaas IPSec policies tests
  * tests the Keystone extensions V2 API
  * Sahara: add API tests for job binary internals
* Fri Jun 13 2014 cloud-devel@suse.de
- Update to version tempest-2.dev359.g2c75b7c:
  * Fix warnings from build_sphinx
  * adds the missing _interface variable
  * Sahara: add API tests for cluster templates
  * Add veritification to name property in cinder volume
* Thu Jun 12 2014 dmueller@suse.com
- Update to version tempest-2.dev351.g1f8688f:
  * Fix update_server JSON Schema for Nova V2
  * Change how tempest debug logs are displayed
  * Use correct base test class for test_stress unit tests
  * Consolidate _check_tenant_network_connectivity in NetworkScenarioTest
  * Consolidate _check_public_network_connectivity into NetworkScenarioTest
  * Add bug skip for test_container_synchronization()
  * Make run_stress.py script an entry point
  * provide ability to tweak oslo log defaults
  * Place baremetal common methods in base class
  * dump console if we time out on a server op
  * Add CLI test of "nova server-group-list"
  * Add compute notifications tests for ceilometer
  * Verify 'update-server-metadata' APIs attributes
  * Test script for CRUD operations on regions
  * Use old dict generator syntax in baremetal/test_ports
  * Remove nova v2 client in ListSnapshotImagesTest
* Tue Jun 10 2014 cloud-devel@suse.de
- Update to version tempest-2.dev321.g798446b:
  * Revert "don't reuse servers in test_server_actions"
* Sat Jun  7 2014 cloud-devel@suse.de
- Update to version tempest-2.dev319.g35ea84f:
  * Revert "Fail fast during advanced networking test"
  * don't reuse servers in test_server_actions
  * Add missing compute service tags to volume API tests
  * Wait for server activations for the updated servers
  * Add API test for resizing a stopped server
* Thu Jun  5 2014 cloud-devel@suse.de
- Update to version tempest-2.dev309.ga7d3292:
  * Remove the list_servers_since_test
  * adds tests for CINDER encryption volume-type APIs
* Wed Jun  4 2014 cloud-devel@suse.de
- Update to version tempest-2.dev305.g6654c35:
  * Upload public image requires admin role by default
  * Relax security group rules cleanup
  * test_aggregates_basic_ops picks a non compute node
  * Verify server list_addresses V2/V3 APIs attributes
  * Start using oslotest for tempest unit tests
  * Switch back to nc in test_load_balancer_basic
  * Fail fast during advanced networking test
  * modifies the test to sort based on UUID
* Sat May 31 2014 dmueller@suse.com
- Update to version tempest-2.dev289.gaf6d14d:
  * javelin 2
  * allow for arbitrary kwargs in image client
  * Updated from global requirements
  * Sahara: minor changes for API tests
  * allow 'main' as valid name for find_test_caller
  * log request start when tracing classes
  * Remove dependency on keyring
  * validate server action 'console_output' attributes
  * Cleanup docstring in test_l3_agent_scheduler
  * Sahara: preparations for job binary internal tests
  * Sahara: add API tests for data sources
  * Remove time.time mock from test_ssh
  * add test for command bash-completion
* Fri May 30 2014 cloud-devel@suse.de
- Update to version tempest-2.dev264.g5cff5ca:
  * Verify delete security group response of V2 API
  * Remove default from image_ref options
  * Fix sudo_cmd_call in tempest.common.commands
  * set all build_intervals to 1s
  * remove skip attributes for fixed bug
  * Add quota delete test to cinder
  * Add Marconi Smoke Tests
  * Add tests for availability-zone-list CINDER V1 API
* Wed May 28 2014 cloud-devel@suse.de
- Update to version tempest-2.dev248.g5606a97:
  * Make test_server_cfn_init a scenario test
* Sun May 25 2014 cloud-devel@suse.de
- Update to version tempest-2.dev246.gaa7eb96:
  * Update version string to follow new convention
  1
  - 
* Fri May 23 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev4186.gfc137b5:
  * Verify Server Actions attributes of Nova APIs
  * Revert "Adds certificate tests for keystone v3"
  * Make sure image exists in test
  * Fix security_group_create_get_delete testcase
  * Verify more information in floating ip tests(part2)
* Thu May 22 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev4177.g6c1a8f0:
  * Split large-ops into three tests so each has its own timeout
  * Neutron Allowed Address Pair API test
* Wed May 21 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev4173.g534a17f:
  * Fix alt tenant id's issue in BaseV2MemberImageTest
  * Enable H302 rule everywhere
  * Fix test_create_show_delete_security_group_rule
  * Add hacking import exception for service clients
  * orchestration: add test for untyped provider resources
  * orchestration: Add test for resource_registry environment
* Tue May 20 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev4161.g8606dd8:
  * Use fixed ips for lbaas pool members
* Mon May 19 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev4159.g41e1cb5:
  * orchestration add basic support for environment API test
* Sun May 18 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev4157.gbadd82c:
  * tolerate HTTPNotFound in scenario manager teardown
  * Sahara: editing licenses
  * Adds certificate tests for keystone v3
  * Add tests for server-group Nova V2 APIs
  * tests the user-password-update for Keystone V2 API
* Sat May 17 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev4147.g69b8225:
  * Fix subnet api test case for non-default cidr
  * Fix test case in security groups
  * Volume xml client translate json attribute names
* Wed May 14 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev4141.gb4171c7:
  * Verify more information in floating ip tests
* Tue May 13 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev4139.g3df6ac7:
  * Added Trove (database) version API tests
* Sun May 11 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev4137.g1c1eb99:
  * Get credential IDs from Credentials class
  * Remove tempest_auto_config script
  * Share Certificates API's tests between V2 & V3
  * Verify list_addresses_by_network APIs attributes
* Sat May 10 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev4129.ge575327:
  * Fix issues introduced /w migration to Credentials
  * Updated from global requirements
  * Verify the response attributes of 'aggregate-add-remove-host' API
  * Add a common admin class for Nova v2/v3 API tests
  * create test and worker summary report
  * Verify "list interfaces" Nova v2/v3 API response attributes
  * Check list servers attributes of Nova APIs
  * Inherit V2 API's flavors tests from V3 tests
  * Inherit V2 keypair API's tests from V3 tests
  * Add test for subnet gateway IPv4 and IPv6
  * Add V3 Test to get Spice & RDP console of server
* Fri May  9 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev4108.gf22b6cc:
  * refactor out code duplication
  * Use find_test_caller to put test name in timeout exception details
  * Verify the response attributes of 'create-aggregate' API
  * Verify update host Nova V2/V3 APIs attributes
  * Add unit tests for tempest hacking checks
  * Access credential fields as attributes
  * Enforces the use of Credentials (part2)
  * Removing unnecessary pass instructions
  * Check for 'Generated' in SSH key comment
  * Improve the extra routes test on router
* Thu May  8 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev4088.g7169d17:
  * Refactor _find_caller into a public test finder utility
  * Sahara: preparations for data source tests
  * VPNaaS API tests cleanup
* Wed May  7 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev4082.g92d3d86:
  * Add in a concurrency aware subunit filter
  * Add compute service tags to ListSnapshotImagesTest
  * Verify "update a server" API response attributes
  * Skip creation of network resources for disabled IPv6 tests
  * Enforces the use of Credentials (part1)
  * Use auth data to fill credentials
  * Define V3 Credentials
  * Add a lacking message format letter 's'
  * ssh_floating verify reboot
  * Adds more testcases to test_telemetry_alarming_api
  * Verify attributes through Nova os-quota-sets API
  * Verify tenant usages API response attributes
  * Unit Tests for glance_http
  * Add network API test to create/update a port with 2 IP addresses
* Mon May  5 2014 dmueller@suse.com
- Update to version tempest-2014.1.dev4054.ga7d0b14:
  * Add noqa support to no_setupclass_for_unit_tests
  * Revert "add server personality files test"
  * Updated from global requirements
  * Add a common class for Nova v2/v3 API tests
  * Separate common 'start_up' definition from v2 schema
  * Add unit tests for verifying extensions list
  * Add unit tests for api_version detection
  * Add unit tests for _get_unversioned_endpoint
  * Add cmd entry point for verify_tempest_config
  * Add support for updating the config file
  * Fix stress runner not stopping on first fail
  * Stress runner/driver prints stats after SIGINT
  * Verify Set/Get/Delete server meta item attributes
  * Add tests for CINDER services v1 APIs
  * Add a response header validation
  * Remove unused arguments
  * Account failure to the tearDown instead of setUp
  * orchestration api add test for volume retain deletion policy
  * Don't output auth tokens with trace output
  * Stop swift resource leaking even if an error occurs
  * Enable security_groups_basic_ops blocking tests
* Wed Apr 30 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev4012.ge3a663b:
  * Skip lbaas test test_load_balancer_basic
  * Verify os-migration API response attributes
* Tue Apr 29 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev4009.g420befd:
  * Remove {begin,roll}_detaching volume API tests
  * Verify create/get flavor attributes of Nova APIs
  * Verify delete aggregate attributes of Nova APIs
* Mon Apr 28 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev4003.gfdcb335:
  * Defines a Credentials class
  * orchestration api add basic volume resource test
  * orchestration api refactor access to stack outputs
  * Verify certificate API response attributes
  * Remove test_create_server_response
* Sun Apr 27 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3993.g4054e62:
  * Verify attributes through Nova os-security-groups API
* Sat Apr 26 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3991.gc0852ca:
  * Verify 'list-server-metadata' APIs attributes
  * Verify the attributes of 'set-server-metadata' API
  * Remove Nova v3 XML test skip
  * Delete OrchestrationManager, and its unusual credentials
  * Fix stress runner signal related issues
  * Verify list agents attributes of V2/V3 APIs
  * Check detail list Images attributes of Nova V2 API
  * Fix test_verify_created_server_ephemeral_disk
  * Consider state in firewall create/delete test
  * Add cinder api version detection to verify_tempest_config
  * Fix service list in verify_tempest_config
  * Fix url parsing for api version check
  * Add check that service tag isn't in path name
  * Stress action for volume attach verify
* Fri Apr 25 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3963.gd9f5e9d:
  * Updated from global requirements
  * fix test_compute_with_volumes
  * Verify addrs only against ports with fixed IPs
  * skip the quota enforcement test for swift
  * Verify flavor extra specs attributes of Nova APIs
  * ssh instance validation add options for Neutron
  * Make large-ops test boot a group of instances 3 times
  * fix dict reference error
  * List multiple fields tests for networks/ports
  * Remove test_create_port_with_no_ip
  * safe_setup preserve original trace
  * Sahara: preparations for new tests
* Thu Apr 24 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3939.ga1eaed8:
  * Verify more information for member in lbaas api tests
  * Add parametric tests of Swift object API, part 2
  * Check attributes of attach/detach volume Nova APIs
  * Verify delete server attributes of Nova API
  * Skip more pause tests if pause is not available
  * Verify the response attributes of 'update-aggregate' API
  * Verify delete interface response of V2/V3 APIs
  * Verify "get az list" API response attributes
  * Change to use absolute path in load_template()
* Wed Apr 23 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3921.g7919447:
  * Added cleanup in some tests
  * Add unit tests for all generators
  * unskip test_list_servers_filtered_by_ip
* Tue Apr 22 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3915.gd0602f0:
  * Missing baremetal NodeState API test
  * move out ironic exception from common import
* Sun Apr 20 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3911.g60b503a:
  * orchestration convert API test Timeouts to respect build_timeout
  * Avoid passing empty string as AZ name
  * Remove the unused _get_unused_flavor_id()
  * Use OS::Nova::Server for NeutronResourcesTestJSON
* Sat Apr 19 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3903.gd124ed3:
  * Inspect listed ports for created port with binding
* Fri Apr 18 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3901.g1da029e:
  * Verify delete agent response of V2/V3 APIs
  * skip test_stack_update_add_remove because of race
  * Validate list_instance_usage_audit_log Nova V2 API
  * Swift formpost cleanup
* Thu Apr 17 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3893.g670c06e:
  * add quotas tests
  * Move exceptions back into one place
  * Implementing XML client for VPNaaS
  * Check get_vnc_console attributes of Nova APIs
  * Rename instance_actions v3 plugin tests to server_actions
  * orchestration API add coverage for stack update API
  * Verify the response attributes of 'shutdown/reboot_host' API
  * Verify list_virtual_interfaces attributes of API
  * Add V2 Nova API os-agents tests
* Wed Apr 16 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3875.gc066015:
  * Up the default timeout for stack builds
  * Add Sahara client for scenarios tests
  * fix import for default clients in clients.py
  * Fix import group ordering in test_utils.py
  * Add load_test mechanism for InputScenarioUtils
  * Move the test_utils module to scenario test dir
  * Improve test_load_balancer_basic
  * orchestration API refactor test_list_resources
  * Add and use a StackResourceBuildErrorException
  * Remove variable part of agent dict to fix AgentManagementTest
* Tue Apr 15 2014 dmueller@suse.com
- remove 0001-Fix-s3-url-default.patch
* Tue Apr 15 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3855.g4fa79ad:
  * Add list roles api to identity v3
* Sun Apr 13 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3853.g528a002:
  * Updated from global requirements
  * Add opportunity to directly update headers
  * Remove unused create_image of Nova v2 API
* Sat Apr 12 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3847.g60dd470:
  * remove n-sch from the watch list
  * Stop neutron resource leaking even if an error occurs
  * Cinder client does not honor disable_ssl_certificate_validation
* Fri Apr 11 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3841.g032e73e:
  * Add unit tests for commands
  * Verify more information for pools in lbaas tests
  * Check add/remove flavor access APIs attributes
  * Add sahara edp cli commands tests
  * Add parametric tests of Swift object API, part 3
* Thu Apr 10 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3831.g864fe07:
  * Add keystone api version detection to verify_tempest_config
  * Verify the response attributes of 'aggregate-set-metadata' API
  * Volume size could be specified to create volume
  * Multiple fixes to test_server_basic_ops
  * Verify detail_list flavor attributes of V2/V3 APIs
  * Adds Ironic test_baremetal_basic_ops scenario test
* Wed Apr  9 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3820.g08b38a5:
  * Verify delete quota response of V2/V3 APIs
  * Check attributes of get server password Nova APIs
  * Honor suspend/pause config switches in scenario tests
  * Verify the create/delete volume APIs attributes
  * Add os-migration tests for Nova v2 API
  * Verify the response attributes of 'get_aggregate'
  * Cleanup common.debug
* Mon Apr  7 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3806.g1466fb9:
  * Trailing '/' throws error
  * Missing baremetal driver API test
  * Expand baremetal port coverage
  * Add "delete the volume-attached server" tests
  * Translate xml server tenantId /userId
* Sun Apr  6 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3796.g94a6364:
  * Verify "enable a service" API response attributes
* Fri Apr  4 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3794.gb683ded:
  * Remove created routers as part of test cleanup
  * Make heat-slow job run in parallel
  * Unskip load balancer basic scenario test
  * Network fwaas API test
  * Adds unit test for negative class decorator
  * Check attributes of create/delete sec groups rule
  * Remove python25 workaround from glance_http
  * Verify the response attributes of 'startup_host' API
  * Remove singleton pattern in base_generator
  * Add os-migration tests for Nova v3 API
  * Cleanup sahara cli tests
* Fri Apr  4 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3772.g340244d:
  * Waiting for ACTIVE state in rescue tests
  * Server create - JSON schema validation: adminPass is optional
  * Verify "get version" API response attributes
  * Validate get_instance_usage_audit_log Nova V2 API
  * Verify "get quotas detail" API response attributes
  * Check reserve/unreserve fixed-ips APIs attributes
  * Add sahara to list of clients for T102
* Thu Apr  3 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3758.gd9d67ae:
  * orchestration API base class rename clear* functions
  * Enable one flavor tests
  * Add unit tests for cli.output_parser
  * Make the checks of identity status code strict
* Wed Apr  2 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3751.g439c1e6:
  * add trace_requests option to debug section
  * Move run_ssh class variable into skip decorators
  * orchestration api tests remove duplicate client assignment
* Tue Apr  1 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3746.g4319052:
  * Move resize_available class variable into skip decorators
  * Move pause_available class variable into skip decorators
  * Move suspend_available class variable into skip decorators
  * Disable other suspend/resume tests if not supported
  * Split certificate API test
  * orchestration add resource limit API test
  * orchestration api tests, docstring cleanups
  * fix sahara base class
  * Deduplicate negative test calls
  * unskip test_integration_1
  * Use HTTP_SUCCESS for checking success status code
* Sun Mar 30 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3724.g75588a3:
  * Verify the response attributes of 'show_host_detail'
* Sat Mar 29 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3722.g59dd424:
  * orchestration remove unused invalid_template_url
  * Verify list extensions attributes of V2/V3 APIs
  * Check attributes of image meta item Nova APIs
  * Validate image metadata attributes of Nova APIs
  * Verify the response status of create delete Image
  * Enable private flavors tests
  * Verify hypervisor uptime attributes of Nova API
  * Check list & search hypervisor attributes of Nova
  * Validate hypervisors_servers Nova V2/V3 API
  * Introduce .coveragerc
  * Updated from global requirements
  * Update documentation for negative testing
  * Validate for list flavor attributes of V2/V3 APIs
  * Stop leaking in images tests
  * Typo in config.py
  * Skip volume snapshot tests if feature is not enabled
  * Add unit tests for NegativeRestClient class
  * Check create/delete keypair attribute of Nova APIs
  * Adds "add_dhcp_agent" to test_dhcp_agent_scheduler
  * Make add_remove_fixed_ip tests executable in Nova gate
  * Add unit tests for debug
  * Enhance test to rescope token using v2
  * Enhance rescope token test using v3
  * Add test to rescope token using v3
* Fri Mar 28 2014 dmueller@suse.com
- savannaclient -> saharaclient
* Fri Mar 28 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3674.g6694fec:
  * Check show_hypervisor attributes of Nova V2/V3 API
  * Verify list_hypervisors_detail Nova V2/V3 API
  * ceilometer-collector now has errors
  * Move xml common code into the common dir
  * Check hypervisor statistics attributes of Nova API
  * Removing unnecessary pieces of code from network client
  * factor out templates to yaml files
  * Add Keystone role and service test cases
  * Add Cinder quota negatives
  * Add unit tests for configurable network resources
* Thu Mar 27 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3655.gd3cbf48:
  * Add config fixture support to unit tests
  * Some keystone V3 API tests throw incorrect errors
  * Verify the list volume attributes of Nova APIs
  * Check attach-detach FIP & get FIP pool attributes
  * Validate list_keypair attribute of Nova V2/V3 APIs
  * Define 'links' as a common parameter type
  * Add validation test in identity v3 test_role
  * Update Oslo config sample generator
  * Modified test case for nova security group
* Wed Mar 26 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3637.g687d077:
  * simplify heat test_limits
  * Verify attributes through Nova "list security groups" API
  * Adds more verification in list alarms
  * Add a new exception for invalid structure
  * Fail a test if stack delete failed
  * Verify the response attributes of 'list_aggregates'
  * Renew token before expiry time
  * Test current tenant not added to private flavor
  * Validate get keypair attributes of Nova V2/V3 API
  * Remove resize-revert workaround for bug 924371
  * Remove usage of internal library function in basic generator
  * Introduce load_tests mechanism for negative tests
  * Refactor create_ and update_ methods for floating ips
* Tue Mar 25 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3611.gbade82f:
  * Stop volume leaking
  * Verify list Image attributes through Nova V2 API
  * Verify Nova create & get Floating IP attributes
  * Move to the python-saharaclient
  * don't log cli output on success
  * add request timing
  * add _find_caller to the request log
  * simplify rest_client logging
  * Verify attributes through Nova list flavor-access API
* Mon Mar 24 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3594.g585f1f3:
  * Move network test_quotas to admin directory
* Sun Mar 23 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3592.g117e4e8:
  * Adds VM connectivity check after advanced VM operations
* Sat Mar 22 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3590.g099a19c:
  * add back empty whitelist
  * API test for 'create server with scheduler hints'
  * Skip loadbalancer basic scenario test
  * Verify quotas attributes through Nova os-quota-sets API
  * Add error handling if testscenarios aren't supported
  * Verify "create a server" API response attributes
  * Fix cinder quota cleanup
  * Stop keystone resource leaking even if an error occurs
  * Stop heat resource leaking even if an error occurs
  * Add tests for external network extension
  * Verify Image attributes through Nova V2 GET API
  * Verify the response attributes of 'list_hosts'
  * Validate of Nova list Floating IPs attributes
  * Networks,Ports: delete with subnet, port with no IP
  * add volume list tests for cinder v2
  * add server personality files test
  * Validate get fixed-ips attributes of Nova V2 API
  * Add unit tests for the tempest.common.utils.file_utils
  * Add return value of classmethod in network base.py
  * Add list user groups api to identity v3
  * Add basic Delete Queue Marconi test
  * Move negative tests for test_images
  * Support disabling suspend/resume for compute api
  * Support disabling server pausing for compute API
  * Add service/endpoint discover to verify_tempest_config
  * Add nova migration-list CLI test
* Fri Mar 21 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3538.g72e6e77:
  * Add server to clean up even in case of errors
  * fix cinder quota equality
  * change dirty logs to work off a whitelist
  * Validate get limits attributes of Nova V2 API
  * Stop test server leaking even if an error happens
  * Ignore .coverage* files
  * Add missing client names to T102 hacking check
  * Fix error trace induced by dhcp test actions
  * Add swift discoverable_api support to verify_tempest_config
* Wed Mar 19 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3521.g65c07d7:
  * Volume boot test uses new block device syntax
  * Add unit tests for wait_for_resource_deletion
  * Add test to rescope token using v2
  * Support endpoint type in CLI tests
  * Remove test_can_log_into_created_server
  * Add api tests for load balancer's VIPs and health monitors
* Tue Mar 18 2014 dmueller@suse.com
- fix requires
* Tue Mar 18 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3509.gf1794eb:
  * Add slow tag for test_ceilometer_resource_list
  * add compute quotas test
  * Add utils.misc unit tests
  * Add network credential unit testing
  * Add unit basic unit tests for tenant_isolation
  * Add cinder tempest cases for encryption-type
  * change teardown check to LOG.error
  * Stop volume leaking even if an error is occurred
  * Wait properly for server deletion in test_volumes_actions
  * Add tests for binding extended attributes for ports
  * Object storage tests to use default auth_provider
  * Convert fake_config class to use config fixture
  * Add quota_set delete test for Nova v3 API
  * Add negative tests for endpoints
* Sun Mar 16 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3481.g77aa856:
  * Move verification of response attributes into service client
  * stress/actions/ssh_floating.py n-net compatibility
* Sat Mar 15 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3477.g22b060e:
  * Add V2 Nova API os-quota-sets tests
  * Rename Savanna to Sahara
  * Fix V3 image tests according to new image_client
  * Make imports proper order
  * Stop leaking test_update_images
  * Updated from global requirements
  * Unset the imageRef when booting from volume
  * V2 API Test to get the VNC console of a Server
  * Add unit test for data_utils
  * fix flake8 errors
  * cleanup resources in setUpClass if exception raised
  * Add unit tests for image waiter
  * Add security group deletion to the cleanup util
* Fri Mar 14 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3451.g70b431f:
  * Do not assert router l3 agent association
  * Fix issue with pep8 gate job
  * Validate Volume attributes of Nova POST & GET API
  * Add agents tests for Nova v3 API
  * Make test_volume_quotas force tenant isolation
  * Skip Nova API attribute tests if an XML response
  * Make tempest accounts independent from devstack
  * Fix RemoteClient usage in scenario tests
  * Fix test by waiting to lbaas entity delete
  * Stop volume leaking test_server_rescue_negative
  * Configure the ec2 zone explicitly
  * Extend network debug infos on network failures
  * Fix InvalidInstanceID.NotFound handling
  * Improve ServerCfnInitTestJSON asserts and debugging
* Thu Mar 13 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3423.g1bcd29a:
  * Verify service attributes through Nova "get services" API
  * Verify more information in API tests for LBaaS
  * Improve readability of test_networks
  * Adds basic Marconi test
  * add token get tests
  * Fix problem of deleting dhcp port
  * Add shelve_offload test for Nova API
  * Add ignore files related to coverage to .gitignore
  * Enable H302 check (api/compute/{c*,f*,i*,s*,t*})
  * Add support for negative tests with admin client
* Wed Mar 12 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3403.g6a66e52:
  * API test for Get Image Member(s) Schema
  * Removed teardown method from image test
  * Remove unused build_url function in data_utils
  * Increase testing of network connectivity
  * Allow failing logs with errors on a per-log-file basis
  * Fixed _error_checker in rest client
  * Prepare for enabling H302 rule (api/compute/admin)
  * Removes gate test annotation in security_groups
  * Add Cinder tests for quota sets
  * Fix setup_test_v3_user method in identity base.py
  * Adds L3 agent test case to test_l3_agent_scheduler.py
  * Stress runner friendly logging.conf.sample
  * Add tempest test for heat resource OS::Nova::KeyPair
* Tue Mar 11 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3377.g622e6b7:
  * Updated from global requirements
  * Prepare for enabling H302 rule(services/telemetry, object_storage, etc)
* Mon Mar 10 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3374.g84a81a4:
  * Enable H302 check (tempest/services/volume)
  * Volume backup details API test
  * Raise orchestration build_timeout to 600 seconds
  * ServerCfnInitTestJSON wait for stack complete before ssh
  * Skip nova cli tests with volumes if Cinder unavailable
  * Add multiple negative test generator support
  * Add Trove (database) Flavor API Tests
  * Do not setUpClass or tearDownClass V3 tests if API is disabled
  * Prepare for enabling H302 rule(api/image)
  * Prepare for enabling H302 rule(services/compute/v3/json)
  * Assign floating ip to a server in load balancer scenario
  * Prepare for enabling H302 rule (api/volume,tempest/*)
  * Fix invalid syntax in HOT templates
  * Move ipv6 config option into network-feature-enabled
  * Cleanup subnet creation in network api tests
  * Add parametric tests of Swift account API
  * Remove unused definition in network base.py
  * Test to update neutron security group
* Thu Mar  6 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3338.gd9393f1:
  * Prepare for enabling H302 rule(services/identity)
  * Cleanup _interface class variables in compute
  * Separate negative tests for test_images
  * Nova V3 API test for resetNetwork/injectNetworkInfo
  * Seperate negative tests for V3 test_server_rescue
  * Implement pluggability for tempest (exceptions)
* Thu Mar  6 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3326.g12cbaac:
  * Prepare for enabling H302 rule(services/compute/json)
  * image(s) schema image metadata API test
  * Stop running CONF getattr during import
  * Add "delete the resized server" tests
  * replace basetring/xrange
  * Split out config option registration
  * Separate negative tests for test_server_addresses
  * Improve tempest auth tests
  * Add namespaces to xml in Network client
  * Adds scenario for hotplug nic in network_basic_ops
* Wed Mar  5 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3306.g652a624:
  * Add status code checks for Nova attach_interfaces API
  * Updated from global requirements
  * Add "Nova V3 API test for add-fixed-IP/remove-fixed-IP"
  * Add V3 API Test to get the VNC console of server
  * Add Nova V2 API test for resetNetwork/injectNetworkInfo
  * XML endpoint client use correct string for enabled
  * Add "V2 API- add-fixed-IP and remove-fixed-IP server action" tests
  * add TRACE level to the items that are being flagged
* Tue Mar  4 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3290.g3d4ddd8:
  * Make reseller admin role configurable
  * NeutronResourcesTestJSON Use the correct resource name for console log
  * Improved tests in tempest.api.image.v2.*
* Sun Mar  2 2014 cloud-devel@suse.de
- Rebased patches:
  + 0001-Use-Python-2.6.x-compatible-syntax-for-dict-comprehe.patch dropped (merged upstream)
* Sun Mar  2 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3284.g4484afd:
  * Remove unused _parse_array functions
  * Cleanup _interface class variables in compute/v3
  * unskip test_security_group_rules_negative tests
  * Use pretty tox with the ``all`` env
  * Revert "always use sitepackages"
  * Skip test_get_instance_action test for nova v3
  * Prepare for enabling H302 rule (thirdparty)
  * Add endpoint_type option to Savanna,Ironic and Ceilometer groups
  * Fix api_version filter for KeystoneV3AuthProvider
  * Check server terminations on "delete server" tests
  * Fix the usage error for config
  * Use Python 2.6.x compatible syntax for dict comprehension
  * add cli.has_manage option
  * Add tests for Swift in orchestration
  * Skip EC2VolumesTest if Cinder is not available
  * Seperate negative tests for test_server_rescue
  * Add api tests for neutron router
  * Replace assertEqual(None, *) with assertIsNone in tests
  * Add more information to BuildErrorException
* Thu Feb 27 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3246.g375a62e:
  * Removal of methods from json/xml network_client files
  * Move admin "delete a server" tests to test_servers
  * Clean network scenarios
  * Test creating router setting tenant_id
  * Scenario : Start instances using fixed network when possible
  * Add unit tests to tempest auth file
  * Separate negative tests for test_projects
  * Separate negative tests for test_multiple_create
  * Mildly wound the interlopers
  * Fix coverage option for run_tests.sh
  * Add logging config values
* Wed Feb 26 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3224.g7f3d438:
  * Separate negative tests for test_instance_actions
  * Prepare for enabling H302 rule (scenario)
  * Prepare for enabling H302 rule (common,services,stress)
  * Prepare for enabling H302 rule (api/compute)
  * Separate negative tests for V3 test_quotas
  * Fix author information
  * Fix a typo of debug log in scenario/manager.py
  * Clarify admin_delete_server_of_others test case
  * fix duplicate api_extensions
  * Fix misspellings in tempest
  * Fix containers with expired objects deletion problem
  * Add quota_set detail test for Nova v3 API
  * Adapt documentation for negative testing
* Tue Feb 25 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3199.g4055378:
  * Log ip Information on ssh failures in the minimum scenario
  * Fix stress runner exit issues
  * Refactor Managers to a common base class
  * Removed RestClientXML class
  * Avoid masking an assert failure with a KeyError Exception
  * Allow IPv6 tests to be disabled
  * Couple of fixes to tempest/auth
* Mon Feb 24 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3185.ge857bd6:
  * Preventing overlapping subnets in network scenarios
  * Fix get versions call in verify_nova_api_versions()
  * Neutron Extra DHCP Options API test
* Sun Feb 23 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3180.gc3849a9:
  * Introduce T106 rule for vi modelines
  * remove some unused code in nova image tests
  * fix quotas client in admin/test_quotas.py
  * Make endpoint type configurable
  * Add test for OS::Neutron::Router Heat resource
* Sat Feb 22 2014 dmueller@suse.com
- added patches:
  * 0001-Fix-s3-url-default.patch
* Sat Feb 22 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3170.g13b7385:
  * EC2 client token is not reuseable for new instance creation
  * Add qcow2 image support
  * Clean up scenario functions
  * Add "delete a shelved server" tests
  * Separate the deleting server tests
  * Makes some Swift API tests optional
  * Separate non-admin AZ tests from admin test files
  * Remove unsed client variables
  * Splits network_basic_ops to fully isolated test cases
  * Refactor cross_tenant to security_groups_basic_ops
  * Minor changes to scenario manager
  * Migrate negative test to a different file
* Fri Feb 21 2014 dmueller@suse.com
- added patches:
  * 0001-Use-Python-2.6.x-compatible-syntax-for-dict-comprehe.patch
- remove user/group generation, is not used here
* Fri Feb 21 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3146.g3fb814d:
  * Adds cinder backup functional tests
  * Prepare for enabling H302 (identity,volume,etc.)
  * Fix test classes name of test_tokens.py
  * Removes vim headers 5th round
  * Prepare for enabling H302 rule (api/object_storage)
  * Neutron LBaaS Agent Scheduler API test
  * Fix request id log messages
  * cleanUp() removing all test resources as an admin
  * Adds list pool stat test case
  * Test to list ports filtered by router ID
  * Add check_uptodate.sh to run_tests.sh -p
* Thu Feb 20 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3124.g95d97b1:
  * Add python-savannaclient to requirements
  * Skip test_list_server_addresses if neutron until bug 1210483 is fixed
  * Restore heat tests running with admin user, demo tenant
  * Fix get_versions string parsing
  * Remove using of deprecated self.headers (part2)
  * unskip test_list_non_public_flavor
  * clean up security groups tests
  * Add support for special char in volume metadata
  * Fixed misspellings in Tempest
* Wed Feb 19 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3107.g69303a8:
  * Add basic Savanna CLI tests
  * Refactor create_ and update_ methods for VIPs and health_monitors
  * Add extra list servers by host test
  * unskip neutron_meter_label cli tests
  * Rename Openstack to OpenStack
  * port flavors and server_password tests into nova v3 part2
  * Separate negative tests for test_list_image_filters
  * Add some cases about volume-create and volume-rename
  * port flavors and server_password tests into nova v3 part1
  * Let the soft reboot really happen in the minimum scenario
  * Network API: default to ipv4, add ipv6 tests
  * InputScenarioUtils load images if glance available
  * Support building wheels (PEP-427)
  * Make v2 and v3 identity apis configurable
* Tue Feb 18 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3079.ged9fdf1:
  * Remove using of deprecated self.headers (part1)
  * port nova v2 images related tests into nova v3 part2
  * Ensure that bug number is actually a number for skip_because
  * Add test case for snapshot-create with in-use volume
  * Test updating port's admin_state_up
  * Remove tests for Nova V3 API os-simple-tenant-usage
  * Remove tests for Nova V3 API os-instance-usage-audit-log
  * enable volume list tests for cinder v2 - part2
  * Fix volume transfer tests with tenant isolation disabled
  * network: add metering api operations
  * Adds test_show_XX_fields cases to show some fields
* Mon Feb 17 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3057.g538ee21:
  * Test tempest decorators used on integration tests
* Sat Feb 15 2014 dmueller@suse.com
- Update to version tempest-2014.1.dev3055.g1a34732:
  * Switch over to oslosphinx
* Fri Feb 14 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3053.gaf37dc9:
  * Add a note about python2.6 support to the README
  * Add CRUD tests for telemetry alarming
  * Define py27 assertFoo methods for py26
  * make testing neutron api extensions optional
  * Add missing isolated_cred cleanup to savanna tests
* Thu Feb 13 2014 dmueller@suse.com
- added patches:
  * 0001-Switch-over-to-oslosphinx.patch
* Thu Feb 13 2014 cloud-devel@suse.de
- Update to version tempest-2014.1.dev3044.gf8870ec:
  * auth.py is too verbose
  * Negative tests: Add result check for resources
* Wed Feb 12 2014 speilicke@suse.com
- Update to version tempest-2014.1.dev3040.gdaea026:
  * Refactor rest-client and identity v2-client
  * Fix usage of NotImplementedError exceptions in auth classes
  * Use testtools.matchers.GreaterThan in test_volumes_transfer
  * enable volume list tests for cinder v2 - part1
  * fix base_url in auth.py
  * Fix admin tenant credential
  * Add skips to the services decorators
  * Dump all log errors to console
- Replace git_tarballs source service with download_files and set_version
  + Use upstream URL as source (enables verification)
- Fix build requirements
* Tue Feb  4 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2951.g56fe321:
  + Fix attach_interfaces tests
  + Remove suffix "JSON" from Nova v3 API test classes
  + add tests for force delete snapshot:
* Mon Feb  3 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2945.g14e6790:
  + Cleanup exceptions
* Sun Feb  2 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2943.gc7522db:
  + Move negative tests for v3 test_server_metadata
  + Move common _delete_volume cleanup method in base compute test class
  + Fix logic for config file env variables
  + Updated from global requirements
  + Matches one flavor and one image by default
  + Removes vim headers 4th round
  + Enable tenant isolation for the boto tests
  + Add bool and integer support to XML parser
  + Fix stress test README.rst
  + Skip flavor_access_add/remove related tests
* Sat Feb  1 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2923.g986f61e:
  + Remove network resources created in scenario tests
  + Add alias as prefix for flavor_rxtx v3
  + Fixed up an error message
  + stop leaking tempdirs
  + Convert ironic, swift, and heat api tests to use global CONF object
  + Convert volume api tests to use global CONF object
  + Convert thirdparty and stress tests to use global CONF object
  + Convert scenario tests to use global CONF object
  + Convert cli tests to use global CONF object
  + Convert all service clients to global CONF object
  + test_rescued_vm_add_remove_security_group missing addCleanup
  + Remove last uses of config without global CONF object
  + Add list server filter with extra limits
  + Add key -n for sudo utility
* Fri Jan 31 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2895.gbab2c6c:
  + Remove Nova v3 XML tests completely
  + tighten up isolated creds create
  + Make --debug flag on run_tests and run_tempest use testtools.run
  + Fix class inheritance for volume_types tests
  + Avoid expiration before updating metadata
  + Check if service is available for cli tests
  + Remove unused method basic_auth from rest client
  + Use BaseComputeTest.create_test_server
  + Remove super call in overloaded close()
  + Rewrite RemoteClient.get_boot_time()
  + Run SNAT specific test cases only with ext-gw-mode extension
  + Refactor usage of custom_match tests
  + Removes vim headers 3rd round
  + Update 'Member' with option 'operator_role' in tempest.conf
  + Remove baremetal xml support
  + Convert compute api tests to global CONF object
  + Convert image and identity api tests to use global CONF object
  + Convert network api tests to use global CONF object
  + Removed unnecessary lock from a aggregate test
  + Do not assume volume metadata is identical to POST request
* Thu Jan 30 2014 dmueller@suse.com
- move lock_path to /var/run
* Thu Jan 30 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2855.g0a8d94d:
  + Skip test_list_servers_by_admin_with_all_tenants test
  + Moves negative tests from test_server_metadata
  + Add simple node group tmpl API test for Savanna
  + Add a couple log errors to whitelist.yaml
  + Sync Patch and PatchObject fixtures from oslo-incubator
* Wed Jan 29 2014 vuntz@suse.com
- Use correct group name for directory ownerships.
* Wed Jan 29 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2845.g1ea9ada:
  + Fix parameter type spelling tempest HOT template
  + Add a check for compute api versions to verify_tempest_config
  + Fix glance_http HTTPS response issues
  + Fixing typo in test_volumes_get.py
  + Add test for volume list with all-tenants
  + Separate negative tests for test_templates
* Tue Jan 28 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2833.g6e4f15c:
  + Fix parameter in auth error message
  + Use automated create and update methods for core network resources
  + Use unittest2.TestSuite with py26
  + Specify 'active' status for deleting situations
* Mon Jan 27 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2825.g93daa28:
  + Separate negative tests for Swift
* Mon Jan 27 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2823.g083c82b:
  + Remove user creation in object service and healthcheck test
  + Increase ping timeout from 60 to 120 seconds
  + stop validating user IDs on role assignment operations
* Sun Jan 26 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2817.gc68b9a5:
  + Avoid using assertGreater
  + Create telemetry client
  + Add delete specific status server test
  + text-html type is absent in TXT_ENC
  + Remove X-Storage-Stoken from object_storage
  + Python 2.6 do not has unittest.loader, we import unittest2 instead
  + Add more descriptive assertion message for test_create_backup
  + Use install_venv from oslo to fix no post_process issue
  + Separate negative tests for test_quotas
  + Add unit tests for SSH client functionality
  + Remove vim headers 2nd round
  + Rework extension verification in verify_tempest_config
  + Add neutron extension support to verify_tempest_config
  + Add volume cleanup to test_volume_transfer test
  + Exclude heartbeat timestamp from agent list checks
  + Fix log_console_output call in test_network_basicops
* Sat Jan 25 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2785.g7aaea9a:
  + remove the nova v3 xml tests from the code
  + Tests object_storage extension listing
  + Change status available to active
* Fri Jan 24 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2779.g640629f:
  + Remove vim headers
  + add keystone group tests
  + Create only necessary resources for image, object_storage, volume
  + AttachInterfacesTest: use build_timeout on iterface deletion
  + Fix typo in imagev2 class name : Memeber should be Member
  + Move console output log place in test_cross_tenant_connectivity
  + Fixing typo "existant". Must be "existent"
  + cinder v2 api tests - fix volume client
  + Update README.rst with details about unit tests
  + remove Nova v3 XML testing
  + Catch ssh exception and detach in min scenario
* Wed Jan 22 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2758.g6382816:
  + skip test_volume_boot_pattern
  + Add a version API test for Nova v3 API
* Tue Jan 21 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2754.g97b4a65:
  + Only create necessary resources for compute v3 tests
* Mon Jan 20 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2752.gc7c332e:
  + Create security group rule with additional args
  + Make network resource creation in isolation configurable
  + Make BaseV2MemeberImageTest inherits from BaseV2ImageTest
  + Add a config option for trusts
  + Create only necessary networks resources for scenario tests
  + Create only necessary resources for compute v2 and network tests
  + Remove FloatingIPChecker from network_basic_ops
  + port instance_usage_audit_log tests into nova v3 part2
  + Forbid admin_password None in rescue Nova API
* Sun Jan 19 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2734.g9abd422:
  + Remove test_network_quotas_scenario
* Sat Jan 18 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2732.gfafced2:
  + Add more console output log for scenario tests
  + Add a unit test coverage tox job
  + Fix an error when executing run_tests.sh
  + Fix host_update test case for losing essential parameter
  + Fix parameter of nova v3 flavors API
  + Add aggregates scenario test
* Fri Jan 17 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2720.g6cbd7f5:
  + Add to whitelist two errors that slipped through
  + Adds test_list_XX_fields cases to list some fields
  + Add missing whitespace in config description
* Thu Jan 16 2014 dmueller@suse.com
- fix requires
* Thu Jan 16 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2714.gc59c9d7:
  + port test_server_metadata and test_server_personality into v3 part2
  + fix a minor bug when detecting server image flavor
  + Test server create with ephemeral disk
* Wed Jan 15 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2708.gaa419c9:
  + Remove copyright from empty files
  + Add extra list server by status test
  + port admin/test_servers* into Nova V3 tests part2
  + Improve testing of list_extensions for compute
* Tue Jan 14 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2700.g9cc5684:
  + Fix typo in ceilometer and neutron tests
  + Input scenario capability for tempest
  + Fix volume metadata validation of identical to request
  + Add heat stack action test case
  + Neutron Agent Management List Agents Non Admin
  + Add a discoverable_apis option for swift
* Tue Jan 14 2014 dmueller@suse.com
- fix requires
* Mon Jan 13 2014 dmueller@suse.com
- install run_tempest.sh
- update default config
* Mon Jan 13 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2688.g4c1c884:
  + Fix reference config before initialization in cli tests
  + Fixes handling of arrays in XML to JSON conversion
  + List Nova and Cinder extensions in debug log
  + log console_output when test_network_basic_ops failed
  + trusts API test, avoid creating duplicate user
  + Fix v3 test_list_servers_negative
  + Remove Swift container-sync test skipping
  + Skip simple_tenant_usage related tests
  + Add coverage option to run_tests.sh
* Sun Jan 12 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2670.g155fe7f:
  + Add base class for Telemetry tests
  + Fix typo in ssh_floating.json for stress tests
  + Make run_tests.sh for running unit tests
  + Add a run_tempest.sh script
  + Remove skip_because in swift object expiry test
  + Moves negative tests from test_instance_actions
* Sat Jan 11 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2658.g8ceec46:
  + port nova v2 images related tests into nova v3 part1
  + Delete a BuildError server
* Fri Jan 10 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2654.g608df26:
  + Fix bug in validating Swift transaction ID
  + API tests for Ironic
  + Add tests for snapshot_metadata
* Thu Jan  9 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2648.gd9317e6:
  + Wait for the server before validate the rotation result
  + Add tests for volume_metadata
  + Add python-swift client to the requirements
* Wed Jan  8 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2642.gcb59706:
  + keystone trusts API test, move delete into tearDown handler
  + Make testing neutron agents optional
* Tue Jan  7 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2638.g5d1b3df:
  + Moves negative tests from test_server_addresses
  + Add negative tests for routers
  + Remove test_auth_token.py
  + Moves negative tests from test_absolute_limits
  + always use sitepackages
  + remove eventlet from requirements
  + Add basic read-only tests for heat cli
  + add tests for security_group updating
* Sun Jan  5 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2622.gfc691e3:
  + sync oslo to current
* Sat Jan  4 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2621.gc4cf297:
  + Add config for Telemetry
* Fri Jan  3 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2619.g3c4419c:
  + keystone OS-TRUST extension, test list operations
  + Add test for HEAD queries on Swift tempurl MW
  + Kill finally, use addCleanUp
  + keystone OS-TRUST extension, test with expiry
  + Add create_floating_ip function
  + Add 2 tests to the Floating IP test case
  + Increase exception log details
  + port admin/test_servers* into Nova V3 tests part1
* Thu Jan  2 2014 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2603.gfd7493c:
  + port servers negative tests into v3 Part2
  + port some flavor tests into nova v3 part2
  + cinder v2 api tests - part1
  + Fix AutoScalingTest test suite error
  + Separate negative tests for test_image_metadata
  + Refactor network client: add create_ and update_ methods
  + port test_aggregates and test_hosts into nova v3 part1
  + port test_aggregates and test_hosts into nova v3 part2
  + port test_live_block_migration into nova v3 part1
  + port test_live_block_migration into nova v3 part2
  + Add version test for Ceilometer cli
  + Remove unused wait_for function
  + port some servers tests into nova v3 part2
  + port test_quotas into v3 part2
  + Moves negative tests from test_multiple_create
  + Use wrapper create_volume() in volume tests
  + Separate negative tests for test_simple_tenant_usage
* Thu Dec 26 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2572.gc653790:
  + port test_keypairs into nova v3 part2
  + Enable HostsAdminTestXML
  + Moves negative tests from api/compute/servers/test_virtual_interfaces
  + allow hypervisors to be down but still pass
  + Fix the example of testr testing
* Wed Dec 25 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2562.g883bf82:
  + Fix OS_TEST_PATH in .testr.conf
* Tue Dec 24 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2560.g09daa4e:
  + rename old config object to TempestConfigPrivate
  + remove unneeded __init__ file
  + remove last errant file parse warning
  + Add swift scenario tests
  + Serialize plurals correctly in neutron xml client
  + Use create_router_interface and create_port
* Sun Dec 22 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2551.g36cb048:
  + port related volumes tests into nova v3 part2
  + attach_interfaces as smoke
  + Fix AttributeError on BadRequest in scenario tests
  + Heat: check response fields
  + Run test_service_type_management test only if extension is available
  + Fix cinder test cases when cinder extensions are in use
* Sat Dec 21 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2539.g9e3e0b6:
  + Add Savanna-related configs for testing
  + Add Savanna client for node group templates
  + scenario/network_basic_ops: reassociate floating-ip
  + moving to global lazy loaded config
  + Add testcases for images
  + move negative tests out of test_services in nova v3
  + Skip extraroute tests if extension is not enabled
  + port related volumes tests into nova v3 part1
* Fri Dec 20 2013 dmueller@suse.com
- update default config
* Fri Dec 20 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2524.g7374093:
  + Separate negative tests for list_floating_ips
  + Separate negative tests for test_fixed_ips
  + Add test_discover module to provide a load_tests hook
  + port test_keypairs into nova v3 part1
  + Add negative tests for network
  + Use rand_uuid and remove unused client for clean-up
  + port certificates tests into nova v3 part1
  + port certificates tests into nova v3 part2
  + Increase support for isolated tenants in scenario
  + Add volume extensions tests
  + Only initialize the glance_http if service is enabled
  + Refactor cross_tenant_connectivity for tenant isolation
  + port instance_usage_audit tests into nova v3 part1
  + Remove unnecessary spaces from messages
  + Add unit tests for rest_client
  + Fix the help message for run_ssh
* Thu Dec 19 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2492.g741b9f7:
  + add some negative tests for flavor
  + Adds ping method to remote client
  + provide a valid utf8 multibyte test for nova images
  + clean up invalid_multibyte test
  + Add testcases for security groups
  + avoid resource leaks in keypairs tests
  + Fix three accidentally formatted paragraphs
  + Separate negative tests for test_availability_zone
  + Remove duplicate negative test of flavor_id
  + Move common wait_for_image_status from compute images_client to waiters
  + add both v2 and v3 tests for get specified extension
  + SSH connection related cleanups
  + Make Heat's non_empty_stack usable without a server
  + Refactor network client
  + scenario cross_tenant_connectivity
  + Fix failures when l3_agent_scheduler ext is not available
* Wed Dec 18 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2460.g913bdab:
  + add some tests for aggregates
* Tue Dec 17 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2458.gee95841:
  + Test for the update extra route
  + Tighten ERROR regexp in log checker
  + scenario/network_basic_ops: detach floating-ip
  + Make negative snapshot tests faster
  + Add new env variable to specify test path
  + actually turn on neutron cli tests
  + Test for the agent management extension API
  + Add testcases for volume
  + Update tempest hacking regarding unit tests
  + Add tests for keystone OS-TRUST v3 API
* Sun Dec 15 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2438.gcdbbb2e:
  + don't fail on dirty logs with grenade
  + Make the wait_for_server_status timeout message a bit more clear
  + Wait for backup images to be ACTIVE in test_create_backup
  + Add the external gateway interface to vpn router
  + remove a spurious wait that could get us into trouble
  + Set pipefail for wrapper scripts
  + Add whitelist entry for s-proxy 'Timeout talking to memcached'
  + Add a control point for floating IP assignment
* Sat Dec 14 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2423.gec61323:
  + Fix the upper values of test_network_quotas
  + Remove generic_setup_package() function
  + Change unstable test which gets console output
* Fri Dec 13 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2417.g48fbbdc:
  + Skip autoscaling test until more reliable
  + Don't have tox install pre-release software
  + Fix Neutron VPNaaS Test
  + Separate negative tests in flavors/test_flavors
* Thu Dec 12 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2409.g76c30ce:
  + remove  test_service_enable_disable in nova V3 tests
  + Use correct types for thresholds
  + Handle rest client 500 response if non-json body
  + add admin server tests
  + Fix display_name of volume for test_volumes_list
  + Fix the scope to share a server between tests
* Wed Dec 11 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2397.g9c9453f:
  + Modify the name of a negative test class
  + Remove redundant whitelist for DHCP agent
  + Race condition in ListImageFilters tests
  + Updated from global requirements
  + Add config options for enabled extensions
* Tue Dec 10 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2388.g30f6c41:
  + port test_server_rescue into v3 part2
  + Separate negative tests for test_services in Tempest
  + Add mock to test-requirements.txt
  + Adds paramiko logs to console output
* Mon Dec  9 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2381.g3eeb857:
  + Rip out the coverage extension client from tempest
* Sun Dec  8 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2379.gd31257e:
  + port test_quotas into v3 part1
  + port some server tests into nova v3 part1
  + VPNaas IKE policies tests
  + port test_server_rescue into v3 part1
  + Move import to import block again
  + port test_server_metadata and test_server_personality into v3 part1
  + remove the test: test_service_enable_disable
  + Check HTTP response headers of Swift middleware API in detail
  + port some flavor tests into nova v3 part1
* Fri Dec  6 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2361.gc0549fe:
  + Use channel_timeout for SSH connection timeout
  + Fix rebuild_server() function
  + Remove unused allow_tenant_reuse flag
  + Negative tests separate file for floating_ips_actions
  + Adds "list hosts" test case - Cinder
  + Some tests for dhcp agent scheduler
  + Add internal testing for the stress test framework
  + add some negative tests for security group:
  + Fix a minor error in method _get_alternative_flavor
  + port test_simple_tenant_usage into nova v3 part2
  + Add tests for testing swift slo middleware
* Wed Dec  4 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2339.g6b44788:
  + Enable a uuid flavor
  + Update openstack/common/lockutils
  + Add test for Swift formpost middleware
  + Support Neutron security groups in scenario testing
  + Add two more tests for Swift staticweb middleware
  + Adds improvements to the Swift TempURL test
  + add some test for force delete:
  + update to hacking 0.8
* Tue Dec  3 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2324.g589d68f:
  + Revert "Add test_cases for cinder cli in v2 version"
  + Start failing logs with errors except neutron
* Mon Dec  2 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2321.g21c7db1:
  + Moves negative tests from api/compute/keypairs/test_keypairs
* Sun Dec  1 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2319.g9a83a39:
  + Fix file print logic bug and update whitelist
  + port servers_negative tests into v3 part1
* Sat Nov 30 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2315.g8633ceb:
  + Add migrate negative tests
  + port test_hypervisor into nova v3 part1
  + port test_hypervisor into nova v3 part2
  + Adds delete api test to glance
* Fri Nov 29 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2308.gc42ce44:
  + Add some tests for os_update_readonly_flag
  + Ensure no dangling resources are left if tests are skipped
  + Add test_cases for cinder cli in v2 version
  + Add missing "interface" argument to AltManager
* Thu Nov 28 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2300.ge60b945:
  + Improve the UX around sample config generation
  + More stuff in the whitelist
  + Dump all error messages for neutron
  + port attach_interfaces and server_address tests into v3 part2
  + port test_simple_tenant_usage into nova v3 part1
  + Check HTTP response headers of Swift API in detail
* Wed Nov 27 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2289.g2560d6f:
  + Add sample config check to tox pep8 job
  + Add test for update/reset_snapshot_status API
  + Enhance tests for flavor_extra_spec API
  + Add some tests for security_group_rules api
  + Avoid deleting ports assigned to router interfaces
  + Cleanup using about the data_utils module and functions again
  + port test_availability_zone into nova v3 part2
  + Add hard reboot for outputting console log
  + Enable the Nova V3 API Tests
  + Add hopefully last batch to the whitelist
* Tue Nov 26 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2269.g7811379:
  + Reuse a server instance in test_disk_config
  + Cleanup using about the data_utils module and functions
  + port instance_actions and server_list tests into nova v3 part1
  + port instance_actions and server_list tests into nova v3 part2
  + Make sure ssh retries on paramiko.SSHException
  + Adds negative tests to glance api's
  + Add test cases for volume-transfer
  + Added images support and existing config support
  + port attach_interfaces and server_address tests into v3 part1
  + Rename object storage features section
  + Forced isolation for the tests in test_list_servers_negative.py
  + add tests for InstanceUsageAuditLog
  + Move admin client initialization into stress-openstack
* Mon Nov 25 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2243.g8b3e78d:
  + port test_availability_zone into nova v3 part1
* Sun Nov 24 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2241.g7d6f821:
  + Don't use duplicate IP addresses
* Sat Nov 23 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2239.g9ca1b50:
  + Remove unused code in tempest files
  + Remove unused code in user test
  + add role negative tests
  + add tests for server_password
  + Adds tests to cover Swift's crossdomain middleware
  + Moves negative tests to test_images_oneserver_negative
* Fri Nov 22 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2227.g19a26af:
  + Disable V3 tests
  + Skip test_create_backup
* Mon Nov 18 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2224.gfd7bfb5:
  + Enable all nova v3 tests
* Sat Nov 16 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2222.g26df0ac:
  + Make smoke tests parallel
* Fri Nov 15 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2220.gc6b7133:
  + removing dead docs
  + Fixing ImageKilledException raising
  + Test image member is enforced
  + port test_services into nova v3 part1
  + port test_services into nova v3 part2
  + port test_extensions into v3 part1
  + add tests for certificates
  + Add shelve/unshelve test of nova APIs
  + add negative volumes tests
  + Test for l3 agent scheduler API
  + Add special serial smoke option
  + glance v2 image sharing tests
  + add test for create_backup
  + port test_extensions into nova v3 part2
  + Test for service type management
* Thu Nov 14 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2190.gf08b2d4:
  + Remove unused code in api/compute/admin/test_quotas.py
  + move nova v3 delete image tests into glance testing
  + Remove unused run_ssh variable
  + Remove skips for bug 1182384
  + Add negative resize server action test
* Wed Nov 13 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2180.g2fbf152:
  + Add additional documentation for stress tests
  + Skip all nova v3 tests temporarily
  + Sync latest module versions from oslo-incubator
  + Switch base unit test class to oslo mox fixture
  + Added some tests for reserve and unreserve volume
  + Test for flavor-access-list with private/public flavor
  + assertTrue to assertIn
  + Rename to create_test_server in API tests
  + remove redundant code in fixed_ips_client for xml
  + Configure scenario clients with region
  + Adapt scenario readme with real-life aspect
  + removes a duplicate volume type test
  + Fix NameError exception
  + Add missing CLI Neutron tests
* Tue Nov 12 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2152.gc5f22d9:
  + remove old README files that are now redundant
* Mon Nov 11 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2150.g90d3df7:
  + Make test_show_host_detail work with multi host installation
* Sat Nov  9 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2148.gb510f47:
  + Sync config file generator from oslo
  + port test_images and test_server_actions into v3 part1
  + port test_images and test_server_actions into v3 part2
* Fri Nov  8 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2142.gdadd85c:
  + add some negative tests for force_delete/restore
* Wed Nov  6 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2140.g06a237d:
  + add positive tests for volume
* Tue Nov  5 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2138.g2cbc95b:
  + Update mailmap for Joe Gordon
  + Add design principles to docs
  + add debugging for when changes-sinces fails
  + remove skip bug 1233026
  + Stop testing deprecated command nova-manage instance_type
  + edit inheritence tree api/network/security_groups
* Mon Nov  4 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2126.gdf0f503:
  + add tests for show and update of Flavor Extra Spec API extension
  + Change all non-slow scenario tests to smoke
* Sat Nov  2 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2122.g0d54a85:
  + API tests for neutron router gateway
  + Add tempest unit test to verify the test list
* Fri Nov  1 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2118.gda267cc:
  + Adds test to cover Swift healthcheck middleware
  + Add some test_cases for glance_cli
  + Adds api test to test_images
  + add extend volume tests:
  + Reorganize project feature config options
  + Stop auto-detecting glance API versions
  + Sync fixtures from oslo and use LockFixture
  + Add test case to api/compute/test_quotas
  + RunTimeError on tearDownClass explained
  + Add base test class for unit tests
  + Add config feature verification script
  + Add api version detection to verify_tempest_config
  + Fix incorrect config option types
  + Fix default values so they work in a devstack run
  + Move decision_maker() call into setUpClass
* Wed Oct 30 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2088.g51e4b77:
  + Adds initial ceilometerclient testing code
* Tue Oct 29 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2086.g14b75e8:
  + Set max_template_size to heat's default value
  + Use lower case true/false in the sample config file
  + add negative test cases for create snapshots:
* Tue Oct 29 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.dev2080.g4fcaad5:
  + Raise specific exceptions on tearDownClass failure
  + Preserve the configured log level
  + Refactor duplicate isolated creds code
  + Fix bad classname
* Sat Oct 26 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.a2072.g4327699:
  + Fix bad classname
  + add some tests for host and seperate negative ones
  + Added some test for image tags
  + add tests for set_metadata in aggregate
  + Add filenames to skip_tracker.py output
  + Replace assertLessEqual - is not in py26 testtools
  + Early die if on image gets killed
* Fri Oct 25 2013 opensuse-cloud@opensuse.org
- Update to version 2014.1.a2059.gadae447:
  + Set tempest version for icehouse
  + Add more stuff to the whitelist
  + Update to latest pbr
  + Updated from global requirements
* Thu Oct 24 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a2051.gffe8afe:
  + fix DeletableSubnet in api/network/common
  + Revert "Use isolation credentials for neutron api tests"
* Wed Oct 23 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a2048.g771b950:
  + add volume tests
  + Change six to match global requirements
  + Simplify xml/json client selection
  + Add a flavor test for getting a specified key value API
  + add BaseV2ComputeTest as the base class of nova v2 api tests
  + Fix issue with ImagesOneServerJSON test
  + api/network/security_groups_negative add testcases
  + Test for server create with IPv6 address only
  + Forced isolation for the nova quota test
  + uses skip_because where appropriate instead of regular skip
  + Use isolation credentials for neutron api tests
  + use "" instead of "None" in xml file
* Mon Oct 21 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a2024.g7ca13ed:
  + add token test for token-api
  + add test for updating server's disk_config test
* Sun Oct 20 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a2020.ge34ac37:
  + add some tests for hypervisor operation
* Sat Oct 19 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a2018.gcb8c5c0:
  + server status remained in unexpected state
  + Changed the exception name
  + Inject "-tempest-" string to rand_name
  + Add a skip for meter-label cli tests
* Thu Oct 17 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a2013.g8bdb0f7:
  + Fixing ImagesOneServerTestXml issue
  + Skip negative compute quota tests that don't work with Neutron
  + Move negative action tests to right place
  + VPNaas vpnservice test cases
  + Separate negative tests  api/network/security_groups
* Wed Oct 16 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a2003.gc0c6d85:
  + skip test_lock_unlock_server
  + glance image v1 member test cleaup
  + Adds test_update_all_metadata_field_not_included negative test
  + add some negative tests for tenant
  + Orchestration autoscaling improve status polling
  + Fix to use proper random values
* Wed Oct 16 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1991.g717fb56:
  + Rename cli tests from compute to nova
  + Reduce vm creations in negative tests
  + Update to latest tox
  + remove tearDownClass in test_quotas.py
  + Restores passing additional parameters to nosetest
  + add more test cases to api/network/security_groups
  + Add a create_router utility function
  + Skip get_server_diagnostics test until bug 1240043 is fixed
  + Split out unit tests as separate tox jobs
* Mon Oct 14 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1973.gf55f4e5:
  + delete the duplicated variable definition
* Mon Oct 14 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1971.g86ab238:
  + add some negative tests for volume updating:
  + Test for the nova diagnostics API
  + Add some test_cases for compute-cli
  + Update lockutils from oslo-incubator
  + Add some test-cases for cinder cli
  + Use built in cleanup for servers in test_large_ops
  + Add security group to large_ops test
  + add some tests for user api
  + Add CLI tests for Neutron's metering agent
  + add a negative test for flavor_extra_specs
  + Script to filter logs for ERRORs based on whitelist
  + Add section for negative tests to HACKING.rst
  + Increase heat's default max_template_size
  + Accept gzip files in find_stack_traces.py
* Wed Oct  9 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1944.gd729220:
  + pass stop_on_error to _has_error_in_logs
  + remove code duplication in tempest/config.py
  + Allow _status_timeout to be used for non-nova polling
  + Initial basic setup of openstack and tempest config file
  + add volume list tests
  + Cleanup existing instances in setup for test_list_servers_negative.py
  + meta should be metadata in rebuild server
  + Remove unused CONF variable and import statement
* Tue Oct  8 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1928.gd0181f6:
  + add server reset_state tests
  + Test cases for V3 Project Actions
  + Add test for admin deleting servers of others
  + Heat: use first_address instead of first_private_address
  + Unskip test_tokens and update expected status to 404 from 401
  + add server delete/unpause tests
  + TEMPEST_PY26_NOSE_COMPAT in py26 jobs
  + Handle test_list_servers_by_changes_since without tenant isolation
  + add server suspend/resume negative tests
  + _error_in_logs function of driver.py shall check all nodes
  + Do not check for id in the keystone output
  + introduces skip_because decorator
  + Clean up existing instances when not using tenant isolation
  + Add xml support to the floating ip and router
  + tempest/config.py parse some sections incorrectly
  + Fix skip_because decorator
  + Placeholder log check script to be called by devstack-gate
  + Add addtional logging and catch exceptions
  + Cleanup test_list_server_filters setup/teardown
  + Use predictable instance/volume names in test_volumes_actions
  + add two negative tests for flavor-access
* Tue Oct  8 2013 dmueller@suse.com
- remove 0001-Do-not-check-for-id-in-the-keystone-output.patch
* Wed Oct  2 2013 speilicke@suse.com
- Update to version 2013.2.a1888.g0432a37:
  + Add tempest tests for os-aggregate update
  + Make smoketests working again with Python 2.6/nose
  + unskipping bug related to test_stamp_pattern.py
  + Revert "unskipping bug related to test_stamp_pattern.py"
  + Explicity specify network for heat slow tests
  + Update style guide link in HACKING.rst
- Drop 0001-Make-smoketests-working-again-with-Python-2.6-nose.patch:
  Merged upstream
* Mon Sep 30 2013 dmueller@suse.com
- add 0001-Make-smoketests-working-again-with-Python-2.6-nose.patch
- add 0001-Do-not-check-for-id-in-the-keystone-output.patch
* Mon Sep 30 2013 dmueller@suse.com
- Update to version 2013.2.a1877.g7061c70:
  + Bump oslo.config version
  + The debug configuration group is not registered
  + Update docs config
  + driver.py should log errors when ssh operations fail
  + fix typo in config.py
  + _get_tenant_by_name doesn't return correctly
  + Print the lekaed 'boto' tags on Failure
* Sat Sep 28 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1863.gf13a350:
  + Adds more test to cover Swift tempURL middleware
  + Add positive tests for os-floating-ip-pools
  + Add test for nova API of VM lock/unlock
  + add __str__ function to RestClient class
  + _create_creds function shouldn't call rand_name twice
  + Added Negative tests for image member
* Fri Sep 27 2013 dmueller@suse.com
- switch to crudini
* Fri Sep 27 2013 dmueller@suse.com
- relax dependency on keyring for now (missing dependency
  in Factory)
* Fri Sep 27 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1851.g2416764:
  + Handling network resources in tenant isolation
* Thu Sep 26 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1849.g58c1321:
  + Move LockFixture to tempest.common
  + Add locking to test_list_hosts_with_zone
  + add negative volume tests
  + makes passing the client optional to utilities in scenario/manager.py
  + Added test to check list/show extensions-neutron
  + Fix json version of bootable check
  + Don't log 'Not Found' ERROR during image cleanup
  + Fix problem with never stopping stress tests
  + add server resizing tests
* Tue Sep 24 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1831.g5f5f1a0:
  + Fix typos in tempest/HACKING.rst Edit
  + README.rst of tempest stress is misleading
  + Sync install_venv_common.py from oslo-incubator
* Sun Sep 22 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1826.gfcbca58:
  + Replace OpenStack LLC with OpenStack Foundation
  + Consider lc string for bootable True/False
  + Test that Heat max_template_size is applied
* Fri Sep 20 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1821.ge947bde:
  + Skip test tokens
  + Remove wait_for_image_resp_code
  + Enable the quota test cases
  + Fix misused assertTrue in unit tests
  + Adds tests covering Swift's container quotas middleware
  + Remove claim that scenario tests need 2 services
* Thu Sep 19 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1809.gea8ce25:
  + Dump basic network info  in the test_network_basic_ops
  + Add update-volume test
  + Use built-in print() instead of print statement
  + Add keystone user-update test
  + Add tempest tests for os-host/{host-name} api
  + Raise OS_TEST_TIMEOUT for heat slow test
* Thu Sep 19 2013 dmueller@suse.com
- configure cli_dir to /usr/bin by default
- add dependency to git-core
* Thu Sep 19 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1797.ga7df393:
  + fix pep8 errors: E231, E128
  + assertEquals is deprecated, use assertEqual
  + Use common create_server method for advanced_ops
  + LBaaS client functions and pool testcases
  + Add "region" config for each service
  + Adding LB member operation test cases
  + Adding health monitoring test case
  + Add missing import of 'subunit' in test-requirements.txt
  + Add update-snapshot test
  + Add 'Field' to the title of the Field Guides
  + Move _check_tenant_network_connectivity to the end
  + Add a function for creating a server on a given network
  + Fix a test case of 35chars+
* Wed Sep 18 2013 dmueller@suse.com
- add -test subpackage in order to be able to run the testsuite
- fix package requires
* Wed Sep 18 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1771.gb17460e:
  + Add a create_server test for flavor authorization
  + Update README.rst to use testr instead of nose
* Tue Sep 17 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1768.g66fcba9:
  + Fixes typos in tempest/api
  + test_fixed_ips unsafe xml/json resource sharing
  + Fix overlapping subnet creation
  + Adding xml support for load balancer
  + Add parallel test execution section to HACKING.rst
  + Sync latest versions of oslo incubator
* Mon Sep 16 2013 speilicke@suse.com
- Update to version 2013.2.a1757.gcc1fb46:
  + Fix race condition for test_flavors_extra_specs
  + Add service tags to api.volume
  + Add services tags to scenario tests
  + Remove bin/tempest script
  + Add hacking check for service tags in scenario
  + Add service tag section to HACKING.rst
  + Remove Whitebox tests
  + added an api test for security_groups
  + Add logging to the python-clients
  + Bulk Subnets and Ports creation
  + Make the admin role configurable within tempest
  + Adds disk_format parameter to upload_volume method in volumes client
  + Add tearDownClass to base swift test class
  + task_state must be consider before many action
  + Credentials Keystone V3 API Tests
  + Adding negative test for port
  + Adds verfication for Bootable Volume
  + Network load balancer testing
  + VolumesListTest may hide configuration issues
  + Fixes some typos in tempest
  + add required python modules(six,iso8601,fixtures) to requirements.txt
- Drop /usr/bin/tempest binary
* Wed Sep 11 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1716.g7fad0ca:
  + Translate server extension attributes to json
  + Append some operations to boot from volume pattern
* Wed Sep 11 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1712.g16c4379:
  + Fix import grouping in scenario tests
  + Remove order dependence from network_basic_ops
  + Add @services decorator
* Mon Sep  9 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1708.gec7aef5:
  + fix race condition between addCleanup and lockutils
  + Fix tempest config usage in test_attach_volume
* Sat Sep  7 2013 dmueller@suse.com
- require the nose_plugin
* Sat Sep  7 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1704.gb3abf9c:
  + Add device name, ssh password to Tempest config
  + Fix colon in create volume logging output
  + Eliminate the impact of "wait_until='BUILD'"
* Fri Sep  6 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1698.g22942ba:
  + add flavor creation tests
  + Add tests for Swift's StaticWeb middelware
  + fix test_flavors_extra_specs failure
  + refactor - _is_timed_out using instance timeout
  + Updating HACKING.rst
  + Restrict Volume type deletion with volumes assoc
  + Added missing xml tests of volume
  + raise assertion error if output is falsy
  + Added test case to check floating IP API operations
* Wed Sep  4 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1680.ga4eb844:
  + Stress ssh_floating test
  + Add handling for inherited stress attributes
  + Add more detailed message about the volumes missing
  + Switch heat template to use native nova resource
  + uniforms skip messages
  + Move the network api tests to smoke
  + emit warning while running flake8 without virtual env
* Wed Sep  4 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1666.gcfa91fb:
  + Remove unused LOG variable in scenario tests
  + Increase default test timeout for timeout fixture
  + KeyError when tearDownClass called from setUpClass
* Tue Sep  3 2013 dmueller@suse.com
- switch to setuptools
- install config as noreplace
- fix requires
* Tue Sep  3 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1660.ga87b64d:
  + Log request ids from glance and nova
* Fri Aug 30 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1658.gedaa084:
  + moves addCleanup few lines upper to avoid potential leftovers
  + Adds tests for Heat
  + per test_method logging
* Thu Aug 29 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1652.gbdaf137:
  + Switch run_tests.sh to run in parallel by default
  + Use common create_keypair method for autoscaling
  + Fix test_admin_catalog_list
  + Add large-ops option to tox
  + Add common "create_server_snapshot" method
  + Fix ssh timeout issue
  + Fix logging problem for stress test wrappers
* Wed Aug 28 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1638.gaa86efd:
  + Update requirements from global requirements
  + Add unittest framework + tests for wrapper scripts
  + removes self.fail as suggested by HACKING.rst
  + Always log stdout and stderr of CLI commands
  + Create discovery option for stress tests
  + Rename heat logical_resource_id to resource_name
* Mon Aug 26 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1627.ga7b9dbc:
  + Skip orchestration scenario tests if heat service not available
  + close http connections
  + Switch gating tox jobs to testr parallel
* Sat Aug 24 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1621.g7e42dd3:
  + Cleanup: Add common "ssh-login server" method
  + Protected matcher import
* Fri Aug 23 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1617.g6deb905:
  + cli: add messages to assertTrue
  + Heat autoscaling scenario test
  + Cleanup: Add common "create volume" method
  + Fixing format_flavor to handle flavor extra_specs
  + Unit tests as stress tests
  + Skip os-fixed-ips test since neutron has not implemented it
  + Provide tox entry for running slow heat tests
  + Fix skip tracker regex for multi-line skips
  + Fixed up a missing space in an error message
  + Add more tests for Swift Account Quota
  + use assertIsNotNone instead of assertNotEqual(*, None)
* Fri Aug 23 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1596.g7395517:
  + Cleanup: Add common "create keypair" method
  + Add tenant isolation to the swift tests
  + Adding network api xml support
  + Remove identity race condition
  + Mismatch dictionary key in the process of parsing XML
  + Cleanup: Add common "create security rule" method
* Wed Aug 21 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1584.g1d41b83:
  + Set missing attribute self.server in _create_and_attach utility
  + Remove skip of neutron connectivity check
* Wed Aug 21 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1580.g129acf5:
  + Fixing the rest of the comment spacing issues
* Mon Aug 19 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1578.g5f4fa8b:
  + Added 3 Routers related testcases for Neutron API
  + Testcase to create bulk networks in one API call
* Fri Aug 16 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1574.g1ac6776:
  + Fix typos in tempest/api/README.rst
  + skip test_list_servers_filtered_by_ip_regex on neutron gate
  + Fixed test for non-public flavor
  + Add nose to run_tests and tox for python 2.6
  + Remove positive tag
  + Cleanup: Add common "create_server" method
* Thu Aug 15 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1562.g4369755:
  + setUpClass/tearDownClass full chain
  + Adding extra_specs to flavor format
* Wed Aug 14 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1558.gbc8dbd3:
  + Cleanup try/except/finally blocks in several tests
* Wed Aug 14 2013 berendt@b1-systems.de
- added missing requirement python-tempest
* Tue Aug 13 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1557.g3049dc9:
  + Switch use of select() to poll()
  + Add tenant isolation for scenario tests
  + White space after # in the tempest/services
* Sat Aug 10 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1553.gf722050:
  + Fix posargs usage for tox jobs
  + Test cases for Roles V3 Actions
  + Add tests for swift container listing filters
* Sat Aug 10 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1547.gcb56994:
  + Switch to testr serial instead of nose
  + scenario test involving glance, cinder and nova functionalities
  + Rework class inheritance for scenario tests
  + Skip secgroup invalid name/desc tests until bug 1161411 is fixed
  + Fix return code for pretty_tox_serial.sh
* Thu Aug  8 2013 opensuse-cloud@opensuse.org
- Update to version 2013.2.a1539.ge8d508d:
  + Remove duplicate image tests for tenant authZ
  + Flag InstanceCfnInitTestJSON as the first slow heat test
  + Adds tests covering Swift's Account Quota middleware
  + Add test for swift ACLs
  + Skip more security group tests until bug 1182384 is fixed
  + Change logging in stress test
  + Added negative tests for server
* Sat Aug  3 2013 berendt@b1-systems.de
- initial creation
